(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     28160,        737]
NotebookOptionsPosition[     27096,        698]
NotebookOutlinePosition[     27725,        722]
CellTagsIndexPosition[     27682,        719]
WindowTitle->Generating Conics by Newton's Method - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Generating Conics by Newton's Method", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], "=", "ab"}], ";", "\[IndentingNewLine]", 
    RowBox[{"p", "=", 
     RowBox[{"{", 
      RowBox[{"px", ",", "1"}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"a", "\[Equal]", "b"}], ",", 
      RowBox[{"a", "=", 
       RowBox[{"b", "+", 
        RowBox[{"{", 
         RowBox[{".01", ",", "0"}], "}"}]}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Norm", "[", 
        RowBox[{"a", "-", "p"}], "]"}], "<", "0.01"}], ",", 
      RowBox[{"a", "=", 
       RowBox[{"p", "-", 
        RowBox[{"{", 
         RowBox[{".1", ",", ".1"}], "}"}]}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Norm", "[", 
        RowBox[{"b", "-", "p"}], "]"}], "<", "0.01"}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"p", "+", 
        RowBox[{"{", 
         RowBox[{".1", ",", ".1"}], "}"}]}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"m1", "=", 
     RowBox[{"RotationMatrix", "[", "\[Alpha]", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"m2", "=", 
     RowBox[{"RotationMatrix", "[", "\[Beta]", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v"}], "}"}], "}"}], "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", "yy"}], "}"}], "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"a", "+", 
           RowBox[{"xx", " ", 
            RowBox[{"m1", ".", 
             RowBox[{"(", 
              RowBox[{"p", "-", "a"}], ")"}]}]}]}], "\[Equal]", 
          RowBox[{"b", "+", 
           RowBox[{"yy", " ", 
            RowBox[{"m2", ".", 
             RowBox[{"(", 
              RowBox[{"p", "-", "b"}], ")"}]}]}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"xx", ",", "yy"}], "}"}]}], "]"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ColorData", "[", 
             RowBox[{"\"\<Legacy\>\"", ",", "\"\<Floral\>\""}], "]"}], ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "6"}], ",", 
                RowBox[{"-", "6"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"6", ",", "6"}], "}"}]}], "]"}], ",", "LightBlue", ",", 
            RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"10", ",", "1"}], "}"}]}], "}"}], "]"}], ",", "Brown",
             ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"px", "-", "0.2"}], ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"px", "+", "0.2"}], ",", "1"}], "}"}]}], "}"}], 
             "]"}]}], "}"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{"lab", ",", 
            RowBox[{"{", 
             RowBox[{"LightGray", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"ArcTan", "@@", 
                   RowBox[{"(", 
                    RowBox[{"p", "-", "a"}], ")"}]}], ",", 
                  RowBox[{"ArcTan", "@@", 
                   RowBox[{"(", 
                    RowBox[{"p", "-", "b"}], ")"}]}]}], "}"}]}], ";", 
               RowBox[{"Disk", "[", 
                RowBox[{"a", ",", 
                 RowBox[{
                  RowBox[{"Norm", "[", 
                   RowBox[{"p", "-", "a"}], "]"}], "/", "2"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{"\[Alpha]", "+", "i"}]}], "}"}]}], "]"}]}], ",", 
              RowBox[{"Disk", "[", 
               RowBox[{"b", ",", 
                RowBox[{
                 RowBox[{"Norm", "[", 
                  RowBox[{"p", "-", "b"}], "]"}], "/", "2"}], ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", 
                  RowBox[{"\[Beta]", "+", "j"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Rotate", "[", 
                   RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<\[Alpha]\>\"", ",", 
                    RowBox[{"a", "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{".4", 
                    RowBox[{"Norm", "[", 
                    RowBox[{"p", "-", "a"}], "]"}]}], " ", ",", "0"}], 
                    "}"}]}]}], "]"}], ",", 
                    RowBox[{"i", "+", 
                    RowBox[{"\[Alpha]", "/", "2"}]}], ",", "a"}], "]"}], ",", 
                  
                  RowBox[{"Rotate", "[", 
                   RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<\[Beta]\>\"", ",", 
                    RowBox[{"b", "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{".4", 
                    RowBox[{"Norm", "[", 
                    RowBox[{"p", "-", "b"}], "]"}]}], " ", ",", "0"}], 
                    "}"}]}]}], "]"}], ",", 
                    RowBox[{"j", "+", 
                    RowBox[{"\[Beta]", "/", "2"}]}], ",", "b"}], "]"}]}], 
                 "}"}], ",", "Black", ",", "20"}], "]"}], ",", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<A\>\"", ",", "Italic"}], "]"}], ",", "a", 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"1.5", ",", "1"}], "}"}]}], "]"}], ",", 
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<B\>\"", ",", "Italic"}], "]"}], ",", "b", 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", 
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<P\>\"", ",", "Italic"}], "]"}], ",", "p", 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1.5"}]}], "}"}]}], "]"}]}], "}"}], ",", 
                "Blue", ",", "20"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", "Black", ",", "Thin", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{"a", ",", "p", ",", "b"}], "}"}], "]"}], ",", "LightGray",
           ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"a", "+", 
              RowBox[{"1000", 
               RowBox[{"m1", ".", 
                RowBox[{"(", 
                 RowBox[{"p", "-", "a"}], ")"}]}]}]}], ",", 
             RowBox[{"a", "-", 
              RowBox[{"1000", 
               RowBox[{"m1", ".", 
                RowBox[{"(", 
                 RowBox[{"p", "-", "a"}], ")"}]}]}]}]}], "}"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"b", "+", 
              RowBox[{"1000", 
               RowBox[{"m2", ".", 
                RowBox[{"(", 
                 RowBox[{"p", "-", "b"}], ")"}]}]}]}], ",", 
             RowBox[{"b", "-", 
              RowBox[{"1000", " ", 
               RowBox[{"m2", ".", 
                RowBox[{"(", 
                 RowBox[{"p", "-", "b"}], ")"}]}]}]}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "Red", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"a", ",", "0.1"}], "]"}], ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"b", ",", "0.1"}], "]"}], ",", "Yellow", ",", 
            RowBox[{"Disk", "[", 
             RowBox[{
              RowBox[{"a", "+", 
               RowBox[{"u", " ", 
                RowBox[{"m1", ".", 
                 RowBox[{"(", 
                  RowBox[{"p", "-", "a"}], ")"}]}]}]}], ",", "0.1"}], "]"}]}],
            "}"}]}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", "None"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"sc", ",", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"u", ",", "v"}], "}"}], "}"}], "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"xx", ",", "yy"}], "}"}], "/.", 
               RowBox[{"Solve", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"a", "+", 
                   RowBox[{"xx", " ", 
                    RowBox[{"m1", ".", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"rr", ",", "1"}], "}"}], "-", "a"}], ")"}]}]}]}], 
                  "\[Equal]", 
                  RowBox[{"b", "+", 
                   RowBox[{"yy", " ", 
                    RowBox[{"m2", ".", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"rr", ",", "1"}], "}"}], "-", "b"}], 
                    ")"}]}]}]}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"xx", ",", "yy"}], "}"}]}], "]"}]}], ")"}]}], ";", 
            RowBox[{"a", "+", 
             RowBox[{"u", " ", 
              RowBox[{"m1", ".", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"rr", ",", "1"}], "}"}], "-", "a"}], ")"}]}]}]}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"rr", ",", 
            RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", 
          RowBox[{"ColorFunction", "\[Rule]", "Red"}], ",", 
          RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], "]"}], 
        ",", 
        RowBox[{"{", "}"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"550", ",", "400"}], "}"}]}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"\"\<None\>\"", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ab", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{".45", ",", 
            RowBox[{"-", "1.7"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", ".5"}], "}"}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "4"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "4"}], "}"}], ",", "Locator", ",", 
      RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "1.7", ",", "\"\<angle \[Alpha]\>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Beta]", ",", "1.7", ",", "\"\<angle \[Beta]\>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lab", ",", "True", ",", "\"\<labels\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sc", ",", "False", ",", "\"\<show conic\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px", ",", "2", ",", "\"\<move P\>\""}], "}"}], ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"TrackedSymbols", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.456667504995322*^9, 3.4566675073859625`*^9}, {
   3.4566686269898577`*^9, 3.4566686488024974`*^9}, {3.457190533368985*^9, 
   3.457190579508429*^9}, 3.457190653412787*^9, {3.457190816333229*^9, 
   3.4571908348643603`*^9}, {3.4571913241938396`*^9, 
   3.4571913796473193`*^9}, {3.4571914099443884`*^9, 
   3.4571914328039093`*^9}, {3.4571914657572455`*^9, 
   3.4571914669291277`*^9}, {3.4571915201482186`*^9, 3.457191677774227*^9}, {
   3.45719171564947*^9, 3.4571917177744837`*^9}, {3.457191797603119*^9, 
   3.457191922588294*^9}, 3.4571922034963417`*^9, {3.457451753242488*^9, 
   3.4574518171368766`*^9}, {3.4574518914423065`*^9, 3.457451944343596*^9}, {
   3.457869508398711*^9, 3.457869531288164*^9}, {3.45787574365941*^9, 
   3.457875746998744*^9}}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ab$$ = {{
     0.45, -1.7}, {-2, 0.5}}, $CellContext`lab$$ = True, $CellContext`px$$ = 
    2, $CellContext`sc$$ = False, $CellContext`\[Alpha]$$ = 
    1.7, $CellContext`\[Beta]$$ = 1.7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ab$$], {{0.45, -1.7}, {-2, 0.5}}}, {-6, -4}, {6, 
      4}}, {{
       Hold[$CellContext`\[Alpha]$$], 1.7, "angle \[Alpha]"}, 0, 2 Pi}, {{
       Hold[$CellContext`\[Beta]$$], 1.7, "angle \[Beta]"}, 0, 2 Pi}, {{
       Hold[$CellContext`lab$$], True, "labels"}, {True, False}}, {{
       Hold[$CellContext`sc$$], False, "show conic"}, {True, False}}, {{
       Hold[$CellContext`px$$], 2, "move P"}, -6, 6}}, Typeset`size$$ = {
    550., {198., 202.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`ab$1060560$$ = 
    0, $CellContext`\[Alpha]$1060561$$ = 0, $CellContext`\[Beta]$1060562$$ = 
    0, $CellContext`lab$1060563$$ = False, $CellContext`sc$1060564$$ = 
    False, $CellContext`px$1060565$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ab$$ = {{
          0.45, -1.7}, {-2, 0.5}}, $CellContext`lab$$ = 
        True, $CellContext`px$$ = 2, $CellContext`sc$$ = 
        False, $CellContext`\[Alpha]$$ = 1.7, $CellContext`\[Beta]$$ = 1.7}, 
      "ControllerVariables" :> {
        Hold[$CellContext`ab$$, $CellContext`ab$1060560$$, 0], 
        Hold[$CellContext`\[Alpha]$$, $CellContext`\[Alpha]$1060561$$, 0], 
        Hold[$CellContext`\[Beta]$$, $CellContext`\[Beta]$1060562$$, 0], 
        Hold[$CellContext`lab$$, $CellContext`lab$1060563$$, False], 
        Hold[$CellContext`sc$$, $CellContext`sc$1060564$$, False], 
        Hold[$CellContext`px$$, $CellContext`px$1060565$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ({$CellContext`a, $CellContext`b} = $CellContext`ab$$; \
$CellContext`p = {$CellContext`px$$, 1}; 
       If[$CellContext`a == $CellContext`b, $CellContext`a = $CellContext`b + \
{0.01, 0}]; 
       If[Norm[$CellContext`a - $CellContext`p] < 
         0.01, $CellContext`a = $CellContext`p - {0.1, 0.1}]; 
       If[Norm[$CellContext`b - $CellContext`p] < 
         0.01, $CellContext`b = $CellContext`p + {0.1, 0.1}]; $CellContext`m1 = 
        RotationMatrix[$CellContext`\[Alpha]$$]; $CellContext`m2 = 
        RotationMatrix[$CellContext`\[Beta]$$]; {{$CellContext`u, \
$CellContext`v}} = ReplaceAll[{$CellContext`xx, $CellContext`yy}, 
          
          Solve[$CellContext`a + $CellContext`xx 
             Dot[$CellContext`m1, $CellContext`p - $CellContext`a] == \
$CellContext`b + $CellContext`yy 
             Dot[$CellContext`m2, $CellContext`p - $CellContext`b], \
{$CellContext`xx, $CellContext`yy}]]; Show[
         Graphics[{{
            ColorData["Legacy", "Floral"], 
            Rectangle[{-6, -6}, {6, 6}], LightBlue, 
            Thickness[0.02], 
            Line[{{-10, 1}, {10, 1}}], Brown, 
            
            Line[{{$CellContext`px$$ - 0.2, 1}, {$CellContext`px$$ + 0.2, 
               1}}]}, 
           
           If[$CellContext`lab$$, {
            LightGray, {$CellContext`i, $CellContext`j} = {
                Apply[ArcTan, $CellContext`p - $CellContext`a], 
                Apply[ArcTan, $CellContext`p - $CellContext`b]}; 
             Disk[$CellContext`a, Norm[$CellContext`p - $CellContext`a]/
               2, {$CellContext`i, $CellContext`\[Alpha]$$ + $CellContext`i}], 
             
             Disk[$CellContext`b, Norm[$CellContext`p - $CellContext`b]/
              2, {$CellContext`j, $CellContext`\[Beta]$$ + $CellContext`j}], 
             Style[{
               Rotate[
                Text[
                "\[Alpha]", $CellContext`a + {
                  0.4 Norm[$CellContext`p - $CellContext`a], 
                   0}], $CellContext`i + $CellContext`\[Alpha]$$/
                 2, $CellContext`a], 
               Rotate[
                Text[
                "\[Beta]", $CellContext`b + {
                  0.4 Norm[$CellContext`p - $CellContext`b], 
                   0}], $CellContext`j + $CellContext`\[Beta]$$/
                 2, $CellContext`b]}, Black, 20], 
             Style[{
               Text[
                Style["A", Italic], $CellContext`a, {1.5, 1}], 
               Text[
                Style["B", Italic], $CellContext`b, {-2, -1}], 
               Text[
                Style["P", Italic], $CellContext`p, {0, -1.5}]}, Blue, 
              20]}, {}], Black, Thin, 
           Line[{$CellContext`a, $CellContext`p, $CellContext`b}], LightGray, 
           
           
           Line[{$CellContext`a + 
             1000 Dot[$CellContext`m1, $CellContext`p - $CellContext`a], \
$CellContext`a - 1000 Dot[$CellContext`m1, $CellContext`p - $CellContext`a]}], 
           
           Line[{$CellContext`b + 
             1000 Dot[$CellContext`m2, $CellContext`p - $CellContext`b], \
$CellContext`b - 1000 
             Dot[$CellContext`m2, $CellContext`p - $CellContext`b]}], {
            EdgeForm[Thick], Red, 
            Disk[$CellContext`a, 0.1], 
            Disk[$CellContext`b, 0.1], Yellow, 
            
            Disk[$CellContext`a + $CellContext`u 
              Dot[$CellContext`m1, $CellContext`p - $CellContext`a], 0.1]}}, 
          PlotRange -> {{-6, 6}, {-4, 4}}, Frame -> True, FrameTicks -> None], 
         If[$CellContext`sc$$, 
          ParametricPlot[
           
           Evaluate[{{$CellContext`u, $CellContext`v}} = 
             ReplaceAll[{$CellContext`xx, $CellContext`yy}, 
               
               Solve[$CellContext`a + $CellContext`xx 
                  Dot[$CellContext`m1, {$CellContext`rr, 
                    1} - $CellContext`a] == $CellContext`b + $CellContext`yy 
                  Dot[$CellContext`m2, {$CellContext`rr, 
                    1} - $CellContext`b], {$CellContext`xx, \
$CellContext`yy}]]; $CellContext`a + $CellContext`u 
              Dot[$CellContext`m1, {$CellContext`rr, 
                  1} - $CellContext`a]], {$CellContext`rr, -10, 10}, Axes -> 
           False, ColorFunction -> Red, PerformanceGoal -> "Quality"], {}], 
         ImageSize -> {550, 400}]), 
      "Specifications" :> {
       "None" -> {{$CellContext`ab$$, {{0.45, -1.7}, {-2, 0.5}}}, {-6, -4}, {
          6, 4}, ControlType -> Locator, Appearance -> 
          None}, {{$CellContext`\[Alpha]$$, 1.7, "angle \[Alpha]"}, 0, 2 
         Pi}, {{$CellContext`\[Beta]$$, 1.7, "angle \[Beta]"}, 0, 2 
         Pi}, {{$CellContext`lab$$, True, "labels"}, {
         True, False}}, {{$CellContext`sc$$, False, "show conic"}, {
         True, False}}, {{$CellContext`px$$, 2, "move P"}, -6, 6}}, 
      "Options" :> {TrackedSymbols -> True}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{601., {290., 295.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->298628865],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Generating Conics by Newton's Method",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/GeneratingConicsByNewtonsMethod/"],
     None},
  ButtonNote->
   "http://demonstrations.wolfram.com/GeneratingConicsByNewtonsMethod/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/GeneratingConicsByNewtonsMethod/\
",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/GeneratingConicsByNewtonsMethod/"],
     None},
  ButtonNote->
   "http://demonstrations.wolfram.com/GeneratingConicsByNewtonsMethod/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Jaime Rangel-Mondragon",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Jaime+Rangel-\
Mondragon"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Jaime+Rangel-\
Mondragon"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
GeneratingConicsByNewtonsMethod"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{780, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Generating Conics by Newton's Method - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[626, 23, 228, 4, 70, "Section"],
Cell[857, 29, 14333, 377, 70, "Input"]
}, Open  ]],
Cell[15205, 409, 7587, 150, 70, "Output",
 CellID->298628865],
Cell[CellGroupData[{
Cell[22817, 563, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[23193, 574, 988, 29, 70, "Text"],
Cell[24184, 605, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[24524, 616, 462, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[25011, 635, 847, 24, 70, "Text"],
Cell[25861, 661, 1207, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature 5SN87fyy9j1BjA0guzxfdD#j *)
