(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     20829,        523]
NotebookOptionsPosition[     19633,        478]
NotebookOutlinePosition[     20263,        502]
CellTagsIndexPosition[     20220,        499]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Family of Curves, Tangents, and Intuition", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", " ", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DynamicModule", " ", "[", 
    RowBox[{
     RowBox[{"{", "x", "}"}], ",", " ", 
     RowBox[{"With", " ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"family", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "x"}], "]"}], 
            RowBox[{"n", 
             SqrtBox["x"]}]], ",", " ", 
           RowBox[{"{", 
            RowBox[{"n", ",", " ", "1", ",", "  ", "nMax"}], "}"}]}], "]"}]}],
         "}"}], ",", " ", "\[IndentingNewLine]", 
       RowBox[{"With", " ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"derivatives", " ", "=", "   ", 
           RowBox[{"Take", " ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"D", " ", "[", 
                RowBox[{"#", ",", "x"}], "]"}], "&"}], "/@", " ", "family"}], 
             ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"nMax", " ", "-", "3"}], ",", " ", "nMax"}], "}"}]}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"at0", "=", "  ", 
              RowBox[{
               RowBox[{
                RowBox[{"Limit", "[", 
                 RowBox[{"#", ",", " ", 
                  RowBox[{"x", "\[Rule]", " ", "0"}]}], "]"}], "&"}], " ", "/@",
                " ", "derivatives"}]}], " ", ",", " ", "\[IndentingNewLine]", 
             
             RowBox[{"atMiddle", "=", 
              RowBox[{"derivatives", " ", "/.", 
               RowBox[{"x", "\[Rule]", " ", 
                FractionBox["\[Pi]", "2"]}]}]}], ",", " ", 
             "\[IndentingNewLine]", 
             RowBox[{"at\[Pi]", "=", 
              RowBox[{"derivatives", " ", "/.", 
               RowBox[{"x", "\[Rule]", " ", "\[Pi]"}]}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{"family", ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "  ", "0", ",", " ", "\[Pi]"}], "}"}], ",", 
               
               RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
                RowBox[{"Table", " ", "[", 
                 RowBox[{
                  RowBox[{"Hue", "[", 
                   RowBox[{
                    FractionBox["n", "nMax"], "//", "N"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"n", ",", " ", "1", ",", " ", "nMax"}], "}"}]}], 
                 "]"}]}]}], "]"}], ",", "    ", "\[IndentingNewLine]", 
             RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLabel", " ", "\[Rule]", 
              RowBox[{"Row", "[", 
               RowBox[{"{", 
                RowBox[{
                "\"\< \!\(\*FractionBox[\(sin\\\ \((n\\\ x)\)\), \(n \
\*SqrtBox[\(x\)]\)]\)  where \>\"", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<n\>\"", ",", "Italic"}], "]"}], ",", 
                 "\"\< goes from 1 to  \>\"", " ", ",", " ", 
                 RowBox[{"ToString", "[", "nMax", "]"}]}], "}"}], "]"}]}], 
             " ", ",", "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", " ", "\[Rule]", " ", 
              RowBox[{"1", "/", "\[Pi]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"Background", " ", "\[Rule]", 
              RowBox[{"RGBColor", "[", 
               RowBox[{"0.911254", ",", " ", "1", ",", " ", "0.92575"}], 
               "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", " ", "\[Rule]", " ", 
              RowBox[{"{", 
               RowBox[{"580", ",", "Automatic"}], "}"}]}], ",", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"FrameLabel", " ", "\[Rule]", " ", 
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Grid", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Prepend", "[", " ", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Range", " ", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"nMax", "-", "3"}], ",", " ", "nMax"}], "}"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"nMax", "-", "3"}], ",", " ", "nMax"}], "}"}], 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
                    "]"}], ",", 
                    RowBox[{"Take", " ", "[", 
                    RowBox[{"family", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"nMax", "-", "3"}], ",", " ", "nMax"}], "}"}]}], 
                    "]"}], ",", "derivatives", ",", "at0", ",", "atMiddle", 
                    ",", "at\[Pi]"}], "}"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<n\>\"", ",", "Italic"}], "]"}], ",", 
                    "\[IndentingNewLine]", "\"\<function\>\"", ",", 
                    "\[IndentingNewLine]", "\"\<derivative\>\"", ",", " ", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", "\"\<tangent at {0, 0}\>\"", "}"}], ",", " ",
                     "Center"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", "\"\<derivative at \[Pi]/2\>\"", "}"}], ",", 
                    " ", "Center"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", "\"\<derivative at \[Pi]\>\"", "}"}], ",", 
                    " ", "Center"}], "]"}]}], "}"}]}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Frame", "\[Rule]", "All"}], ",", " ", 
                  RowBox[{"ItemSize", "\[Rule]", "All"}]}], "]"}], "/.", " ", 
                
                RowBox[{"x", "\[Rule]", " ", 
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}]}]}], " ", 
               "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"FrameTicks", " ", "\[Rule]", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  FractionBox[
                   RowBox[{"\[Pi]", " "}], "2"], ",", "\[Pi]"}], "}"}], ",", 
                " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  FractionBox[
                   RowBox[{"\[Pi]", " "}], "2"]}], "}"}]}], "}"}]}]}], 
            "]"}]}], "]"}]}], "]"}]}], "]"}]}], "]"}], " ", ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nMax", ",", " ", "4", ",", "\"\<number of curves\>\""}], "}"}],
      ",", "4", ",", "20", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.378883814888283*^9, 3.378883870120311*^9}, 
   3.378884654653557*^9, {3.378884793444592*^9, 3.378884813091158*^9}, {
   3.378884852795001*^9, 3.378884885004467*^9}, {3.3788849532302713`*^9, 
   3.3788849549959297`*^9}, {3.3788862359334*^9, 3.3788862365267982`*^9}, {
   3.37889289502631*^9, 3.37889293906289*^9}, {3.3788930021794024`*^9, 
   3.378893009103471*^9}, 3.378893047403016*^9, {3.3788931454613123`*^9, 
   3.3788931525061693`*^9}, {3.378893460891883*^9, 3.378893466284343*^9}, {
   3.378894171352919*^9, 3.378894180433364*^9}, {3.378894301723146*^9, 
   3.378894331957818*^9}, 3.378894616849918*^9, {3.378894866327581*^9, 
   3.378894930912492*^9}, {3.3788949651298037`*^9, 3.378894977448226*^9}, {
   3.378895061432249*^9, 3.378895078672381*^9}, {3.3788951229205513`*^9, 
   3.3788951503560762`*^9}, {3.378895204579384*^9, 3.378895219989113*^9}, {
   3.3788958240882397`*^9, 3.378895901322853*^9}, 3.378896566697837*^9, {
   3.3788973645572433`*^9, 3.378897365185464*^9}, {3.37889756439233*^9, 
   3.378897581345936*^9}, 3.378897640922291*^9, {3.378898174207196*^9, 
   3.3788981747991257`*^9}, {3.378898880534008*^9, 3.3788988811733103`*^9}, {
   3.3789010808420687`*^9, 3.378901083243099*^9}, {3.4010933047301617`*^9, 
   3.401093317819491*^9}, {3.401093661450281*^9, 3.4010936753284683`*^9}, 
   3.4011289943916197`*^9, {3.4012666714286137`*^9, 3.4012666984429407`*^9}, {
   3.401266739628871*^9, 3.401266795209145*^9}, {3.401284316447954*^9, 
   3.401284317405499*^9}, {3.4013009065123587`*^9, 3.40130096047005*^9}, {
   3.4013010330225677`*^9, 3.401301083340029*^9}, {3.4029441413440347`*^9, 
   3.4029441778127847`*^9}, {3.4029442090002847`*^9, 
   3.4029442274846597`*^9}, {3.4029443053752847`*^9, 
   3.4029443272190347`*^9}, {3.4029443677346597`*^9, 
   3.4029443949377847`*^9}, {3.4029445610784097`*^9, 3.4029445662971597`*^9}},
 
 CellID->95427165]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`nMax$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`nMax$$], 4, "number of curves"}, 4, 20, 1}}, 
    Typeset`size$$ = {580., {236., 240.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`nMax$75096$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`nMax$$ = 4}, 
      "ControllerVariables" :> {
        Hold[$CellContext`nMax$$, $CellContext`nMax$75096$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> DynamicModule[{$CellContext`x}, 
        With[{$CellContext`family$ = 
          Table[Sin[$CellContext`n $CellContext`x]/($CellContext`n \
$CellContext`x^Rational[1, 2]), {$CellContext`n, 1, $CellContext`nMax$$}]}, 
         With[{$CellContext`derivatives$ = Take[
             Map[
             D[#, $CellContext`x]& , $CellContext`family$], \
{$CellContext`nMax$$ - 3, $CellContext`nMax$$}]}, 
          
          With[{$CellContext`at0$ = 
            Map[Limit[#, $CellContext`x -> 
               0]& , $CellContext`derivatives$], $CellContext`atMiddle$ = 
            ReplaceAll[$CellContext`derivatives$, $CellContext`x -> 
              Pi/2], $CellContext`at\[Pi]$ = 
            ReplaceAll[$CellContext`derivatives$, $CellContext`x -> Pi]}, 
           Plot[
            
            Evaluate[$CellContext`family$, {$CellContext`x, 0, Pi}, PlotStyle -> 
             Table[
               Hue[
                N[$CellContext`n/$CellContext`nMax$$]], {$CellContext`n, 
                1, $CellContext`nMax$$}]], PlotRange -> All, Axes -> True, 
            PlotLabel -> 
            Row[{" \!\(\*FractionBox[\(sin \((n x)\)\), \(n \
\*SqrtBox[\(x\)]\)]\)  where ", 
               Style["n", Italic], " goes from 1 to  ", 
               ToString[$CellContext`nMax$$]}], AspectRatio -> 1/Pi, 
            Background -> RGBColor[0.911254, 1, 0.92575], 
            ImageSize -> {580, Automatic}, RotateLabel -> False, Frame -> 
            True, FrameLabel -> {
              ReplaceAll[
               Grid[
                Prepend[
                 Transpose[{
                   Range[
                    Part[{$CellContext`nMax$$ - 3, $CellContext`nMax$$}, 1], 
                    Part[{$CellContext`nMax$$ - 3, $CellContext`nMax$$}, 2]], 
                   
                   
                   Take[$CellContext`family$, {$CellContext`nMax$$ - 
                    3, $CellContext`nMax$$}], $CellContext`derivatives$, \
$CellContext`at0$, $CellContext`atMiddle$, $CellContext`at\[Pi]$}], {
                  Style["n", Italic], "function", "derivative", 
                  Column[{"tangent at {0, 0}"}, Center], 
                  Column[{"derivative at \[Pi]/2"}, Center], 
                  Column[{"derivative at \[Pi]"}, Center]}], Frame -> All, 
                ItemSize -> All], $CellContext`x -> Style["x", Italic]]}, 
            FrameTicks -> {{0, Pi/2, Pi}, {0, Pi/2}}]]]]], 
      "Specifications" :> {{{$CellContext`nMax$$, 4, "number of curves"}, 4, 
         20, 1, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{624., {279., 284.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->923306473],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Family of Curves, Tangents, and Intuition",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/FamilyOfCurvesTangentsAndIntuition/\
"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/FamilyOfCurvesTangentsAndIntuition/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
FamilyOfCurvesTangentsAndIntuition/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/FamilyOfCurvesTangentsAndIntuition/\
"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/FamilyOfCurvesTangentsAndIntuition/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Jacqueline Zizi",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Jacqueline+\
Zizi"], None}]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->520555819],

Cell[TextData[{
 "Additional contributions by: ",
 ButtonBox["Michael Schreiber",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Michael+\
Schreiber"], None}]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->152889438]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 system is required to edit or run this notebook.\[IndentingNewLine](",
 StyleBox["Mathematica Player",
  FontSlant->"Italic"],
 " runs only Demonstrations published on this site.)\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA 6 \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
FamilyOfCurvesTangentsAndIntuition"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{780, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Family of Curves, Tangents, and Intuition - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 233, 4, 70, "Section"],
Cell[826, 29, 10035, 208, 70, "Input",
 CellID->95427165]
}, Open  ]],
Cell[10876, 240, 3986, 80, 70, "Output",
 CellID->923306473],
Cell[CellGroupData[{
Cell[14887, 324, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[15263, 335, 1002, 29, 70, "Text"],
Cell[16268, 366, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[CellGroupData[{
Cell[16630, 379, 369, 13, 70, "Text",
 CellID->520555819],
Cell[17002, 394, 386, 13, 70, "Text",
 CellID->152889438]
}, Open  ]],
Cell[CellGroupData[{
Cell[17425, 412, 967, 27, 70, "Text"],
Cell[18395, 441, 1210, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature xSjKBEdRYiYa#BT#5d6lPtLT *)
