(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32322,        842]
NotebookOptionsPosition[     31211,        802]
NotebookOutlinePosition[     31886,        827]
CellTagsIndexPosition[     31843,        824]
WindowTitle->Maximizing the Volume and Surface Area of Geometric Solids \
Inscribed in a Sphere - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Maximizing the Volume and Surface Area of Geometric Solids Inscribed in a \
Sphere\
\>", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"r", ">", "maxr"}], ",", 
      RowBox[{"r", "=", "maxr"}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"theSphere", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Opacity", "[", "0.4", "]"}], ",", 
        RowBox[{"Sphere", "[", "]"}]}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"theCircle", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Circle", "[", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"theCylinder", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Cylinder", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", 
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "-", 
                 RowBox[{"r", "^", "2"}]}], "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"r", "^", "2"}]}], "]"}]}], "}"}]}], "}"}], ",", 
          "r"}], "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"volCylinder", "[", "r_", "]"}], ":=", 
     RowBox[{"Pi", "*", 
      RowBox[{"r", "^", "2"}], "*", "2", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"r", "^", "2"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"surfCylinder", "[", "r_", "]"}], ":=", 
     RowBox[{
      RowBox[{"2", "Pi", " ", "*", 
       RowBox[{"r", "^", "2"}]}], "+", 
      RowBox[{"2", "Pi", "*", "r", "*", "2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"r", "^", "2"}]}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"projCylinder", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Blue"}], "]"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{".25", ",", ".75", ",", ".25"}], "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "r"}], ",", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "-", 
               RowBox[{"r", "^", "2"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              RowBox[{"r", "^", "2"}]}], "]"}]}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"theCone", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Cone", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", 
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "-", 
                 RowBox[{"r", "^", "2"}]}], "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", "r"}], 
         "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"volCone", "[", "r_", "]"}], ":=", 
     RowBox[{
      RowBox[{"1", "/", "3"}], "*", "Pi", "*", 
      RowBox[{"r", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"r", "^", "2"}]}], "]"}]}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"surfCone", "[", "r_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Pi", " ", "*", 
       RowBox[{"r", "^", "2"}]}], "+", 
      RowBox[{"Pi", "*", "r", "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"r", "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              RowBox[{"r", "^", "2"}]}], "]"}]}], ")"}], "^", "2"}]}], 
        "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"projCone", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Blue"}], "]"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{".25", ",", ".75", ",", ".25"}], "]"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "r"}], ",", 
             RowBox[{"-", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"r", "^", "2"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", 
             RowBox[{"-", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", 
                RowBox[{"r", "^", "2"}]}], "]"}]}]}], "}"}]}], "}"}], "]"}]}],
        "}"}], "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"theCuboid", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Cuboid", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "r"}], " ", ",", 
            RowBox[{"-", "r"}], ",", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "-", 
               RowBox[{"2", 
                RowBox[{"r", "^", "2"}]}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", " ", ",", "r", " ", ",", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              RowBox[{"2", 
               RowBox[{"r", "^", "2"}]}]}], "]"}]}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"volCuboid", "[", "r_", "]"}], ":=", 
     RowBox[{"4", 
      RowBox[{"r", "^", "2"}], "*", "2", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"2", 
         RowBox[{"r", "^", "2"}]}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"surfCuboid", "[", "r_", "]"}], ":=", 
     RowBox[{
      RowBox[{"8", 
       RowBox[{"r", "^", "2"}]}], "+", 
      RowBox[{"4", "*", "2", "r", "*", "2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"2", 
          RowBox[{"r", "^", "2"}]}]}], "]"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"projCuboid", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Blue"}], "]"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{".25", ",", ".75", ",", ".25"}], "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "r"}], " ", ",", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "-", 
               RowBox[{"2", 
                RowBox[{"r", "^", "2"}]}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", " ", ",", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              RowBox[{"2", 
               RowBox[{"r", "^", "2"}]}]}], "]"}]}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Switch", "[", 
     RowBox[{"fig", ",", "\[IndentingNewLine]", "cylinder", ",", 
      RowBox[{
       RowBox[{"theFigure", "=", "theCylinder"}], ";", 
       RowBox[{"maxr", "=", "1"}], ";", 
       RowBox[{"volFunc", "=", "volCylinder"}], ";", 
       RowBox[{"surfFunc", "=", "surfCylinder"}], ";", 
       RowBox[{"proj", "=", "projCylinder"}]}], ",", "\[IndentingNewLine]", 
      "cone", ",", 
      RowBox[{
       RowBox[{"theFigure", "=", "theCone"}], ";", 
       RowBox[{"maxr", "=", "1"}], ";", 
       RowBox[{"volFunc", "=", "volCone"}], ";", 
       RowBox[{"surfFunc", "=", "surfCone"}], ";", 
       RowBox[{"proj", "=", "projCone"}]}], ",", "\[IndentingNewLine]", 
      "cuboid", ",", 
      RowBox[{
       RowBox[{"theFigure", "=", "theCuboid"}], ";", 
       RowBox[{"maxr", "=", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "/", "2"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"r", ">", 
          RowBox[{
           RowBox[{"Sqrt", "[", "2", "]"}], "/", "2"}]}], ",", 
         RowBox[{"r", "=", "0.25"}]}], "]"}], ";", 
       RowBox[{"volFunc", "=", "volCuboid"}], ";", 
       RowBox[{"surfFunc", "=", "surfCuboid"}], ";", 
       RowBox[{"proj", "=", "projCuboid"}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"volPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"volFunc", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxr"}], "}"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<volume of \>\"", ",", "fig"}], "}"}], "]"}], ",", 
          "18"}], "]"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "250"}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", "20"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"surfPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"surfFunc", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxr"}], "}"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<surface area of \>\"", ",", "fig"}], "}"}], "]"}], 
          ",", "18"}], "]"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "250"}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", "20"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"projPlot", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"theCircle", ",", "proj", ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"x", ",", "z"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pointOnVolCurve", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Large", "]"}], ",", "Green", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"volFunc", "[", "r", "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"pointOnSurfCurve", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Large", "]"}], ",", "Green", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"surfFunc", "[", "r", "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"volDisplay", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"volPlot", ",", "pointOnVolCurve", ",", 
       RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"surfDisplay", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"surfPlot", ",", "pointOnSurfCurve", ",", 
       RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Switch", "[", 
     RowBox[{"obj", ",", "volume", ",", 
      RowBox[{"displayFunc", "=", "volDisplay"}], ",", "surface", ",", 
      RowBox[{"displayFunc", "=", "surfDisplay"}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Switch", "[", 
     RowBox[{"disp", ",", "False", ",", 
      RowBox[{"theDisplay", "=", "displayFunc"}], ",", "True", ",", 
      RowBox[{"theDisplay", "=", "projPlot"}]}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Text", "@", 
     RowBox[{"Pane", "[", 
      RowBox[{
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Show", "[", 
           RowBox[{"theSphere", ",", "theFigure", ",", 
            RowBox[{"Axes", "\[Rule]", "True"}], ",", 
            RowBox[{"AxesOrigin", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}], ",", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Show", "[", "theDisplay", "]"}], ",", "\"\<\>\"", ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{"\"\<r\>\"", ",", "Italic"}], "]"}], ",", 
                  "\"\< = \>\"", ",", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{"r", ",", 
                    RowBox[{"{", 
                    RowBox[{"6", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], 
               ",", "24"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<volume = \>\"", ",", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{
                    RowBox[{"volFunc", "[", "r", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"6", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], 
               ",", "24"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<surface area = \>\"", ",", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{
                    RowBox[{"surfFunc", "[", "r", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"6", ",", "4"}], "}"}]}], "]"}]}], "}"}], "]"}], 
               ",", "24"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"560", ",", "360"}], "}"}]}]}], "]"}]}]}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fig", ",", "cylinder", ",", "\"\<figure\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cylinder", ",", "cone", ",", "cuboid"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"obj", ",", "volume", ",", "\"\<objective\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"volume", "\[Rule]", "\"\<volume\>\""}], ",", 
       RowBox[{"surface", "\[Rule]", "\"\<surface area\>\""}]}], "}"}], ",", 
     RowBox[{"Enabled", "\[Rule]", 
      RowBox[{"!", "disp"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0.5"}], "}"}], ",", "0", ",", "maxr"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"disp", ",", "False", ",", "\"\<show projection\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"False", ",", "True"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"maxr", ",", "1"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", "True"}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.4605813993125*^9, {3.460745712505432*^9, 
   3.46074579559865*^9}, {3.461070793274021*^9, 3.461070858725566*^9}, {
   3.4610709068253756`*^9, 3.461070967398432*^9}}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`disp$$ = 
    False, $CellContext`fig$$ = $CellContext`cylinder, $CellContext`maxr$$ = 
    1, $CellContext`obj$$ = $CellContext`volume, $CellContext`r$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`fig$$], $CellContext`cylinder, 
       "figure"}, {$CellContext`cylinder, $CellContext`cone, \
$CellContext`cuboid}}, {{
       Hold[$CellContext`obj$$], $CellContext`volume, 
       "objective"}, {$CellContext`volume -> "volume", $CellContext`surface -> 
       "surface area"}}, {{
       Hold[$CellContext`r$$], 0.5}, 0, 
      Dynamic[$CellContext`maxr$$]}, {{
       Hold[$CellContext`disp$$], False, "show projection"}, {False, True}}, {{
       Hold[$CellContext`maxr$$], 1}}}, Typeset`size$$ = {560., {178., 184.}},
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`fig$49258$$ = 0, $CellContext`obj$49259$$ = 
    False, $CellContext`r$49260$$ = 0, $CellContext`disp$49261$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`disp$$ = 
        False, $CellContext`fig$$ = $CellContext`cylinder, \
$CellContext`maxr$$ = 
        1, $CellContext`obj$$ = $CellContext`volume, $CellContext`r$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`fig$$, $CellContext`fig$49258$$, 0], 
        Hold[$CellContext`obj$$, $CellContext`obj$49259$$, False], 
        Hold[$CellContext`r$$, $CellContext`r$49260$$, 0], 
        Hold[$CellContext`disp$$, $CellContext`disp$49261$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> (
       If[$CellContext`r$$ > $CellContext`maxr$$, $CellContext`r$$ = \
$CellContext`maxr$$]; $CellContext`theSphere = Graphics3D[{
           Opacity[0.4], 
           Sphere[]}]; $CellContext`theCircle = Graphics[
          Circle[]]; $CellContext`theCylinder = Graphics3D[{Green, 
           Cylinder[{{0, 0, -Sqrt[1 - $CellContext`r$$^2]}, {0, 0, 
              Sqrt[
              1 - $CellContext`r$$^2]}}, $CellContext`r$$]}]; \
$CellContext`volCylinder[
          Pattern[$CellContext`r, 
           Blank[]]] := 
        Pi $CellContext`r^2 2 
         Sqrt[1 - $CellContext`r^2]; $CellContext`surfCylinder[
          Pattern[$CellContext`r, 
           Blank[]]] := 
        2 Pi $CellContext`r^2 + 
         2 Pi $CellContext`r 2 
          Sqrt[1 - $CellContext`r^2]; $CellContext`projCylinder = Graphics[{
           EdgeForm[
            Directive[Thick, Blue]], 
           RGBColor[0.25, 0.75, 0.25], 
           
           Rectangle[{-$CellContext`r$$, -
             Sqrt[1 - $CellContext`r$$^2]}, {$CellContext`r$$, 
             Sqrt[1 - $CellContext`r$$^2]}]}]; $CellContext`theCone = 
        Graphics3D[{Green, 
           
           Cone[{{0, 0, -Sqrt[1 - $CellContext`r$$^2]}, {0, 0, 
             1}}, $CellContext`r$$]}]; $CellContext`volCone[
          Pattern[$CellContext`r, 
           Blank[]]] := (1/3) 
         Pi $CellContext`r^2 (1 + 
          Sqrt[1 - $CellContext`r^2]); $CellContext`surfCone[
          Pattern[$CellContext`r, 
           Blank[]]] := 
        Pi $CellContext`r^2 + 
         Pi $CellContext`r 
          Sqrt[$CellContext`r^2 + (1 + 
              Sqrt[1 - $CellContext`r^2])^2]; $CellContext`projCone = 
        Graphics[{
           EdgeForm[
            Directive[Thick, Blue]], 
           RGBColor[0.25, 0.75, 0.25], 
           
           Polygon[{{-$CellContext`r$$, -Sqrt[1 - $CellContext`r$$^2]}, {0, 
             1}, {$CellContext`r$$, -
              Sqrt[1 - $CellContext`r$$^2]}}]}]; $CellContext`theCuboid = 
        Graphics3D[{Green, 
           
           Cuboid[{-$CellContext`r$$, -$CellContext`r$$, -
             Sqrt[1 - 
               2 $CellContext`r$$^2]}, {$CellContext`r$$, $CellContext`r$$, 
             Sqrt[1 - 2 $CellContext`r$$^2]}]}]; $CellContext`volCuboid[
          Pattern[$CellContext`r, 
           Blank[]]] := 
        4 $CellContext`r^2 2 
         Sqrt[1 - 2 $CellContext`r^2]; $CellContext`surfCuboid[
          Pattern[$CellContext`r, 
           Blank[]]] := 
        8 $CellContext`r^2 + 
         4 2 $CellContext`r 2 
          Sqrt[1 - 2 $CellContext`r^2]; $CellContext`projCuboid = Graphics[{
           EdgeForm[
            Directive[Thick, Blue]], 
           RGBColor[0.25, 0.75, 0.25], 
           
           Rectangle[{-$CellContext`r$$, -
             Sqrt[1 - 2 $CellContext`r$$^2]}, {$CellContext`r$$, 
             Sqrt[1 - 2 $CellContext`r$$^2]}]}]; 
       Switch[$CellContext`fig$$, $CellContext`cylinder, \
$CellContext`theFigure = $CellContext`theCylinder; $CellContext`maxr$$ = 
          1; $CellContext`volFunc = $CellContext`volCylinder; \
$CellContext`surfFunc = $CellContext`surfCylinder; $CellContext`proj = \
$CellContext`projCylinder, $CellContext`cone, $CellContext`theFigure = \
$CellContext`theCone; $CellContext`maxr$$ = 
          1; $CellContext`volFunc = $CellContext`volCone; \
$CellContext`surfFunc = $CellContext`surfCone; $CellContext`proj = \
$CellContext`projCone, $CellContext`cuboid, $CellContext`theFigure = \
$CellContext`theCuboid; $CellContext`maxr$$ = Sqrt[2]/2; 
         If[$CellContext`r$$ > Sqrt[2]/2, $CellContext`r$$ = 
           0.25]; $CellContext`volFunc = $CellContext`volCuboid; \
$CellContext`surfFunc = $CellContext`surfCuboid; $CellContext`proj = \
$CellContext`projCuboid]; $CellContext`volPlot = Plot[
          $CellContext`volFunc[$CellContext`x], {$CellContext`x, 
           0, $CellContext`maxr$$}, PlotLabel -> Style[
            Row[{"volume of ", $CellContext`fig$$}], 18], ImageSize -> 250, 
          ImagePadding -> 20]; $CellContext`surfPlot = Plot[
          $CellContext`surfFunc[$CellContext`x], {$CellContext`x, 
           0, $CellContext`maxr$$}, PlotLabel -> Style[
            Row[{"surface area of ", $CellContext`fig$$}], 18], ImageSize -> 
          250, ImagePadding -> 20]; $CellContext`projPlot = 
        Show[$CellContext`theCircle, $CellContext`proj, Axes -> True, 
          AxesLabel -> {$CellContext`x, $CellContext`z}, ImageSize -> 
          200]; $CellContext`pointOnVolCurve = Graphics[{
           PointSize[Large], Green, 
           Point[{$CellContext`r$$, 
             $CellContext`volFunc[$CellContext`r$$]}]}]; \
$CellContext`pointOnSurfCurve = Graphics[{
           PointSize[Large], Green, 
           Point[{$CellContext`r$$, 
             $CellContext`surfFunc[$CellContext`r$$]}]}]; \
$CellContext`volDisplay = 
        Show[$CellContext`volPlot, $CellContext`pointOnVolCurve, ImageSize -> 
          250]; $CellContext`surfDisplay = 
        Show[$CellContext`surfPlot, $CellContext`pointOnSurfCurve, ImageSize -> 
          250]; Switch[$CellContext`obj$$, $CellContext`volume, \
$CellContext`displayFunc = $CellContext`volDisplay, $CellContext`surface, \
$CellContext`displayFunc = $CellContext`surfDisplay]; 
       Switch[$CellContext`disp$$, 
         False, $CellContext`theDisplay = $CellContext`displayFunc, 
         True, $CellContext`theDisplay = $CellContext`projPlot]; Text[
         Pane[
          Row[{
            
            Show[$CellContext`theSphere, $CellContext`theFigure, Axes -> True,
              AxesOrigin -> {0, 0, 0}, ImageSize -> 300], 
            Column[{
              Show[$CellContext`theDisplay], "", 
              Style[
               Row[{
                 Style["r", Italic], " = ", 
                 NumberForm[$CellContext`r$$, {6, 4}]}], 24], 
              Style[
               Row[{"volume = ", 
                 NumberForm[
                  $CellContext`volFunc[$CellContext`r$$], {6, 4}]}], 24], 
              Style[
               Row[{"surface area = ", 
                 NumberForm[
                  $CellContext`surfFunc[$CellContext`r$$], {6, 4}]}], 24]}]}],
           ImageSize -> {560, 360}]]), 
      "Specifications" :> {{{$CellContext`fig$$, $CellContext`cylinder, 
          
          "figure"}, {$CellContext`cylinder, $CellContext`cone, \
$CellContext`cuboid}}, {{$CellContext`obj$$, $CellContext`volume, 
          "objective"}, {$CellContext`volume -> 
          "volume", $CellContext`surface -> "surface area"}, Enabled -> 
         Dynamic[
           Not[$CellContext`disp$$]]}, {{$CellContext`r$$, 0.5}, 0, 
         Dynamic[$CellContext`maxr$$]}, {{$CellContext`disp$$, False, 
          "show projection"}, {False, True}}, {{$CellContext`maxr$$, 1}, 
         ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> True, AutorunSequencing -> {1, 2, 3, 4}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{605., {257., 262.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->141444057],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Maximizing the Volume and Surface Area of Geometric Solids \
Inscribed in a Sphere",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Marc Brodie",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Marc+Brodie"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Marc+Brodie"],
 " (Wheeling Jesuit University)"
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
MaximizingTheVolumeAndSurfaceAreaOfGeometricSolidsInscribedI"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{780, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Maximizing the Volume and Surface Area of Geometric Solids \
Inscribed in a Sphere - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[672, 24, 282, 7, 70, "Section"],
Cell[957, 33, 16339, 430, 70, "Input"]
}, Open  ]],
Cell[17311, 466, 9376, 194, 70, "Output",
 CellID->141444057],
Cell[CellGroupData[{
Cell[26712, 664, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[27088, 675, 1177, 32, 70, "Text"],
Cell[28268, 709, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[28608, 720, 464, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[29097, 739, 847, 24, 70, "Text"],
Cell[29947, 765, 1236, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature FSN30wOxXUx@CBD7BfW#L42w *)
