(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32148,        811]
NotebookOptionsPosition[     31063,        770]
NotebookOutlinePosition[     31671,        794]
CellTagsIndexPosition[     31628,        791]
WindowTitle->Newton's Method - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Newton's Method", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"NewtonPlot", "[", 
    RowBox[{
     RowBox[{"GetFunction", "[", "function", "]"}], ",", 
     RowBox[{"RangeToVary", "[", 
      RowBox[{
       RowBox[{"GetRange", "[", "function", "]"}], ",", "x0"}], "]"}], ",", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}]}], ",", 
     RowBox[{"GetRange", "[", "function", "]"}], ",", "zoom", ",", "20"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"function", ",", 
       RowBox[{"functionrules", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{
       RowBox[{"First", "/@", "functionrules"}], ",", 
       RowBox[{"SynchronousUpdating", "\[Rule]", "False"}]}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", "0", ",", "\"\<starting point\>\""}], "}"}], ",", 
     "0", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"zoom", ",", "0.9"}], "}"}], ",", "0.1", ",", ".9"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"function", ",", "x0", ",", "zoom"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"NewtonsMethod", "[", 
        RowBox[{"f_", ",", "x_", ",", " ", 
         RowBox[{"nz_", " ", ":", " ", 
          RowBox[{"10", "^", 
           RowBox[{"(", 
            RowBox[{"-", "10"}], ")"}]}]}]}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"f", "'"}], "[", "x", "]"}], "]"}], " ", ">", " ", "nz"}],
          " ", ",", 
         RowBox[{"N", "[", 
          RowBox[{"x", " ", "-", " ", 
           FractionBox[
            RowBox[{"f", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"f", "'"}], "[", "x", "]"}]]}], "]"}], ",", 
         "NewtonError"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ConvergenceTest", "[", 
        RowBox[{"f_", ",", "x_", ",", "tol_"}], "]"}], ":=", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", "x", "]"}], " ", ">", " ", "tol"}], " ", "&&", 
         "  ", 
         RowBox[{"x", " ", "=!=", " ", "NewtonError"}]}], ")"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FindRootNewton", "[", 
        RowBox[{"f_", ",", "x0_", ",", "tol_", ",", " ", 
         RowBox[{"maxiter_:", "100"}]}], "]"}], ":=", 
       RowBox[{"NestWhileList", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"NewtonsMethod", "[", 
           RowBox[{"f", ",", "#"}], "]"}], "&"}], ",", "x0", ",", 
         RowBox[{
          RowBox[{"ConvergenceTest", "[", 
           RowBox[{"f", ",", "#", ",", "tol"}], "]"}], "&"}], ",", "1", ",", 
         "maxiter"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pointStyle", "[", 
        RowBox[{"size_", ",", "color_", ",", "pt_"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "size", "]"}], ",", "color", ",", 
         RowBox[{"Point", "[", "pt", "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"stdopts", " ", "=", " ", 
       RowBox[{"Sequence", "[", 
        RowBox[{
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"250", ",", "150"}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"NewtonPlot", "[", 
        RowBox[{"f_", ",", "x0_", ",", "tol_", ",", 
         RowBox[{"{", 
          RowBox[{"xmin_", ",", "xmax_"}], "}"}], ",", "zoom_", ",", " ", 
         "max_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"iterates", " ", "=", " ", "\[IndentingNewLine]", 
            RowBox[{"FindRootNewton", "[", 
             RowBox[{"f", ",", "x0", ",", "tol", ",", "max"}], "]"}]}], ",", 
           "fmtpts", ",", "fmtlines", ",", "fmtarrows", ",", "ip", ",", "fp", 
           ",", "lp"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"lp", " ", "=", " ", 
           RowBox[{"Last", "[", "iterates", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"lp", " ", "=!=", " ", "NewtonError"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"fp", "  ", "=", " ", 
              RowBox[{"pointStyle", "[", 
               RowBox[{"Large", ",", "Red", ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{"f", "[", "#", "]"}]}], "}"}], "&"}], "@", " ", 
                 RowBox[{"Last", "[", "iterates", "]"}]}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ip", " ", "=", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"pointStyle", "[", 
                 RowBox[{"Large", ",", "Green", ",", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{"f", "[", "#", "]"}]}], "}"}]}], "]"}], "&"}], 
               "@", " ", 
               RowBox[{"First", "[", "iterates", "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"fmtpts", " ", "=", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"pointStyle", "[", 
                 RowBox[{"Medium", ",", "Blue", ",", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{"f", "[", "#", "]"}]}], "}"}]}], "]"}], "&"}], "/@",
                "iterates"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"fmtlines", " ", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"{", " ", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"Blue", ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"First", "[", "#", "]"}], ",", 
                    RowBox[{"f", "[", 
                    RowBox[{"First", "[", "#", "]"}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Last", "[", "#", "]"}], ",", "0"}], "}"}]}], 
                    "}"}], "]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"Orange", ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Last", "[", "#", "]"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Last", "[", "#", "]"}], ",", 
                    RowBox[{"f", "[", 
                    RowBox[{"Last", "[", "#", "]"}], "]"}]}], "}"}]}], "}"}], 
                    "]"}]}], "}"}]}], "}"}], "&"}], "/@", 
               RowBox[{"Reverse", "[", 
                RowBox[{"Partition", "[", 
                 RowBox[{"iterates", ",", "2", ",", "1"}], "]"}], "]"}]}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"Grid", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Plot", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "x", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", " ", 
                    RowBox[{"{", 
                    RowBox[{"fmtlines", ",", "fmtpts", ",", "ip", ",", "fp"}],
                     "}"}]}], ",", 
                    RowBox[{"Evaluate", "[", "stdopts", "]"}]}], "]"}], ",", 
                  RowBox[{"Plot", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "x", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"lp", " ", "-", " ", "zoom"}], ",", 
                    RowBox[{"lp", "+", "zoom"}]}], "}"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", " ", 
                    RowBox[{"{", 
                    RowBox[{"fmtlines", ",", "fmtpts", ",", "ip", ",", "fp"}],
                     "}"}]}], ",", 
                    RowBox[{"Evaluate", "[", "stdopts", "]"}]}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Plot", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "x", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"lp", " ", "-", " ", 
                    RowBox[{"zoom", "^", "2"}]}], ",", 
                    RowBox[{"lp", "+", 
                    RowBox[{"zoom", "^", "2"}]}]}], "}"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", " ", 
                    RowBox[{"{", 
                    RowBox[{"fmtlines", ",", "fmtpts", ",", "ip", ",", "fp"}],
                     "}"}]}], ",", 
                    RowBox[{"Evaluate", "[", "stdopts", "]"}]}], "]"}], ",", 
                  RowBox[{"Plot", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "x", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"lp", " ", "-", " ", 
                    RowBox[{"zoom", "^", "3"}]}], ",", 
                    RowBox[{"lp", "+", 
                    RowBox[{"zoom", "^", "3"}]}]}], "}"}], ",", 
                    RowBox[{"Epilog", "\[Rule]", " ", 
                    RowBox[{"{", 
                    RowBox[{"fmtlines", ",", "fmtpts", ",", "ip", ",", "fp"}],
                     "}"}]}], ",", 
                    RowBox[{"Evaluate", "[", "stdopts", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], " ", "]"}]}], ",", "\[IndentingNewLine]", 
            "\"\<Newton Error Divide by Zero\>\""}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"functions", " ", "=", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"3", " ", 
               RowBox[{"Cos", "[", "x", "]"}]}], " ", "+", " ", 
              RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2.5"}], "}"}], ",", "1"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"Exp", "[", "x", "]"}], " ", "-", " ", 
              RowBox[{"x", "^", "2"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "1"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"x", "^", "2"}], " ", "-", "1"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "0"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"Cos", "[", "x", "]"}], " ", "-", " ", 
              RowBox[{"x", "^", "4"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "1"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"9", " ", "x"}], "]"}], " ", "+", " ", 
              RowBox[{"5", "x"}], " ", "-", " ", "2"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "1"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"12", " ", "x"}], "]"}], " ", "-", " ", 
              RowBox[{"x", "^", "2"}], " ", "+", "3"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", "2"}], "}"}]}], 
        "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"functionrules", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ToString", "[", 
           RowBox[{
            RowBox[{"Last", "[", 
             RowBox[{"First", "[", "#", "]"}], "]"}], ",", 
            "TraditionalForm"}], "]"}], "\[Rule]", " ", "#"}], "&"}], "/@", 
        " ", "functions"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"GetFunction", "[", "str_", "]"}], ":=", 
       RowBox[{"First", "[", 
        RowBox[{"str", " ", "/.", " ", "functionrules"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"GetRange", "[", "str_", "]"}], ":=", 
       RowBox[{"Part", "[", 
        RowBox[{
         RowBox[{"str", "/.", "functionrules"}], ",", "2"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"RangeToVary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a_", ",", "b_"}], "}"}], ",", "x_"}], "]"}], ":=", 
       RowBox[{"a", " ", "+", " ", 
        RowBox[{"x", 
         RowBox[{"(", 
          RowBox[{"b", "-", "a"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
     ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35757176568782*^9, {3.361558630014*^9, 3.36155864916603*^9}, {
   3.36250082854813*^9, 3.36250087441505*^9}, {3.3625009076239*^9, 
   3.36250094291341*^9}, {3.3625017919004*^9, 3.36250179373161*^9}, {
   3.36250186006086*^9, 3.36250191512304*^9}, {3.36250197571635*^9, 
   3.36250199144458*^9}, {3.36250220900494*^9, 3.3625022178585*^9}, {
   3.36250227108514*^9, 3.36250227134329*^9}, {3.36250275130975*^9, 
   3.36250276817177*^9}, {3.362502853184*^9, 3.36250285428229*^9}, {
   3.36250307722423*^9, 3.36250312138437*^9}, {3.36250337735145*^9, 
   3.36250339308063*^9}, {3.36250651473538*^9, 3.36250651514967*^9}, {
   3.36250658290806*^9, 3.36250658406457*^9}, {3.36250663382748*^9, 
   3.36250664232191*^9}, 3.36250673198577*^9, {3.36250719936138*^9, 
   3.36250722981065*^9}, {3.36250783624725*^9, 3.36250784202189*^9}, {
   3.3625079063595*^9, 3.36250793482138*^9}, {3.36250798398681*^9, 
   3.36250800748027*^9}, {3.36250882857407*^9, 3.36250885734817*^9}, {
   3.36250891150091*^9, 3.36250891194555*^9}, {3.3625091249204*^9, 
   3.36250913214877*^9}, {3.36250933456711*^9, 3.36250937164379*^9}, {
   3.36250942109964*^9, 3.36250943534936*^9}, {3.36250952983419*^9, 
   3.36250953686203*^9}, {3.36267479056692*^9, 3.36267480503874*^9}, {
   3.36267488896281*^9, 3.36267489430124*^9}, {3.36267493904923*^9, 
   3.36267494963741*^9}, {3.36283014153787*^9, 3.36283014923897*^9}, 
   3.3628302503139*^9, {3.36578057997092*^9, 3.36578058314415*^9}, {
   3.36578064216676*^9, 3.36578066206055*^9}, {3.36578069894519*^9, 
   3.36578070016155*^9}, {3.36578077049583*^9, 3.3657807714425*^9}, {
   3.36578086453993*^9, 3.36578090589903*^9}, {3.3725348155077*^9, 
   3.3725348454609423`*^9}, {3.3853163359714193`*^9, 
   3.3853163365339193`*^9}, {3.3853166457214193`*^9, 
   3.3853166566901693`*^9}, {3.456069276826316*^9, 3.4560693259762306`*^9}, {
   3.4560693602426567`*^9, 3.4560693665582886`*^9}, {3.4560694253961716`*^9, 
   3.45606946028266*^9}, {3.4560695075343847`*^9, 3.4560695103536663`*^9}, {
   3.4560695768503156`*^9, 3.456069604061036*^9}, {3.4560699203316603`*^9, 
   3.456069932802907*^9}},
 CellID->1496021318]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`function$$ = 
    "\!\(TraditionalForm\`\(\(\(sin(x)\)\) + \(\(3\\ \(\(cos(x)\)\)\)\)\)\)", \
$CellContext`x0$$ = 0, $CellContext`zoom$$ = 0.9, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`function$$], 
       "\!\(TraditionalForm\`\(\(\(sin(x)\)\) + \(\(3\\ \
\(\(cos(x)\)\)\)\)\)\)"}, 
      Dynamic[
       Map[First, $CellContext`functionrules], SynchronousUpdating -> 
       False]}, {{
       Hold[$CellContext`x0$$], 0, "starting point"}, 0, 1}, {{
       Hold[$CellContext`zoom$$], 0.9}, 0.1, 0.9}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`x0$954209$$ = 
    0, $CellContext`zoom$954210$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`function$$ = 
        "\!\(TraditionalForm\`\(\(\(sin(x)\)\) + \(\(3\\ \(\(cos(x)\)\)\)\)\)\
\)", $CellContext`x0$$ = 0, $CellContext`zoom$$ = 0.9}, "ControllerVariables" :> {
        Hold[$CellContext`x0$$, $CellContext`x0$954209$$, 0], 
        Hold[$CellContext`zoom$$, $CellContext`zoom$954210$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> $CellContext`NewtonPlot[
        $CellContext`GetFunction[$CellContext`function$$], 
        $CellContext`RangeToVary[
         $CellContext`GetRange[$CellContext`function$$], $CellContext`x0$$], 
        10^(-2), 
        $CellContext`GetRange[$CellContext`function$$], $CellContext`zoom$$, 
        20], "Specifications" :> {{{$CellContext`function$$, 
          "\!\(TraditionalForm\`\(\(\(sin(x)\)\) + \(\(3\\ \(\(cos(x)\)\)\)\)\
\)\)"}, 
         Dynamic[
          Map[First, $CellContext`functionrules], SynchronousUpdating -> 
          False], ControlType -> 
         PopupMenu}, {{$CellContext`x0$$, 0, "starting point"}, 0, 
         1}, {{$CellContext`zoom$$, 0.9}, 0.1, 0.9}}, 
      "Options" :> {
       TrackedSymbols :> {$CellContext`function$$, $CellContext`x0$$, \
$CellContext`zoom$$}, SynchronousInitialization -> False, 
        AutorunSequencing -> {2, 3}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{302., {77., 82.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`NewtonsMethod[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`nz, 
           Blank[]], 10^(-10)]] := If[Abs[
           Derivative[1][$CellContext`f][$CellContext`x]] > $CellContext`nz, 
         N[$CellContext`x - $CellContext`f[$CellContext`x]/Derivative[
          1][$CellContext`f][$CellContext`x]], $CellContext`NewtonError]; \
$CellContext`ConvergenceTest[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`tol, 
          Blank[]]] := 
       And[Abs[$CellContext`x] > $CellContext`tol, $CellContext`x =!= \
$CellContext`NewtonError]; $CellContext`FindRootNewton[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`tol, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`maxiter, 
           Blank[]], 100]] := 
       NestWhileList[$CellContext`NewtonsMethod[$CellContext`f, #]& , \
$CellContext`x0, $CellContext`ConvergenceTest[$CellContext`f, #, \
$CellContext`tol]& , 1, $CellContext`maxiter]; $CellContext`pointStyle[
         Pattern[$CellContext`size, 
          Blank[]], 
         Pattern[$CellContext`color, 
          Blank[]], 
         Pattern[$CellContext`pt, 
          Blank[]]] := {
         PointSize[$CellContext`size], $CellContext`color, 
         Point[$CellContext`pt]}; $CellContext`stdopts = 
       Sequence[
        ImageSize -> {250, 150}, PlotStyle -> Black]; $CellContext`NewtonPlot[
        
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`tol, 
          Blank[]], {
          Pattern[$CellContext`xmin, 
           Blank[]], 
          Pattern[$CellContext`xmax, 
           Blank[]]}, 
         Pattern[$CellContext`zoom, 
          Blank[]], 
         Pattern[$CellContext`max, 
          Blank[]]] := 
       Module[{$CellContext`iterates = \
$CellContext`FindRootNewton[$CellContext`f, $CellContext`x0, \
$CellContext`tol, $CellContext`max], $CellContext`fmtpts, \
$CellContext`fmtlines, $CellContext`fmtarrows, $CellContext`ip, \
$CellContext`fp, $CellContext`lp}, $CellContext`lp = 
          Last[$CellContext`iterates]; 
         If[$CellContext`lp =!= $CellContext`NewtonError, $CellContext`fp = \
$CellContext`pointStyle[Large, Red, 
              ({#, 
               $CellContext`f[#]}& )[
               
               Last[$CellContext`iterates]]]; $CellContext`ip = \
($CellContext`pointStyle[Large, Green, {#, 
               $CellContext`f[#]}]& )[
              First[$CellContext`iterates]]; $CellContext`fmtpts = 
            Map[$CellContext`pointStyle[Medium, Blue, {#, 
                $CellContext`f[#]}]& , $CellContext`iterates]; \
$CellContext`fmtlines = Map[{{Blue, 
                Line[{{
                   First[#], 
                   $CellContext`f[
                    First[#]]}, {
                   Last[#], 0}}]}, {Orange, 
                Line[{{
                   Last[#], 0}, {
                   Last[#], 
                   $CellContext`f[
                    Last[#]]}}]}}& , 
              Reverse[
               Partition[$CellContext`iterates, 2, 1]]]; Grid[{{
               Plot[
                $CellContext`f[$CellContext`x], {$CellContext`x, \
$CellContext`xmin, $CellContext`xmax}, 
                Epilog -> {$CellContext`fmtlines, $CellContext`fmtpts, \
$CellContext`ip, $CellContext`fp}, 
                Evaluate[$CellContext`stdopts]], 
               Plot[
                $CellContext`f[$CellContext`x], {$CellContext`x, \
$CellContext`lp - $CellContext`zoom, $CellContext`lp + $CellContext`zoom}, 
                Epilog -> {$CellContext`fmtlines, $CellContext`fmtpts, \
$CellContext`ip, $CellContext`fp}, 
                Evaluate[$CellContext`stdopts]]}, {
               Plot[
                $CellContext`f[$CellContext`x], {$CellContext`x, \
$CellContext`lp - $CellContext`zoom^2, $CellContext`lp + $CellContext`zoom^2},
                 Epilog -> {$CellContext`fmtlines, $CellContext`fmtpts, \
$CellContext`ip, $CellContext`fp}, 
                Evaluate[$CellContext`stdopts]], 
               Plot[
                $CellContext`f[$CellContext`x], {$CellContext`x, \
$CellContext`lp - $CellContext`zoom^3, $CellContext`lp + $CellContext`zoom^3},
                 Epilog -> {$CellContext`fmtlines, $CellContext`fmtpts, \
$CellContext`ip, $CellContext`fp}, 
                Evaluate[$CellContext`stdopts]]}}], 
           "Newton Error Divide by Zero"]]; $CellContext`functions = {{
          
          Function[$CellContext`x, 3 Cos[$CellContext`x] + 
           Sin[$CellContext`x]], {-2, 2.5}, 1}, {
          
          Function[$CellContext`x, 
           Exp[$CellContext`x] - $CellContext`x^2], {-2, 2}, 1}, {
          Function[$CellContext`x, $CellContext`x^2 - 1], {-2, 2}, 0}, {
          
          Function[$CellContext`x, 
           Cos[$CellContext`x] - $CellContext`x^4], {-2, 2}, 1}, {
          
          Function[$CellContext`x, Cos[9 $CellContext`x] + 5 $CellContext`x - 
           2], {-2, 2}, 1}, {
          
          Function[$CellContext`x, Sin[12 $CellContext`x] - $CellContext`x^2 + 
           3], {-1, 2}, 2}}; $CellContext`functionrules = Map[ToString[
           Last[
            First[#]], 
           TraditionalForm] -> #& , $CellContext`functions]; \
$CellContext`GetFunction[
         Pattern[$CellContext`str, 
          Blank[]]] := First[
         ReplaceAll[$CellContext`str, $CellContext`functionrules]]; \
$CellContext`GetRange[
         Pattern[$CellContext`str, 
          Blank[]]] := Part[
         ReplaceAll[$CellContext`str, $CellContext`functionrules], 
         2]; $CellContext`RangeToVary[{
          Pattern[$CellContext`a, 
           Blank[]], 
          Pattern[$CellContext`b, 
           Blank[]]}, 
         Pattern[$CellContext`x, 
          
          Blank[]]] := $CellContext`a + $CellContext`x ($CellContext`b - \
$CellContext`a); Null); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->359113533],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Newton's Method",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/NewtonsMethod/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/NewtonsMethod/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/NewtonsMethod/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/NewtonsMethod/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/NewtonsMethod/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Chris Maes",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Chris+Maes"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Chris+Maes"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->1413988123],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
NewtonsMethod"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Newton's Method - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[605, 23, 207, 4, 70, "Section"],
Cell[815, 29, 16951, 396, 70, "Input",
 CellID->1496021318]
}, Open  ]],
Cell[17781, 428, 9141, 208, 70, "Output",
 CellID->359113533],
Cell[CellGroupData[{
Cell[26947, 640, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[27323, 651, 857, 24, 70, "Text"],
Cell[28183, 677, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[28523, 688, 448, 15, 70, "Text",
 CellID->1413988123],
Cell[CellGroupData[{
Cell[28996, 707, 847, 24, 70, "Text"],
Cell[29846, 733, 1189, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature dSzR8e#iUMZFYDTUw1zY7Zaz *)
