(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32572,        773]
NotebookOptionsPosition[     31406,        731]
NotebookOutlinePosition[     32050,        755]
CellTagsIndexPosition[     32007,        752]
WindowTitle->The Maximum Rectangular Area under Different Curves - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Maximum Rectangular Area under Different Curves", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", "X_", "]"}], ":=", 
   RowBox[{"4", "-", 
    RowBox[{"X", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f2", "[", "X_", "]"}], ":=", 
   RowBox[{"2", "-", 
    RowBox[{"X", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f3", "[", "X_", "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"16", "-", 
     RowBox[{"X", "^", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f4", "[", "X_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4", "-", "X"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["X", "2"]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f5", "[", "X_", "]"}], ":=", 
   RowBox[{"4", 
    RowBox[{"Cos", "[", 
     RowBox[{"X", "/", "2"}], "]"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.35696210375764*^9, {3.45960490746875*^9, 3.45960490790625*^9}, {
   3.4597890076907234`*^9, 3.4597890081637707`*^9}, {3.459791436778121*^9, 
   3.459791443699996*^9}},
 CellID->394568190],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{"func", ",", "f1", ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"X", ">", "2"}], ",", 
         RowBox[{"X", "=", "1"}]}], "]"}], ";", 
       RowBox[{"maxX", "=", "2"}]}], ",", "f2", ",", 
      RowBox[{"maxX", "=", "4"}], ",", "f3", ",", 
      RowBox[{"maxX", "=", "4"}], ",", "f4", ",", 
      RowBox[{"maxX", "=", "4"}], ",", "f5", ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"X", ">", "\[Pi]"}], ",", 
         RowBox[{"X", "=", "1"}]}], "]"}], ";", 
       RowBox[{"maxX", "=", "\[Pi]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"funcPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"func", "[", "X", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"X", ",", "0", ",", "maxX"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Black"}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], 
       RowBox[{"(*", 
        RowBox[{",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"TraditionalForm", "[", 
                RowBox[{"f", "[", "x", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
               
               RowBox[{"func", "[", "X", "]"}]}], "}"}], "]"}], ",", "18"}], 
           "]"}]}]}], "*)"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"300", ",", "300"}], "}"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"areaRect", "[", "X_", "]"}], ":=", 
     RowBox[{"X", " ", 
      RowBox[{"func", "[", "X", "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"pointOnCurve", "=", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"func", "[", "X", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"pointOnAreaCurve", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Large", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{".6", ",", ".73", ",", ".36"}], "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"X", ",", 
           RowBox[{"areaRect", "[", "X", "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"rectangle", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Blue"}], "]"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{".6", ",", ".73", ",", ".36"}], "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "pointOnCurve"}], "]"}]}], 
       "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"areaPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"areaRect", "[", "X", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"X", ",", "0", ",", "maxX"}], "}"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<area of rectangle\>\"", ",", "18"}], "]"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Text", "@", 
     RowBox[{"Pane", "[", 
      RowBox[{
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Show", "[", 
           RowBox[{"funcPlot", ",", "rectangle"}], "]"}], ",", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Show", "[", 
              RowBox[{"areaPlot", ",", "pointOnAreaCurve"}], "]"}], ",", 
             "\"\<\>\"", ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                  "\"\< = \>\"", ",", "X"}], "}"}], "]"}], ",", "24"}], "]"}],
              ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<area = \>\"", ",", 
                  RowBox[{"areaRect", "[", "X", "]"}]}], "}"}], "]"}], ",", 
               "24"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"560", ",", "300"}], "}"}]}]}], "]"}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"func", ",", "f1", ",", "\"\<f(x)\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f1", "\[Rule]", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{"4", "-", 
          SuperscriptBox["x", "2"]}], "]"}]}], ",", 
       RowBox[{"f2", "\[Rule]", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{"2", "-", 
          RowBox[{"x", "/", "2"}]}], "]"}]}], ",", 
       RowBox[{"f3", "\[Rule]", 
        RowBox[{"TraditionalForm", "[", 
         SqrtBox[
          RowBox[{"16", "-", 
           SuperscriptBox["x", "2"]}]], "]"}]}], ",", 
       RowBox[{"f4", "\[Rule]", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", "1"}], ")"}]}], "]"}]}], ",", 
       RowBox[{"f5", "\[Rule]", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{"4", 
          RowBox[{"Cos", "[", 
           RowBox[{"x", "/", "2"}], "]"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", "1"}], "}"}], ",", "0", ",", 
     RowBox[{"Dynamic", "[", "maxX", "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"maxX", ",", "2"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", "True"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.4596044108125*^9, {3.45960489865625*^9, 
   3.45960489921875*^9}, {3.459605046921875*^9, 3.459605050296875*^9}, {
   3.459788989195874*^9, 3.4597891537873316`*^9}, {3.459789200447997*^9, 
   3.4597892855075026`*^9}, {3.459790969043746*^9, 3.459790977403121*^9}, {
   3.459791064371871*^9, 3.459791132824996*^9}, {3.459791189090621*^9, 
   3.459791193340621*^9}, {3.459791234465621*^9, 3.459791373387496*^9}, {
   3.459791476793746*^9, 3.459791491137496*^9}, {3.459791545168746*^9, 
   3.459791577309371*^9}, {3.459791663168746*^9, 3.459791669528121*^9}, {
   3.4597949092836113`*^9, 3.459794917124728*^9}}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`func$$ = $CellContext`f3, \
$CellContext`maxX$$ = 4, $CellContext`X$$ = 1.864, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`func$$], $CellContext`f1, "f(x)"}, {$CellContext`f1 -> 
       TraditionalForm[4 - $CellContext`x^2], $CellContext`f2 -> 
       TraditionalForm[2 + Rational[-1, 2] $CellContext`x], $CellContext`f3 -> 
       TraditionalForm[(16 - $CellContext`x^2)^
         Rational[1, 2]], $CellContext`f4 -> 
       TraditionalForm[(4 - $CellContext`x)/(
         1 + $CellContext`x^2)], $CellContext`f5 -> 
       TraditionalForm[4 Cos[Rational[1, 2] $CellContext`x]]}}, {{
       Hold[$CellContext`X$$], 1}, 0, 
      Dynamic[$CellContext`maxX$$]}, {{
       Hold[$CellContext`maxX$$], 2}}}, Typeset`size$$ = {560., {149., 154.}},
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`func$302035$$ = False, $CellContext`X$302036$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`func$$ = $CellContext`f1, \
$CellContext`maxX$$ = 2, $CellContext`X$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`func$$, $CellContext`func$302035$$, False], 
        Hold[$CellContext`X$$, $CellContext`X$302036$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> (
       Switch[$CellContext`func$$, $CellContext`f1, 
         If[$CellContext`X$$ > 2, $CellContext`X$$ = 1]; $CellContext`maxX$$ = 
          2, $CellContext`f2, $CellContext`maxX$$ = 
         4, $CellContext`f3, $CellContext`maxX$$ = 
         4, $CellContext`f4, $CellContext`maxX$$ = 4, $CellContext`f5, 
         If[$CellContext`X$$ > Pi, $CellContext`X$$ = 1]; $CellContext`maxX$$ = 
          Pi]; $CellContext`funcPlot = Plot[
          $CellContext`func$$[$CellContext`X$$], {$CellContext`X$$, 
           0, $CellContext`maxX$$}, PlotStyle -> {
            Thickness[0.007], Black}, PlotRange -> {{0, 4}, {0, 4}}, 
          AspectRatio -> 1, ImageSize -> {300, 300}]; $CellContext`areaRect[
          Pattern[$CellContext`X$, 
           
           Blank[]]] := $CellContext`X$ $CellContext`func$$[$CellContext`X$]; \
$CellContext`pointOnCurve = {$CellContext`X$$, 
          $CellContext`func$$[$CellContext`X$$]}; \
$CellContext`pointOnAreaCurve = Graphics[{
           PointSize[Large], 
           RGBColor[0.6, 0.73, 0.36], 
           Point[{$CellContext`X$$, 
             $CellContext`areaRect[$CellContext`X$$]}]}]; \
$CellContext`rectangle = Graphics[{
           EdgeForm[
            Directive[Thick, Blue]], 
           RGBColor[0.6, 0.73, 0.36], 
           
           Rectangle[{0, 
            0}, $CellContext`pointOnCurve]}]; $CellContext`areaPlot = Plot[
          $CellContext`areaRect[$CellContext`X$$], {$CellContext`X$$, 
           0, $CellContext`maxX$$}, PlotLabel -> 
          Style["area of rectangle", 18], ImageSize -> 250]; Text[
         Pane[
          Row[{
            Show[$CellContext`funcPlot, $CellContext`rectangle], 
            Column[{
              Show[$CellContext`areaPlot, $CellContext`pointOnAreaCurve], "", 
              
              Style[
               Row[{
                 Style["x", Italic], " = ", $CellContext`X$$}], 24], 
              Style[
               Row[{"area = ", 
                 $CellContext`areaRect[$CellContext`X$$]}], 24]}]}], 
          ImageSize -> {560, 300}]]), 
      "Specifications" :> {{{$CellContext`func$$, $CellContext`f1, 
          "f(x)"}, {$CellContext`f1 -> 
          TraditionalForm[4 - $CellContext`x^2], $CellContext`f2 -> 
          TraditionalForm[
           2 + Rational[-1, 2] $CellContext`x], $CellContext`f3 -> 
          TraditionalForm[(16 - $CellContext`x^2)^
            Rational[1, 2]], $CellContext`f4 -> 
          TraditionalForm[(4 - $CellContext`x)/(
            1 + $CellContext`x^2)], $CellContext`f5 -> 
          TraditionalForm[4 Cos[Rational[1, 2] $CellContext`x]]}, ControlType -> 
         PopupMenu}, {{$CellContext`X$$, 1}, 0, 
         Dynamic[$CellContext`maxX$$]}, {{$CellContext`maxX$$, 2}, 
         ControlType -> None}}, 
      "Options" :> {AutorunSequencing -> {1, 2}, TrackedSymbols -> True}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{605., {213., 218.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(({$CellContext`f1[
          Pattern[$CellContext`X, 
           Blank[]]] := 4 - $CellContext`X^2, $CellContext`f2[
          Pattern[$CellContext`X, 
           Blank[]]] := 2 - $CellContext`X/2, $CellContext`f3[
          Pattern[$CellContext`X, 
           Blank[]]] := Sqrt[16 - $CellContext`X^2], $CellContext`f4[
          Pattern[$CellContext`X, 
           Blank[]]] := (4 - $CellContext`X)/(
         1 + $CellContext`X^2), $CellContext`f5[
          Pattern[$CellContext`X, 
           Blank[]]] := 4 Cos[$CellContext`X/2], $CellContext`funcPlot = 
        Graphics[{{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Thickness[0.007], 
             GrayLevel[0], 
             Line[CompressedData["
1:eJwV1gk01NsfAHBrppQfnld/siRboWl7kl71vS9FWSqMrTT0bFHPUl6KyMio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              "]]}}}, {
          AspectRatio -> 1, Axes -> True, AxesOrigin -> {0, 0}, 
           BaseStyle -> {CellBaseline -> Baseline}, FrameTicksStyle -> 
           Directive[FontFamily -> "Times", FontSize -> 10], 
           ImageSize -> {300, 300}, 
           LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
           PlotRange -> {{0, 4}, {0, 4}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {Automatic, Automatic}, TicksStyle -> 
           Directive[FontFamily -> "Times", FontSize -> 10]}], 
        Attributes[PlotRange] = {ReadProtected}, $CellContext`areaRect[
          Pattern[$CellContext`X$, 
           Blank[]]] := $CellContext`X$ FE`func$$744[$CellContext`X$], 
        Attributes[$CellContext`X$] = {Temporary}, 
        FE`func$$744 = $CellContext`f1, $CellContext`pointOnCurve = {1, 
         3}, $CellContext`pointOnAreaCurve = Graphics[{
           PointSize[Large], 
           RGBColor[0.6, 0.73, 0.36], 
           Point[{1, 3}]}], $CellContext`rectangle = Graphics[{
           EdgeForm[
            Directive[
             Thickness[Large], 
             RGBColor[0, 0, 1]]], 
           RGBColor[0.6, 0.73, 0.36], 
           Rectangle[{0, 0}, {1, 3}]}], 
        Attributes[Thick] = {ReadProtected}, $CellContext`areaPlot = 
        Graphics[{{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Line[CompressedData["
1:eJwd1nk8VN0fB3D7XBSFFpVkzU5KKg/fUylrsoaEyFp5spX0iDyWLIWQPFES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              "]]}}}, {
          AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0},
            BaseStyle -> {CellBaseline -> Baseline}, FrameTicksStyle -> 
           Directive[FontFamily -> "Times", FontSize -> 10], ImageSize -> 250,
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
           PlotLabel -> Style["area of rectangle", 18], 
           PlotRange -> {{0, 2}, {0., 3.0792012269475255`}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {
             Scaled[0.02], 
             Scaled[0.02]}, TicksStyle -> 
           Directive[FontFamily -> "Times", FontSize -> 10]}]}; 
      Typeset`initDone$$ = True); ReleaseHold[{{
         HoldComplete[$CellContext`f1[
             Pattern[$CellContext`X, 
              Blank[]]] := 4 - $CellContext`X^2; Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`f2[
             Pattern[$CellContext`X, 
              Blank[]]] := 2 - $CellContext`X/2; Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`f3[
             Pattern[$CellContext`X, 
              Blank[]]] := Sqrt[16 - $CellContext`X^2]; Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`f4[
             Pattern[$CellContext`X, 
              Blank[]]] := (4 - $CellContext`X)/(1 + $CellContext`X^2); Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`f5[
             Pattern[$CellContext`X, 
              Blank[]]] := 4 Cos[$CellContext`X/2]; Null]}}]; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->2131044112],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["The Maximum Rectangular Area under Different Curves",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
TheMaximumRectangularAreaUnderDifferentCurves/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
TheMaximumRectangularAreaUnderDifferentCurves/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
TheMaximumRectangularAreaUnderDifferentCurves/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
TheMaximumRectangularAreaUnderDifferentCurves/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
TheMaximumRectangularAreaUnderDifferentCurves/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Marc Brodie",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Marc+Brodie"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Marc+Brodie"],
 " (Wheeling Jesuit University)"
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
TheMaximumRectangularAreaUnderDifferentCurves"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{780, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"The Maximum Rectangular Area under Different Curves - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[641, 23, 243, 4, 70, "Section"],
Cell[887, 29, 1153, 37, 70, "Input",
 InitializationCell->True,
 CellID->394568190],
Cell[2043, 68, 7565, 197, 70, "Input"]
}, Open  ]],
Cell[9623, 268, 17380, 322, 70, "Output",
 CellID->2131044112],
Cell[CellGroupData[{
Cell[27028, 594, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[27404, 605, 1071, 31, 70, "Text"],
Cell[28478, 638, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[28818, 649, 464, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[29307, 668, 847, 24, 70, "Text"],
Cell[30157, 694, 1221, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature iQ4YtkswpFRZNCpK0EuIZlmH *)
