(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5285,        189]
NotebookOptionsPosition[      3582,        119]
NotebookOutlinePosition[      4594,        161]
CellTagsIndexPosition[      4395,        151]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ThePerfectVennDiagram", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
A Venn diagram is commonly used to depict the relationship among sets. It is \
difficult, however, to draw freehand a Venn diagram that accurately captures \
a relationship between the cardinality of the sets and their area of overlap. \
This Demonstration produces the \"perfect\" Venn diagram for two sets \
\[ScriptCapitalA] and \[ScriptCapitalB] where you set the cardinality ratio \
between the two sets and the area of overlap between them. You can choose \
whether to compute the area of overlap relative to \[ScriptCapitalA] or to \
\[ScriptCapitalB].\
\>", "Text",
 CellChangeTimes->{{3.427457256671875*^9, 3.42745733140625*^9}, {
  3.42745737709375*^9, 3.42745739734375*^9}, {3.42745742825*^9, 
  3.427457437453125*^9}}],

Cell["\<\

This demo can train your eye to visually calculate fractions of overlaped \
areas among fairly complicated shapes.\
\>", "Text",
 CellChangeTimes->{{3.4274579946875*^9, 3.427458069390625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

If set \[ScriptCapitalA] is the reference set, the slider \"relative size of \
\[ScriptCapitalB], increases the size of \[ScriptCapitalB], the slider \
\"overlap relative to set \[ScriptCapitalA] just makes a displacement of \
\[ScriptCapitalB], changing the amount of overlaping.\
\>", "Text",
 CellChangeTimes->{{3.427458094203125*^9, 3.427458327546875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

The \" overlap area computations\" field show the fractions:
Cardinality of (\[ScriptCapitalA] \[Intersection]\[ScriptCapitalB] \
)/Cardinalty (\[ScriptCapitalA])
Cardinality of (\[ScriptCapitalA] \[Intersection]\[ScriptCapitalB] \
)/Cardinalty (\[ScriptCapitalA])
Cardinality of (\[ScriptCapitalA]\[Intersection] \[ScriptCapitalB] \
)/Cardinalty (\[ScriptCapitalA] \[Union]\[ScriptCapitalB])
The Cardinality of a set definition goes beyond the purpose of this book. for \
this demo we use the area of the set for calculating it.\
\>", "Text",
 CellChangeTimes->{{3.427458559296875*^9, 3.427458588671875*^9}, {
  3.4274586344375*^9, 3.427458782015625*^9}, {3.427459580171875*^9, 
  3.427459718421875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Cardinality of a set, intersections of sets, empty set, area fraction.\
\>", "Text",
 CellChangeTimes->{{3.427457807890625*^9, 3.427457871375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nLink to ",
 ButtonBox["Theory",
  BaseStyle->"Hyperlink",
  ButtonData->{"CantorSet-text.nb", "theory"}]
}], "Text",
 CellChangeTimes->{{3.427459735875*^9, 3.427459779765625*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 274}, {26, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[653, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1701, 54, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[2174, 69, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2989, 91, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3247, 103, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[3510, 115, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 3899, 130},
 {"operation", 3977, 133},
 {"briefexp", 4059, 136},
 {"concepts", 4140, 139},
 {"theory", 4219, 142},
 {"aplications", 4302, 145}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 38, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[653, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[718, 30, 740, 12, 101, "Text"],
Cell[1461, 44, 203, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1701, 54, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1766, 57, 371, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2174, 69, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[2236, 72, 716, 14, 137, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2989, 91, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[3052, 94, 158, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3247, 103, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3296, 106, 199, 6, 47, "Text"]
}, Open  ]],
Cell[3510, 115, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
