(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5373,        192]
NotebookOptionsPosition[      3710,        123]
NotebookOutlinePosition[      4720,        165]
CellTagsIndexPosition[      4521,        155]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["RationalNumberExplorer", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

Rational numbers (\"fractions\") are often more difficult to understand than \
decimal numbers. Use this explorer to get a feeling for them.
\
\>", "Text",
 CellChangeTimes->{{3.427466620359375*^9, 3.427466622171875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The \"left endpoint\" and \"right endpoint\" fix the interval in which we \
want to put the desired number of points with the \"number of points\" \
slider. The \"mode buttons\" let us chose spaced points, simple fractions \
numbers, and random.\
\>", "Text",
 CellChangeTimes->{{3.4274666385625*^9, 3.4274668216875*^9}, {
  3.427467011703125*^9, 3.42746714984375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

For n the number of  points, the spaced mode makes a partition of the selecte \
interval into n subintervals, half the size of this subinterval is left to \
the left of the lowest of the n points and half to the right  of the biggest \
of the n points.
In the simple fraction mode the n points are chosen as fraction with a \
dennominator of 2n.\
\>", "Text",
 CellChangeTimes->{
  3.4274671605625*^9, {3.42746723284375*^9, 3.427467336140625*^9}, {
   3.427467402046875*^9, 3.42746760084375*^9}, {3.42746764365625*^9, 
   3.427467834109375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Contable sets, infinite sets, rational number,\
\>", "Text",
 CellChangeTimes->{3.427471194671875*^9, 3.427471245875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\

A rational number can be expresed as a fraction p/q, p,q integer numbers, q\
\[NotEqual]0. 
The author of this demonstrations points that here are a number of Tricky \
Questions to think about! 
How many rational numbers are there between 0 and 1? 
What is the smallest rational number which is larger than 0? 
How close together can rational numbers get? 
Can you always find a rational number between any two decimal numbers?.
It is always possible to find another rational number between any two members \
of the set of rationals. Therefore, rather counterintuitively, the rational \
numbers are a continuous set, but at the same time can be enumerated. It is \
an  infinite set.
Examples of rational numbers include -7, 0, 1, 1/2, 22/7, 12345/67, and so \
on. Farey sequences provide a way of systematically enumerating all rational \
numbers.

\
\>", "Text",
 CellChangeTimes->{{3.427471262546875*^9, 3.427471367453125*^9}, {
  3.4274714545*^9, 3.42747151609375*^9}, {3.427471548453125*^9, 
  3.427471549171875*^9}, {3.42747176646875*^9, 3.427471768984375*^9}, {
  3.427471806640625*^9, 3.427471895140625*^9}, {3.427471953953125*^9, 
  3.42747202865625*^9}, {3.427472080125*^9, 3.427472105828125*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 401}, {77, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[654, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[3638, 119, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1470, 57, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2125, 77, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[988, 41, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2357, 89, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4027, 134},
 {"aplications", 4107, 137},
 {"briefexp", 4192, 140},
 {"concepts", 4273, 143},
 {"operation", 4355, 146},
 {"theory", 4434, 149}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 39, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[654, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[719, 30, 232, 6, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[988, 41, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1053, 44, 380, 8, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1470, 57, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1532, 60, 556, 12, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2125, 77, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2188, 80, 132, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2357, 89, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2406, 92, 1217, 24, 263, "Text"]
}, Open  ]],
Cell[3638, 119, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
