(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6022,        228]
NotebookOptionsPosition[      4352,        159]
NotebookOutlinePosition[      5365,        201]
CellTagsIndexPosition[      5166,        191]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["SeriesStepsOnANumberLine", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

Sequences of real numbers can be generated in several ways.This sequences may \
or may not have a limit. In this demonstration four sequences are generated, \
three with limit or convergent and one without it or divergent. The sequences \
are generated by using  the \"partial sums\" mechanism.  \
\>", "Text",
 CellChangeTimes->{{3.427454246125*^9, 3.42745425565625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\
Explore the sample series that illustrate convergence and divergence. 
 Select various options to better see the steps. 
  Adding up an infinite number of numbers does not always equal infinity. 
  Notice that in each case the steps get smaller, a necessary condition for \
convergence. 
  However, one of these example series diverges. (Which one?) Having smaller \
steps is not a sufficient condition for convergence. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[TextData[{
 "Given a sequence of real numbers, for example ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    RowBox[{"{", 
     SuperscriptBox["2", 
      RowBox[{"-", "n"}]], "}"}], "1", "\[Infinity]"], TraditionalForm]], 
  "Subtitle",
  FontSize->8],
 StyleBox["\t",
  FontSize->8],
 " , we can form another sequence out of it, the so called sequence of \
partial sums, given by: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]], "Subtitle",
  FontSize->8],
 StyleBox[" =",
  FontSize->8],
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "k"], TraditionalForm]], "Subtitle",
  FontSize->8],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"-", "n"}]], TraditionalForm]], "Subtitle",
  FontSize->8],
 "  , That is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]],
  FontSize->10],
 "=1/2+1/4+1/8+...+1/ ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SuperscriptBox["2", "k"],
     FontSize->9], " "}], TraditionalForm]], "Subtitle"],
 "This is the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]], "Subtitle",
  FontSize->10],
 " term of the new sequence ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubsuperscriptBox[
     RowBox[{"{", 
      SubscriptBox["S", "k"], "}"}], "1", "\[Infinity]"],
    FontSize->10], TraditionalForm]], "Subtitle"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\
Sequence, limit, partial sum, steps, convergent, size of steps.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "A sequence is an ordered set of mathematical objects. Sequences of object \
are most commonly denoted using braces. For example, the symbol ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubsuperscriptBox[
     RowBox[{"{", 
      RowBox[{"2", " ", "n"}], "}"}], "1", "\[Infinity]"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "\t denotes the infinite sequence of even numbers {2,4,...,2n,...}. For each \
n, the number 2n is called the n'th term of the sequence.\nSequences of \
numbers are said to have limit if for suficiently large n, the n'th term of \
the sequence approach a number L. Formal criteria for establishing if \
sequences have or do not have limit and which number is it if it exist can be \
found in the literature. ",
 StyleBox["Link to bibliographi",
  FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 116}, {54, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[656, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1141, 42, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1687, 58, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[3198, 121, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3385, 131, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[4280, 155, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4669, 170},
 {"operation", 4747, 173},
 {"briefexp", 4829, 176},
 {"concepts", 4910, 179},
 {"theory", 4990, 182},
 {"aplications", 5073, 185}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 41, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[656, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[721, 30, 383, 7, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1141, 42, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1206, 45, 444, 8, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1687, 58, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1749, 61, 1412, 55, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3198, 121, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[3261, 124, 87, 2, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3385, 131, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3434, 134, 831, 18, 121, "Text"]
}, Open  ]],
Cell[4280, 155, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
