(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5404,        205]
NotebookOptionsPosition[      3671,        133]
NotebookOutlinePosition[      4682,        175]
CellTagsIndexPosition[      4483,        165]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["PolarCoordinates", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
Points in two-dimensional space are commonly specified using either \
rectilinear (x- and -y) coordinates or polar (radial and angular) \
coordinates. \
\>", "Text",
 CellChangeTimes->{{3.427557434390625*^9, 3.4275574599375*^9}, 
   3.4275574921875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\
Use the locator to see how these coordinates change as a point moves in the \
plane.
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
The demo shows two different coordinate system x-y, superimposed into the \
polar coodinates system (r,\[Theta]) a single point can be refered either to \
the x-y or to the r-\[Theta] sytem. Both systems share the same origen in \
this example tough can be different for each one.\
\>", "Text",
 CellChangeTimes->{{3.42755760503125*^9, 3.427557698703125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\
Coordinate systems, base vectors, linear transformations, polar coordinates\
\>", "Text",
 CellChangeTimes->{{3.427557746140625*^9, 3.427557753796875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nThe polar coordinates r (the radial coordinate) and theta (the angular \
coordinate, often called the polar angle) are defined in terms of Cartesian \
coordinates by\nx=r Cos(\[Theta]),\ny=r Sin(\[Theta])\nwhere r is the radial \
distance from the origin, and theta is the counterclockwise angle from the \
x-axis.\n In terms of x and y,\n \n\n \n r= ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    SuperscriptBox["x", "2"]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->9],
 StyleBox["+",
  FontSize->9],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->9],
 StyleBox[" ",
  FontSize->9],
 ".\n \n \[Theta]=",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["Tan", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "(y/x)\n"
}], "Text",
 CellChangeTimes->{
  3.427557550078125*^9, 3.427558832171875*^9, {3.4275588885625*^9, 
   3.427559303859375*^9}, 3.4275593358125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aplications", "Section",
 CellTags->"aplications"],

Cell["\<\
Depending upon the geometry of the objects of study, some times is more \
convenient to use a coordinate system which is not orthogonal, but one whose  \
 intrinsic geometry reflects better  the physical or geometric object been \
studied (non orthogonal corners or wedges par example). then normally the \
equations asociated to the modeling of the system come out to be simpler.\
\>", "Text",
 CellChangeTimes->{{3.42755781771875*^9, 3.4275578531875*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 327}, {Automatic, 13}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[648, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1013, 41, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1224, 53, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1692, 67, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[1957, 78, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[3117, 119, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 3988, 144},
 {"operation", 4066, 147},
 {"briefexp", 4148, 150},
 {"concepts", 4229, 153},
 {"theory", 4308, 156},
 {"aplications", 4390, 159}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 33, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[648, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[713, 30, 263, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1013, 41, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1078, 44, 109, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1224, 53, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1286, 56, 369, 6, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1692, 67, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[1755, 70, 165, 3, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1957, 78, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2006, 81, 1074, 33, 269, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3117, 119, 56, 1, 71, "Section",
 CellTags->"aplications"],
Cell[3176, 122, 467, 7, 83, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
