(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8678,        291]
NotebookOptionsPosition[      6720,        213]
NotebookOutlinePosition[      7729,        255]
CellTagsIndexPosition[      7530,        245]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Combining Functions", "Title",
 CellChangeTimes->{3.427564183765625*^9}],

Cell[" ", "Text",
 CellChangeTimes->{3.42756673234375*^9}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
Functions can be combined through addition, subtraction, and other operations \
in the same ways that numbers can. They can also be combined by composition, \
as shown by the last two choices in the combination setter. Arithmetic \
combinations of a periodic and a non-periodic function are not periodic, but \
compositions might be periodic, like Cos(x).
\
\>", "Text",
 CellChangeTimes->{{3.427564164203125*^9, 3.42756417540625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Choose the desired  functions  with the buttons in f(x) and g(x), then with \
the combination button select the operation between the functions f and g you \
want to do. In each combination try to get used to the result of the desired \
operation in such a way that latter on you are able to sketch a result of a \
proposed operation without actually calculating it, or to be able to say if a \
given function can be writen as an operations of certain functions.\
\>", "Text",
 CellChangeTimes->{{3.42756430428125*^9, 3.427564321*^9}, {3.4275643515*^9, 
  3.427564370234375*^9}, {3.427564414578125*^9, 3.42756448178125*^9}, {
  3.42756484084375*^9, 3.4275650145*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

Even though the number of example functions given is not big, this functions \
are fairly representative in their behavior, and operating with them is \
enough to understand the general behavior of operations among functions. 
The arithmetic of functions open the treatment of function within wider \
concepts, for example Fields of functions. and can be then systematically \
studied in subjets as functional analysis.
\
\>", "Text",
 CellChangeTimes->{{3.427564661125*^9, 3.427564676984375*^9}, {
  3.427564720234375*^9, 3.42756480259375*^9}, {3.42756504171875*^9, 
  3.427565105515625*^9}, {3.427565137921875*^9, 3.427565379578125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Functions, sum, substraction, multiplication and division of functions, \
function composition\
\>", "Text",
 CellChangeTimes->{{3.427564500734375*^9, 3.4275646040625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nGiven two functions f and g with domains and ranges of f and g  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,  ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox["  respectively.\n",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.42756729946875*^9, 3.427567463484375*^9}, {
   3.427567495484375*^9, 3.427567631*^9}, 3.427569479359375*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Sum of the functions f and g is defined as (f+g)(x)=f(x)+g(x).", 
  "Item",
  FontSize->14],
 StyleBox[" ", "Item"]
}], "Item",
 CellChangeTimes->{{3.427567693265625*^9, 3.427567693265625*^9}}],

Cell[TextData[{
 StyleBox["Substraction ", "Item"],
 StyleBox["of the functions f and g is defined as (f-g)(x)=f(x)-g(x)", "Item",
  
  FontSize->14]
}], "Item",
 CellChangeTimes->{{3.427567699953125*^9, 3.42756774*^9}}],

Cell[TextData[StyleBox["Multiplication of the functions f and g is defined as \
(f g)(x)=f(x)g(x)", "Item",
 FontSize->14]], "Item",
 CellChangeTimes->{{3.42756774890625*^9, 3.427567787078125*^9}}],

Cell[TextData[{
 StyleBox["Division of the functions f and g is defined as \
(f/g)(x)=f(x)/g(x), with g(x)", "Item",
  FontSize->14],
 "\[NotEqual]",
 StyleBox["0.", "Item",
  FontSize->14]
}], "Item",
 CellChangeTimes->{{3.427567791125*^9, 3.42756784321875*^9}}]
}, Open  ]],

Cell[TextData[{
 "In each case the domain of the new functions: sum, substraction, \
multiplication and division is given by the intersection of the domains of \
each function. In the division x\[Element]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 " such that ",
 StyleBox["g(x)", "Item",
  FontSize->14],
 "\[NotEqual]",
 StyleBox["0 have to be discarded too", "Item",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.42756785940625*^9, 3.42756800496875*^9}, {
   3.42756804315625*^9, 3.427568082421875*^9}, 3.427568374375*^9}],

Cell[TextData[{
 "The nesting of two or more functions to form a single new function is known \
as composition. The composition of two functions f and g is denoted f \
\[Degree]g, where f is a function whose domain includes the range of g. The \
notation\n(f \[Degree]g)(x)=f(g(x)), \t\nis sometimes used to explicitly \
indicate the variable. \nIn order  for  composition rule to make sense, it \
has to be that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\[SubsetEqual]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\nComposition is associative, so that \nf\[Degree] (g \[Degree]h ) =(f \
\[Degree]g )\[Degree]h\nWeinstain, Eric W, Function from Mathworld"
}], "Text",
 CellChangeTimes->{{3.4275657611875*^9, 3.427565802796875*^9}, {
  3.427565854*^9, 3.42756595228125*^9}, {3.4275667096875*^9, 
  3.427566709703125*^9}, {3.427568167125*^9, 3.427568180109375*^9}, {
  3.427568226296875*^9, 3.427568335609375*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 47}, {Automatic, 5}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[754, 31, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1301, 47, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[2081, 66, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2830, 86, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3113, 99, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[6648, 209, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 7035, 224},
 {"operation", 7113, 227},
 {"briefexp", 7195, 230},
 {"concepts", 7276, 233},
 {"theory", 7355, 236},
 {"aplications", 7437, 239}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 78, 1, 83, "Title"],
Cell[671, 26, 58, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[754, 31, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[819, 34, 445, 8, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1301, 47, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1366, 50, 678, 11, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2081, 66, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[2143, 69, 650, 12, 137, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2830, 86, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2893, 89, 183, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3113, 99, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3162, 102, 845, 28, 70, "Text"],
Cell[CellGroupData[{
Cell[4032, 134, 220, 6, 30, "Item"],
Cell[4255, 142, 220, 6, 30, "Item"],
Cell[4478, 150, 197, 3, 30, "Item"],
Cell[4678, 155, 263, 8, 30, "Item"]
}, Open  ]],
Cell[4956, 166, 606, 16, 70, "Text"],
Cell[5565, 184, 1068, 22, 177, "Text"]
}, Open  ]],
Cell[6648, 209, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
