(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5657,        211]
NotebookOptionsPosition[      3991,        142]
NotebookOutlinePosition[      5003,        184]
CellTagsIndexPosition[      4804,        174]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Composition Of Functions", "Title",
 CellChangeTimes->{{3.42756871571875*^9, 3.42756871815625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

Construct f(g(x)) by starting at a point on the axis and moving vertically to \
the graph of g(x). Move horizontally to the graph of y=xto relocateg(x)  to \
an x value. Next evaluate there by moving vertically to the graph of f(x). \
Finally move horizontally to the point (x,f(g(x)).
\
\>", "Text",
 CellChangeTimes->{
  3.427568659953125*^9, {3.427568706515625*^9, 3.4275688495*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Moving the slider \"x value\" moves the point (x,f(g(x)) over the graph of f\
\[Degree]g thickening the trace of it.\
\>", "Text",
 CellChangeTimes->{{3.42756898696875*^9, 3.42756910875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

This construction  follows the \"path\":  (x.0)\[RightArrow](x,g(x)\
\[RightArrow](g(x),g(x)))\[RightArrow](g(x),f(g(x))\[RightArrow](x,(g(x),g(x))\
)\
\>", "Text",
 CellChangeTimes->{{3.427569124765625*^9, 3.42756929640625*^9}, {
  3.42756933346875*^9, 3.42756934440625*^9}, {3.4275696428125*^9, 
  3.427569665296875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Functions, composition of functions, domain and range of functions, the graph \
of a function.\
\>", "Text",
 CellChangeTimes->{{3.427569361234375*^9, 3.42756939121875*^9}, {
  3.427569583*^9, 3.4275696179375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "Given two functions f and g with domains and ranges of f and g  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,  ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox[" ,",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 StyleBox["  respectively.\n",
  FontSize->14],
 "The nesting of two or more functions to form a single new function is known \
as composition. The composition of two functions f and g is denoted f \
\[Degree]g, where f is a function whose domain includes the range of g. The \
notation\n(f \[Degree]g)(x)=f(g(x)), \t\nis sometimes used to explicitly \
indicate the variable. \nIn order  for  composition rule to make sense, it \
has to be that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\[SubsetEqual]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\nComposition is associative, so that \nf\[Degree] (g \[Degree]h ) =(f \
\[Degree]g )\[Degree]h\nWeinstain, Eric W, Function from Mathworld"
}], "Text",
 CellChangeTimes->{{3.42756953428125*^9, 3.427569537609375*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{512, Automatic}, {Automatic, -15}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[720, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1219, 45, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1523, 58, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1956, 74, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[2281, 88, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[3919, 138, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4309, 153},
 {"operation", 4387, 156},
 {"briefexp", 4469, 159},
 {"concepts", 4550, 162},
 {"theory", 4629, 165},
 {"aplications", 4711, 168}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 105, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[720, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[785, 31, 397, 9, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1219, 45, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1284, 48, 202, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1523, 58, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1585, 61, 334, 8, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1956, 74, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2019, 77, 225, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2281, 88, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2330, 91, 1574, 44, 218, "Text"]
}, Open  ]],
Cell[3919, 138, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
