(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6593,        235]
NotebookOptionsPosition[      4891,        165]
NotebookOutlinePosition[      5902,        207]
CellTagsIndexPosition[      5703,        197]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ElementaryTranscendentalFunctionsAndTheirInverses", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

Toggle which functions are plotted together. The functions ln and exp are \
inverses of each other. The inverses of the trigonometric and hyperbolic \
functions are the arc functions
\
\>", "Text",
 CellChangeTimes->{{3.4276107313125*^9, 3.427610734484375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Try to have just one function and its inverse for each group: trigonometric, \
hyperbolic and exponential, each time.\
\>", "Text",
 CellChangeTimes->{{3.427610870515625*^9, 3.427610917234375*^9}, {
  3.42761095815625*^9, 3.4276110134375*^9}, {3.427614201046875*^9, 
  3.427614252765625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

Since a neccesary condition for the existence of the inverse is that the \
function has to be one to one, it is necessary to shorten the domain of the \
original function to comply with this requirement.
In all the examples you can see in this demo, you will have tha the graph of \
the inverse function in the proper domain, it is a reflection of the original \
function in the x=y line.\
\>", "Text",
 CellChangeTimes->{{3.42761101865625*^9, 3.427611335765625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, one to one functions, domain of a function, inverse function, graph \
of a function.\
\>", "Text",
 CellChangeTimes->{{3.42761134775*^9, 3.427611418375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nLet f be a function  defined on a set A and taking values in a set B. \
Then f is said to be an injection if, whenever f(x)=f(y), it must be the case \
that x=y. Equivalently, x!=y implies f(x)!=f(y). In other words, f is an \
injection if it maps  distinct objects to distinct objects. An injection is \
sometimes also called one-to-one.\nGiven a function f(x), its inverse ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "(x) is defined by\nf(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "(x))=",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ")(f(x))=x. \t\n\nTherefore, f(x) and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "(x) are reflections about the line y=x. \n\n",
 ButtonBox["more from ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/InverseFunction.html"], None}],
 StyleBox[ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/InverseFunction.html"], None}],
  FontSlant->"Italic"],
 ButtonBox[". ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/InverseFunction.html"], None}]
}], "Text",
 CellChangeTimes->{
  3.42761142853125*^9, 3.42761172603125*^9, 3.427611783*^9, {
   3.42761203503125*^9, 3.42761208490625*^9}, {3.42761213859375*^9, 
   3.4276122115625*^9}, {3.4276122629375*^9, 3.4276123133125*^9}, 
   3.427612481078125*^9, {3.427612574734375*^9, 3.4276125983125*^9}, {
   3.4276126395625*^9, 3.427612659*^9}, {3.42761292375*^9, 
   3.427612929078125*^9}, {3.4276130961875*^9, 3.4276131019375*^9}, {
   3.42761321575*^9, 3.42761321575*^9}, {3.4276134465625*^9, 
   3.4276134535*^9}, {3.4276135181875*^9, 3.427613524046875*^9}, {
   3.42761356859375*^9, 3.42761358378125*^9}, {3.428233131375*^9, 
   3.42823314615625*^9}}],

Cell[TextData[{
 "\nSee ",
 ButtonBox["also",
  BaseStyle->"Hyperlink",
  ButtonData->{"InjectiveSurjectiveBijective-text.nb", "theory"}],
 " "
}], "Text",
 CellChangeTimes->{{3.428233157953125*^9, 3.4282331673125*^9}, {
  3.428233245875*^9, 3.428233245875*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 210}, {45, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[681, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1055, 42, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1460, 57, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2037, 74, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[2315, 87, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[4819, 161, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 5208, 176},
 {"operation", 5286, 179},
 {"briefexp", 5368, 182},
 {"concepts", 5449, 185},
 {"theory", 5528, 188},
 {"aplications", 5610, 191}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 66, 0, 137, "Title"],
Cell[CellGroupData[{
Cell[681, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[746, 30, 272, 7, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1055, 42, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1120, 45, 303, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1460, 57, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1522, 60, 478, 9, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2037, 74, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2100, 77, 178, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2315, 87, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2364, 90, 2175, 58, 215, "Text"],
Cell[4542, 150, 262, 8, 47, "Text"]
}, Open  ]],
Cell[4819, 161, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
