(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8169,        260]
NotebookOptionsPosition[      6559,        194]
NotebookOutlinePosition[      7573,        236]
CellTagsIndexPosition[      7374,        226]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Finding An  Inverse", "Title",
 CellChangeTimes->{{3.427641284859375*^9, 3.427641304796875*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "\nPolynomials that are strictly increasing or strictly decreasing have \
inverse functions. For example, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["x", "3"],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["x", "5"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " +x +1 are strictly increasing. However, neither ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["x", "2"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " nor ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "3"], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->10],
 StyleBox[" ",
  FontSize->10],
 "-x are one-to-one, and so they do not have an inverse defined for all real \
x . \nA polynomial is one-to-one on its intervals of increase and decrease. A \
restriction of the polynomial is a new function, with one of those intervals \
as its domain, whose values agree with the values of the polynomial on that \
interval. Those functions are one-to-one on those intervals and have \
inverses. For example, the function defined for x\[GreaterSlantEqual]o  with \
values ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["x", "2"],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " has the inverse function -",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox["x"],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " . The function defined for x\[LessSlantEqual]0 with values ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SuperscriptBox["x", "2"],
     FontSize->10], " "}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "has the inverse function -",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox["x"],
    FontSize->7], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->48],
 " . \nThe graphs of a function and its inverse are symmetric in the line y=x \
. \nThis Demonstration plots the graphs of each restricted function (solid \
curve) and its inverse (dashed curve) in matching colors. \n"
}], "Text",
 CellChangeTimes->{{3.42762063803125*^9, 3.427620676921875*^9}, {
   3.427620719703125*^9, 3.4276207239375*^9}, {3.427620755078125*^9, 
   3.42762078371875*^9}, {3.42762081753125*^9, 3.427620855703125*^9}, {
   3.427621360875*^9, 3.427621436578125*^9}, {3.427621501078125*^9, 
   3.427621527625*^9}, 3.42762159075*^9, {3.4276216238125*^9, 
   3.42762174765625*^9}, {3.427621802828125*^9, 3.42762180746875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The \"locators\" can be dragged to get any smooth graph (continuos curve), . \
The inverse function graph is pictured as red dotted curve.   \
\>", "Text",
 CellChangeTimes->{{3.42762888546875*^9, 3.427628926109375*^9}, {
   3.4276290085*^9, 3.4276291155*^9}, {3.427629213015625*^9, 
   3.42762923646875*^9}, {3.427629353828125*^9, 3.42762941115625*^9}, {
   3.42762945709375*^9, 3.42762956490625*^9}, 3.427629599125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
For each particulatr choice of the locators position, internally the program \
uses splines to draw the graph of the function, and by using the symetry \
along the x=y line, builds the inverse of this function.
Since not for every choice of the locators position we have a one to one \
function, it paints in red the restricted part of  the curve with this \
property and shows the red dotted curve as the graph of the inverse of this \
restricted function.\
\>", "Text",
 CellChangeTimes->{{3.42762960196875*^9, 3.427629605546875*^9}, {
   3.427629639109375*^9, 3.42763009384375*^9}, 3.42763016371875*^9}]
}, Open  ]],

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "The nesting of two or more functions to form a single new function is known \
as composition. The composition of two functions f and g is denoted f \
\[Degree]g, where f is a function whose domain includes the range of g. The \
notation\n(f \[Degree]g)(x)=f(g(x)), \t\nis sometimes used to explicitly \
indicate the variable. \nIn order  for  composition rule to make sense, it \
has to be that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\[SubsetEqual]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\nComposition is associative, so that \nf\[Degree] (g \[Degree]h ) =(f \
\[Degree]g )\[Degree]h\nIf the function f is one to one, then, if there is a \
funtion g  with domain the range of, such that  f\[SmallCircle]g=g\
\[SmallCircle]f=I, where I is the identity function, ie. a function such that \
I(x)=x.. Then  g is said to be the  inverse of  f. very often in the \
literature g is termed as ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " \nWeinstain, Eric W, Function from Mathworld"
}], "Text",
 CellChangeTimes->{{3.428335659078125*^9, 3.4283356595625*^9}, {
  3.428335705125*^9, 3.4283358983125*^9}, {3.42833592890625*^9, 
  3.428335995328125*^9}, {3.428336589765625*^9, 3.428336757390625*^9}, {
  3.428337442203125*^9, 3.428337469*^9}, {3.428337632703125*^9, 
  3.428337679375*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{614, 685},
WindowMargins->{{Automatic, 274}, {0, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[717, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[6487, 190, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[4049, 128, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[4742, 144, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[3515, 112, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[4827, 149, 46, 1, 41, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6875, 205},
 {"aplications", 6955, 208},
 {"briefexp", 7040, 211},
 {"concepts", 7122, 214},
 {"operation", 7205, 217},
 {"theory", 7286, 220}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 102, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[717, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[782, 31, 2696, 76, 259, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3515, 112, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[3580, 115, 432, 8, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4049, 128, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[4111, 131, 616, 10, 101, "Text"]
}, Open  ]],
Cell[4742, 144, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[CellGroupData[{
Cell[4827, 149, 46, 1, 41, "Section",
 CellTags->"theory"],
Cell[4876, 152, 1596, 35, 231, "Text"]
}, Open  ]],
Cell[6487, 190, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
