(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5545,        164]
NotebookOptionsPosition[      4156,        107]
NotebookOutlinePosition[      5166,        149]
CellTagsIndexPosition[      4967,        139]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Horizontal And Vertical Line Tests", "Title",
 CellChangeTimes->{{3.4276492491875*^9, 3.42764925565625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "\nA relation is a set of ordered pairs(d,r) . For example, the set of \
points at distance 1 from the origin\[LongDash]the unit circle\[LongDash]is a \
relation. The domain \[ScriptCapitalD] is the set of first values d . The \
range \[ScriptCapitalR] is the set of last values r . \nWhen every element in \
the domain corresponds to exactly one element in the range, the relation is a \
function. A function passes the vertical line test\[LongDash]no vertical line \
passes through more than one point within the relation. The unit circle is \
thus not a function. The half-circle above the axis is the function f(x)=",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["x", "2"]}]],
    FontSize->9], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " . \nThe horizontal line test, which tests if any horizontal line \
intersects a graph at more than one point, can have three different results \
when applied to functions: \n1. If no horizontal line intersects the function \
in more than one point, it is one-to-one (or injective). \n2. If every \
horizontal line intersects the function in at least one point, it is onto (or \
surjective). \n3. If every horizontal line intersects the function in exactly \
one point, it is one-to-one and onto (or bijective). \nSuppose is a function \
with domain\[ScriptCapitalD] and range \[ScriptCapitalR]. The inverse of  f \
is a function ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " with domain \[ScriptCapitalR] and range \[ScriptCapitalD] such that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " (y) =x iif and only if y=f(x). For the inverse to exist, the original \
function f must be one-to-one and onto. \nLet \[DoubleStruckCapitalR] be the \
set of real numbers. The inverse of f(x)=2 x with domain and range \
\[DoubleStruckCapitalR] is the function g(x)=1/2(x-1) with the same domain \
and range. \nMany functions that come up in practice are either not \
one-to-one or not onto. For example, because trigonometric functions are \
periodic they are many-to-one on \[DoubleStruckCapitalR] . Also, except for \
the tangent and arctangent functions, the trig functions are not onto. For \
example, there is no real number x such that sin(x)=2.\n"
}], "Text",
 CellChangeTimes->{{3.427649226375*^9, 3.42764923240625*^9}, {
  3.427649299703125*^9, 3.427649302921875*^9}, {3.427649335265625*^9, 
  3.427649378203125*^9}, {3.4276494395*^9, 3.427649446171875*^9}, {
  3.42764948121875*^9, 3.4276495284375*^9}, {3.427649573546875*^9, 
  3.427649583625*^9}, {3.42764961534375*^9, 3.42764963071875*^9}, {
  3.427649663421875*^9, 3.427649798609375*^9}, {3.427649863234375*^9, 
  3.42764993475*^9}, {3.427649965703125*^9, 3.427650049640625*^9}}]
}, Open  ]],

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{24, Automatic}, {Automatic, 7}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[729, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[4084, 103, 56, 1, 41, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[3910, 94, 59, 1, 41, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[3972, 97, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[3845, 91, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[4035, 100, 46, 1, 41, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4471, 118},
 {"aplications", 4551, 121},
 {"briefexp", 4636, 124},
 {"concepts", 4717, 127},
 {"operation", 4799, 130},
 {"theory", 4879, 133}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 114, 1, 137, "Title"],
Cell[CellGroupData[{
Cell[729, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[794, 31, 3036, 57, 449, "Text"]
}, Open  ]],
Cell[3845, 91, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[3910, 94, 59, 1, 41, "Section",
 CellTags->"briefexp"],
Cell[3972, 97, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[4035, 100, 46, 1, 41, "Section",
 CellTags->"theory"],
Cell[4084, 103, 56, 1, 41, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
