(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8857,        251]
NotebookOptionsPosition[      7107,        180]
NotebookOutlinePosition[      8120,        222]
CellTagsIndexPosition[      7921,        212]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Injective Surjective Bijective", "Title",
 CellChangeTimes->{{3.42756672421875*^9, 3.427566726359375*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellChangeTimes->{{3.4282277068125*^9, 3.42822771390625*^9}},
 CellTags->"about"],

Cell["\<\
In the function mappingx\[RightArrow] f(x) , the domain is all x values and \
the range is all f(x) values. 
If f(a) =f(b) implies a=b  , the function is called injective, or one-to-one. \

If for any y in the range there is an x  in the domain so that f(x)=y  , the \
function is called surjective, or onto. 
If both conditions are met, the function is called bijective, or one-to-one \
and onto.
\
\>", "Text",
 CellChangeTimes->{{3.428227632203125*^9, 3.4282277883125*^9}, {
  3.4282278325*^9, 3.428227875265625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

With the sliders \"domain size\" and \" range size \", fix the number of \
elements (points) of the domain and range. Choose first an small number of \
elemets in both sets to avoid clogging of the picture.
The \"random seed\" randomly generates functions. Pay attention to the \
relative sizes of both: the domain and range size\
\>", "Text",
 CellChangeTimes->{{3.428228303734375*^9, 3.42822849015625*^9}, {
  3.4282285255625*^9, 3.428228535640625*^9}, {3.42822856734375*^9, 
  3.428228686765625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[TextData[{
 "\nSince the choosen combinations are functions and all the points in the \
domain are associated with a given point of the counterdomain. If the domain \
size is bigger then the counterdomain size, you always have a surjection, if \
it is smaller an inyection and when they are equal a biyection.\nIt is worth \
noticing that some authors do distinguish the terms \"range or image\" and \
\"counterdomain\".\n",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Range.html"], None}]
}], "Text",
 CellChangeTimes->{{3.428228722078125*^9, 3.428228805125*^9}, {
  3.4282289466875*^9, 3.428228981609375*^9}, {3.428229021796875*^9, 
  3.4282290385625*^9}, {3.428229105515625*^9, 3.428229116078125*^9}, {
  3.4282293198125*^9, 3.428229365734375*^9}, {3.42822941975*^9, 
  3.42822944796875*^9}, {3.42822954225*^9, 3.4282296358125*^9}, {
  3.428229721296875*^9, 3.428229723953125*^9}, {3.42823167065625*^9, 
  3.428231695234375*^9}, {3.428231762703125*^9, 3.42823176271875*^9}, {
  3.42823207109375*^9, 3.42823207490625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, surjective or onto function, injective or one to one function, \
bijective function, domain of a function, range of a function, counterdomain \
of a function.\
\>", "Text",
 CellChangeTimes->{
  3.4282294641875*^9, {3.42822978721875*^9, 3.428229884984375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\
A function is a relation that uniquely associates members of one set with \
members of another set. More formally, a function from A to B is an object f \
such that every a in A is uniquely associated with an object f(a) in B. A \
function is therefore a many-to-one (or sometimes one-to-one) relation. The \
set A of values at which a function is defined is called its domain, while \
the set B of values that the function can produce is called its range. The \
term \"map\" is synonymous with function.
Examples of functions over the reals R include sinx (many-to-one), x \
(one-to-one), x^2 (two-to-one except for the single point x=0), etc.

Unfortunately, the term \"function\" is also used to refer to relations that \
map single points in the domain to possibly multiple points in the range. \
These \"functions\" are called multivalued functions (or multiple-valued \
functions), and arise prominently in the theory of complex functions, where \
the presence of multiple values engenders the use of so-called branch cuts.

Several notations are commonly used to represent (non-multivalued) functions. \
The most rigorous notation is f:x\[RightArrow]f(x), which specifies that f is \
function acting upon a single number x (i.e., f is a univariate, or \
one-variable, function) and returning a value f(x). To be even more precise, \
a notation like \"f:R\[RightArrow]R, where f(x)=x^2\" is sometimes used to \
explicitly specify the domain and range of the function. The slightly \
different \"maps to\" notation f:x|\[RightArrow]f(x) is sometimes also used \
when the function is explicitly considered as a \"map.\"

Generally speaking, the symbol f refers to the function itself, while f(x) \
refers to the value taken by the function when evaluated at a point x. \
However, especially in more introductory texts, the notation f(x) is commonly \
used to refer to the function f itself (as opposed to the value of the \
function evaluated at x). In this context, the argument x is considered to be \
a dummy variable whose presence indicates that the function f takes a single \
argument (as opposed to f(x,y), etc.). While this notation is deprecated by \
professional mathematicians, it is the more familiar one for most \
nonprofessionals. Therefore, unless indicated otherwise by context, the \
notation f(x) is taken in this work to be a shorthand for the more rigorous \
f:x\[RightArrow]f(x)\
\>", "Text",
 CellChangeTimes->{{3.42756634553125*^9, 3.427566352890625*^9}, {
  3.42756650334375*^9, 3.4275665683125*^9}, {3.4275666251875*^9, 
  3.4275666343125*^9}}],

Cell["\<\
In the function mappingx\[RightArrow] f(x) , the domain is all x values and \
the range is all f(x) values. 
If f(a) =f(b) implies a=b  , the function is called injective, or one-to-one. \

If for any y in the range there is an x  in the domain so that f(x)=y  , the \
function is called surjective, or onto. If both conditions are met, the \
function is called bijective, or one-to-one and onto.\
\>", "Text",
 CellChangeTimes->{3.42823203121875*^9}],

Cell[TextData[{
 "Weinstain, Eric W, Function from Mathworld:",
 ButtonBox[" Link",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Bijective.html"], None}]
}], "Text",
 CellChangeTimes->{{3.42756691271875*^9, 3.427566991015625*^9}, {
  3.4283995420625*^9, 3.428399564796875*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 521}, {13, Automatic}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[727, 28, 125, 2, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1422, 49, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[2038, 67, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[3226, 94, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3607, 109, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[7035, 176, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 7424, 191},
 {"operation", 7503, 194},
 {"briefexp", 7585, 197},
 {"concepts", 7666, 200},
 {"theory", 7745, 203},
 {"aplications", 7828, 206}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 112, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[727, 28, 125, 2, 71, "Section",
 CellTags->"about"],
Cell[855, 32, 530, 12, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1422, 49, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1487, 52, 514, 10, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2038, 67, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[2100, 70, 1089, 19, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3226, 94, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[3289, 97, 281, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3607, 109, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3656, 112, 2585, 40, 515, "Text"],
Cell[6244, 154, 461, 9, 83, "Text"],
Cell[6708, 165, 312, 8, 29, "Text"]
}, Open  ]],
Cell[7035, 176, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
