(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5252,        184]
NotebookOptionsPosition[      3655,        118]
NotebookOutlinePosition[      4667,        160]
CellTagsIndexPosition[      4468,        150]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["InverseCompositionRule", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

If f is the inverse function of g , then f(g(x))=g(f(x))=x. In this \
Demonstration you can choose two functions f and g . The graphs of f and g \
are drawn with red and blue dashes. Choose the composition f(g(x) or g(f(x) . \
The graph of the composition is drawn as a solid green curve. If it is the \
line y=x , the functions are inverses of each other. If the solid curve is \
only partly the same as the line y=x, the domain of the functions has to be \
restricted. 
\
\>", "Text",
 CellChangeTimes->{{3.42833699759375*^9, 3.428337253515625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The functions f and its inverse g are already paired by columns. \
\>", "Text",
 CellChangeTimes->{
  3.428338113296875*^9, {3.42833840565625*^9, 3.428338449484375*^9}, {
   3.428338497796875*^9, 3.428338695390625*^9}, 3.428338750890625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
Since it is needed that f has to be one to one in order to have inverse, then \
the domain of f where it  exists its  inverse is restricted to the set where \
f is one to one also. \
\>", "Text",
 CellChangeTimes->{{3.428338757796875*^9, 3.42833878125*^9}}]
}, Open  ]],

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "The nesting of two or more functions to form a single new function is known \
as composition. The composition of two functions f and g is denoted f \
\[Degree]g, where f is a function whose domain includes the range of g. The \
notation\n(f \[Degree]g)(x)=f(g(x)), \t\nis sometimes used to explicitly \
indicate the variable. \nIn order  for  composition rule to make sense, it \
has to be that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalR]", "g"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\[SubsetEqual]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->14],
 "\nComposition is associative, so that \nf\[Degree] (g \[Degree]h ) =(f \
\[Degree]g )\[Degree]h\nIf the function f is one to one, then, if there is a \
funtion g  with domain the range of, such that  f\[SmallCircle]g=g\
\[SmallCircle]f=I, where I is the identity function, ie. a function such that \
I(x)=x.. Then  g is said to be the inverse of  f. Very often in the \
literature g is termed as ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " \nWeinstain, Eric W, Function from Mathworld"
}], "Text",
 CellChangeTimes->{{3.428337394453125*^9, 3.42833742159375*^9}, {
  3.428337707703125*^9, 3.428337715109375*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 392}, {Automatic, -27}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[654, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[3583, 114, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1672, 60, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2016, 71, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1318, 46, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2101, 76, 46, 1, 41, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 3973, 129},
 {"aplications", 4053, 132},
 {"briefexp", 4138, 135},
 {"concepts", 4219, 138},
 {"operation", 4301, 141},
 {"theory", 4381, 144}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 39, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[654, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[719, 30, 562, 11, 137, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1318, 46, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1383, 49, 252, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1672, 60, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1734, 63, 267, 5, 47, "Text"]
}, Open  ]],
Cell[2016, 71, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[CellGroupData[{
Cell[2101, 76, 46, 1, 41, "Section",
 CellTags->"theory"],
Cell[2150, 79, 1418, 32, 231, "Text"]
}, Open  ]],
Cell[3583, 114, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
