(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5423,        195]
NotebookOptionsPosition[      3827,        129]
NotebookOutlinePosition[      4838,        171]
CellTagsIndexPosition[      4639,        161]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Piecewise Functions", "Title",
 CellChangeTimes->{3.4283521479375*^9}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
This Demonstration allows you to create a variety of piecewise functions\
\[LongDash]that is, functions whose output rule changes abruptly from one \
piece of its domain to another. The sliders control where the rules change \
and the buttons control which output rule is used in which region.
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The domain of the studied function can be partitioned into three, two or one, \
depending upon the values setting of the sliders \"first rule change\" and \
\"second rule change\".
 In each part the domain  any of the five shown functions can be depicted. \
Try several combinations of the sliders and the function buttons to get \
interestings plots.\
\>", "Text",
 CellChangeTimes->{
  3.42835381809375*^9, {3.428353921921875*^9, 3.428354278953125*^9}, {
   3.428355634625*^9, 3.42835564753125*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Piecewise defined functions, \
\>", "Text",
 CellChangeTimes->{{3.42835429571875*^9, 3.42835430715625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nA piecewise function is a function that is defined on a sequence of \
intervals. A common example is the absolute value,\n\n\n\[VerticalBar]x\
\[VerticalBar] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     TagBox[
      StyleBox[
       RowBox[{"{", 
        StyleBox[GridBox[{
           {
            UnderscriptBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "x"}], "  ", "for", " ", "x"}], "<", "0"}], 
             RowBox[{
              RowBox[{"0", "   ", "for", "  ", "x"}], "=", "0"}]]},
           {
            RowBox[{
             RowBox[{"x", "  ", "for", " ", "x"}], ">", "0"}]}
          }],
         ShowAutoStyles->True]}],
       FontSize->8],
      #& ],
     FontSize->12], " "}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " \n\nAdditional piecewise functions include the Heaviside step function, \
rectangle funtion, and triangle function.\nSee Weisstein, Eric W. \"",
 ButtonBox["Piecewise Function",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/PiecewiseFunction.html"], None}],
 ".\" From MathWorld--A Wolfram Web Resource."
}], "Text",
 CellChangeTimes->{{3.428354317109375*^9, 3.428354319015625*^9}, {
   3.42835445521875*^9, 3.4283544585625*^9}, 3.4283544940625*^9, {
   3.428354650640625*^9, 3.428354704328125*^9}, {3.428354752*^9, 
   3.428354918421875*^9}, {3.4283549719375*^9, 3.42835497325*^9}, {
   3.428355046265625*^9, 3.4283550721875*^9}, {3.42835511496875*^9, 
   3.42835514328125*^9}, {3.428355414125*^9, 3.42835543278125*^9}, {
   3.428355516265625*^9, 3.42835552596875*^9}, {3.42835555934375*^9, 
   3.42835555934375*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 417}, {Automatic, 11}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[691, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[3755, 125, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1703, 59, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1787, 64, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1111, 42, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2005, 76, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4144, 140},
 {"aplications", 4224, 143},
 {"briefexp", 4309, 146},
 {"concepts", 4390, 149},
 {"operation", 4472, 152},
 {"theory", 4552, 155}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 76, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[691, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[756, 31, 318, 6, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1111, 42, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1176, 45, 512, 11, 101, "Text"]
}, Open  ]],
Cell[1703, 59, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[1787, 64, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[1850, 67, 118, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2005, 76, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2054, 79, 1686, 43, 211, "Text"]
}, Open  ]],
Cell[3755, 125, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
