(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     19430,        460]
NotebookOptionsPosition[     17090,        371]
NotebookOutlinePosition[     18108,        413]
CellTagsIndexPosition[     17903,        403]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["End Behavior Of Polynomial Functions", "Title",
 CellChangeTimes->{{3.4289521109375*^9, 3.428952119890625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
A close look at polynomials shows a wide variety of interesting behavior. \
This Demonstration shows the opposite\[LongDash]the predicable, eventual \
behavior of a polynomial. Indeed, when the range is maximized, there seem to \
be only four different graphs: 
Up, up: highest nonzero coefficient is even and positive. 
Down, down: highest nonzero coefficient is even and negative. 
Up, down: highest nonzero coefficient is odd and negative. 
Down, up: highest nonzero coefficient is odd and positive.
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

If you can not fix a desired value of a coeficient, open the input field and \
type in the number.\
\>", "Text",
 CellChangeTimes->{{3.4289527721875*^9, 3.42895282565625*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Polynomial, degree of a polynomial, coeficients, roots, highest non zero \
coeficient\
\>", "Text",
 CellChangeTimes->{{3.42895288678125*^9, 3.4289529586875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[CellGroupData[{

Cell["\<\
A polynomial is a mathematical expression involving a sum of powers 
in one or more variables multiplied by coefficients. A polynomial
 in one variable (i.e., a univariate polynomial) with constant 
 coefficients is given by \:f35f\
\>", "Input",
 CellChangeTimes->{{3.428953119875*^9, 3.428953126671875*^9}}],

Cell[GraphicsData["CompressedBitmap", "\<\
eJylV1sorVsU/pZ1tY697c5poyVlq8OD5A1F6uQ4ik4eROmQVsthr8I5tp3y
zotC3hBCW26JFyS3B7ckidxLiCT3+zWcf85//v/5lzPXv9buPMy1xhxzzPF9
a4w5xxzrd+vXz3/mW7/abdbAhC/Wvz/bbUWBv/31RVBpNQC+CeOnQBD5VRDZ
xze8vr6SRfplpl9a3N/fU4mMKo5OL5ob2SQlJQX7+/u4urpCdHQ0FhYW8Atb
a2trQ0hICGJjYxEVFYX29nb8zFzOzc3By8sL09PTCKQ6HQ4ODlBYWIiOjg6U
lpYaRCSGeHp6ioeHBypfXl7Cg4HU1taiqkpkGhcXR220bO38/Fzm/fz8TNd8
GdjZ2Zm8JgwP3N3daRk55doHZv8GX8vUAwMD2NvbozOBvxqyD9+TjoEGBwfL
W3QqbpwQkuJRWVmJ8fFxOsvLy6MBpqw0xJuGxdQLra2tCAoKQlFREWZmZhAZ
GYni4mKayO3tbURERFCInJwcrK+vi+6NGB0dpUtDQ0NUU1BQgOTkZKytrQlO
xV9C1iXWBqYjOTWZTCTKkHyRfWlpabLt7e0tjEYjurq6YOL40rN9atQ92L6a
mho5je5wf8fB030HnjJ7WjfwjE7x1FOTlJSE3d1dalleXo6KigoPMbsNDQ0a
eHt7a+hJISlOTExEWVkZtR0ZGUFoaCjNw+bmJm5ubhAeHo7BwUHqu6mpSTp0
U1NTWFxcREBAAJaXl7GxsaGa2qOjIzQ3NytCrcXExAT1o9QJENRWDI7z9KrR
lnyRk5mZmelwWXi81dLqDo4yrXoVHLV0quEQ/1JMyJEtKSlh6RSKiQadnZ3/
3tj8/Hx6GyX/NpsNdrtdrohjY2O4vr7G7OwsiY+eUaquroavr1j2eOGwOE2F
SRXy5OREilJ8fDyOj48Vv9oR9r3T6BicQUilWJkAA8c1r05IgVdjn5qaipWV
FSoLbw26u7vZyybAkIwSgIuLC6ojWRaI/MCwWlpaEBMTQ2eeLF4k8MS3NHx8
fARLImllN2T86NL+g4M9GU7oUHl+fh7Dw8O0zFssFlJD9RyaZpewng6wziCl
jK+ursLf39/hLivxdC7xvN3CIzLxW1dXR+X09HQcHh5KXQjDrq+vR3Z2NpVf
Xl5gNpuxs7Mj9zRWqxVZWVm02EkJe3x8RH9/vzxIo6KlklZ+VpUJc9feg8Xb
GScyb2xsRG5uLiYnJw0cimaXkO8cINVCQOYkCaQtMHGwdC6x3n8XllCx0NPT
Q94t1r9JjUlvby+9ueR1T0hIoE+GiR2gp6cnuu7n54elpSX09fUhLCwMW1tb
8pFTNqFS1FzVMeP/xHb+7PF9errhk8ddzad4GvCRmfAabt7rwwuHhfngNea8
QvqJo/voSIfXfkt0MjIy/kNHqfNnpeJND23imH7i6N4w4TStiGPblN3gr47b
OI2QvE3ZZbzZxnlw5f89wssok5SeRrb9D2bCKduSSQYDVxQJxItL7K8aNP8A
J92cmA==\
\>"], "Graphics",
 ImageSize->{164, 19}]
}, Open  ]],

Cell["\<\
The individual summands with the coefficients (usually) included 
are called monomials (Becker and Weispfenning 1993, p. 191), whereas
 the products of the form in the multivariate case, i.e., with the 
 coefficients omitted, are called terms (Becker and Weispfenning 1993,
  p. 188). The highest power in a univariate polynomial is called its
   order, or sometimes its degree. 
Any polynomial with can be expressed as \:f35f\
\>", "Input",
 CellChangeTimes->{{3.42895197878125*^9, 3.42895197884375*^9}, {
   3.4289531949375*^9, 3.428953222796875*^9}, {3.42895346775*^9, 
   3.4289534691875*^9}, 3.42895353728125*^9, {3.42895356984375*^9, 
   3.42895359625*^9}, {3.4289536353125*^9, 3.428953649234375*^9}, 
   3.428953699578125*^9}],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{142, 42},
  ImageMargins->0],
 "\n"
}], "Text",
 CellChangeTimes->{{3.428953602390625*^9, 3.42895361875*^9}}],

Cell["\<\
(2) where the product runs over the roots of and it is understood 
that multiple roots are counted with multiplicity. 
A polynomial in two variables (i.e., a bivariate polynomial) with 
constant coefficients is given by \:f35f\
\>", "Input",
 CellChangeTimes->{{3.42895197884375*^9, 3.428951978875*^9}, {
  3.428953230640625*^9, 3.428953233546875*^9}}],

Cell["\<\
(3) The sum of two polynomials is obtained by adding together the 
coefficients sharing the same powers of variables (i.e., the same 
terms) so, for example, \:f35f\
\>", "Input",
 CellChangeTimes->{{3.428953238390625*^9, 3.42895324025*^9}}],

Cell[CellGroupData[{

Cell["\<\
(4) and has order less than (in the case of cancellation of leading 
terms) or equal to the maximum order of the original two polynomials. \
Similarly, the product of two polynomials is obtained by multiplying term by \
term and combining the results, for example \:f35f\
\>", "Input",
 CellChangeTimes->{{3.428953243390625*^9, 3.42895324825*^9}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000@D0@0006`0000200000@0000P0000=0000
00000000002n0000:0400215CDH0004050@001L0000400000000000000000000T0H001X4001:0@00
cP00000000000000000001091@2`90<0AP000<`0002n0000AdA9@`4008000`00=6Uk=`00002V0000
0@090003D`0000<070000000100000<11P050000308X0Kh01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?oooooDkI@1100002d10P0700008@D103d1mOlD00<0000000004@0000`000080000
2`000100000:00003`0000T0000@00002P0000l0000A0000300000H00009000040000;h0000X0@00
9`0001P00001000000000000000000009@0000`0000100009P0001`0000200000000000000000000
000002D0000<00000P000580001`0@000`0000`00009000000000000002@0@00000000020P9=05<0
801C0640KP1c0200D`1U0780J@1V0000000000000000000000000000000000000000000000000000
000B00005@0b1i5l0`0001P75@0001D0D;lM063^4P0C1?ooY?0B01S^T7`h1i5loooooc87TGb[1Y5l
j`JAO000002P0o8200000<c`4P3Z1`00f?0B03PETGbF5I5lj`JAO0000020000064@J0:<@8F`N0000
:0`E00005@0001d0b>hB0387TG`<lA806>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l000009cGSP2S425/
C>lB09Wa4P1k27H0000B0?gooon;4GH0000000400014ka80FbSbMfSb7P0U000064@J0000<00HA1X0
F>lB0=`WlWL<0000Xa0QK6Af00P000009@0000`000030000E00005@0000200000@0000P0000=0000
0@000176hCoCaN6o50000?Goool10000C00000000000000000000?ooooooooooD00003d000130000
9@0000`0000700209@0000`000000020<00000`0000?00209@0000`0000=0020B`00010000000000
1@0002P0000<00000@0002P0000<00000P0002P0000<00000`0000h0000D000000000100000D0000

\>"], "Graphics",
 ImageSize->{8.375, 5.375}]
}, Open  ]],

Cell["\<\
(5) (6) and has order equal to the sum of the orders of the two 
original polynomials. 
A polynomial quotient \:f35f\
\>", "Input",
 CellChangeTimes->{{3.42895197890625*^9, 3.428951978921875*^9}, 
   3.428953252515625*^9}],

Cell["\<\
(7) of two polynomials and is known as a rational function.
 The process of performing such a division is called long division, 
 with synthetic division being a simplified method of recording the 
 division. 
For any polynomial , divides , meaning that the polynomial quotient 
is a rational polynomial or, in the case of an integer polynomial, 
another integer polynomial (pers. comm., N. Sato, Nov. 23, 2004). 
Exchanging the coefficients of a univariate polynomial end-to-end 
produces a polynomial \:f35f\
\>", "Input",
 CellChangeTimes->{{3.4289519789375*^9, 3.428951979*^9}, {3.428953261125*^9, 
  3.4289532719375*^9}}],

Cell["\<\
(8) whose roots are reciprocals of the original roots . 
Horner's rule provides a computationally efficient method of forming 
a polynomial from a list of its coefficients, and can be implemented 
in Mathematica as follows. 
  Polynomial[l_List, x_] := Fold[x #1 + #2&, 0, l]
The following table gives special names given to polynomials of low 
orders. 
polynomial orderpolynomial name2quadratic polynomial3cubic 
polynomial4quartic5quintic6sexticPolynomials of fourth degree may 
be computed using three multiplications and five additions if a few 
quantities are calculated first (Press et al. 1989): \:f35f\
\>", "Input",
 CellChangeTimes->{{3.428951979*^9, 3.428951979046875*^9}, {
  3.428953295453125*^9, 3.4289533065*^9}}],

Cell[CellGroupData[{

Cell["(9) where \:f35f", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000@D0@0006`0000100000@0000P0000=0000
00000000002n0000:0400215CDH0004050@001L0000400000000000000000000T0H001X4001:0@00
cP00000000000000000001091@2`90<0AP000<`0002n0000AdA9@`4008000`00CN7oS000002V0000
0@090003D`0000<070000000100000<11P050000308X0Kh01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?oooooDkI@1100002d10P0700008@D10441mOl?00<0000000004@0000`000080000
2`000100000:00003`0000T0000@00002P0000l0000A0000300000H00009000040000;h0000X0@00
9`0001P00001000000000000000000009@0000`0000100009P0001`0000200000000000000000000
000002D0000<00000P000580001`0@000`0000`00009000000000000002@0@00000000020P9=05<0
801C0640KP1c0200D`1U0780J@1V0000000000000000000000000000000000000000000000000000
000B00005@0b1i5l0`0001P75@0001D0D;lM063^4P10kQ80Y?0B01S^T7`h1i5loooooc87TGb[1Y5l
j`JAO000002`33h900000<c`4P3Z1`00f?0B03PETGbF5I5lj`JAO0000020000064@J0:0@8D/N0000
:0`E00005@0001d0b>hB0387TG`<lA806>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l000009cGSP2P425;
W64l1f3_4P280000001F063_4P1Pka80@>lB011`HP14ka80FbSbMfSb7P0U000064@J0000<00HA1X0
F>lB0=`WlWL<0000X10QBfAf00P000009@0000`000030000E00005@0000100000@0000P0000=0000
0@000176hCoCaN6o3`000?Goool10000C00000000000000000000?ooooooooooD0000440001>0000
9@0000`0000700209@0000`000000020<00000`0000?00209@0000`0000=0020B`00010000000000
1@0002P0000<00000@0002P0000<00000P0002P0000<00000`0000h0000D000000000100000D0000

\>"], "Graphics",
 ImageSize->{8.375, 5.375}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000@D0@0006`0000200000@0000P0000=0000
00000000002n0000:0400215CDH0004050@001L0000400000000000000000000T0H001X4001:0@00
cP00000000000000000001091@2`90<0AP000<`0002n0000AdA9@`4008000`00XfD_@P00002V0000
0@090003D`0000<070000000100000<11P050000308X0Kh01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?oooooDkI@1100002d10P0700008@D103d1mOlD00<0000000004@0000`000080000
2`000100000:00003`0000T0000@00002P0000l0000A0000300000H00009000040000;h0000X0@00
9`0001P00001000000000000000000009@0000`0000100009P0001`0000200000000000000000000
000002D0000<00000P000580001`0@000`0000`00009000000000000002@0@00000000020P9=05<0
801C0640KP1c0200D`1U0780J@1V0000000000000000000000000000000000000000000000000000
000B00005@0b1i5l0`0001P75@0001D0D;lM063^4P0C1?ooY?0B01S^T7`h1i5loooooc87TGb[1Y5l
j`JAO00000101ch900000<c`4P3Z1`00f?0B03PETGbF5I5lj`JAO0000020000064@J09h@8A4N0000
:0`E00005@0001d0b>hB0387TG`<lA806>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l000009cGSP2N424A
C>lB09Wa4P1k27H0000B0?gooon;4GH0000000400014ka80FbSbMfSb7P0U000064@J0000<00HA1X0
F>lB0=`WlWL<0000WQ0Q4FAf00P000009@0000`000030000E00005@0000200000@0000P0000=0000
0@000176hCoCaN6o50000?Goool10000C00000000000000000000?ooooooooooD00003d000130000
9@0000`0000700209@0000`000000020<00000`0000?00209@0000`0000=0020B`00010000000000
1@0002P0000<00000@0002P0000<00000P0002P0000<00000`0000h0000D000000000100000D0000

\>"], "Graphics",
 ImageSize->{8.375, 5.375}]
}, Open  ]]
}, Open  ]],

Cell["\<\
(10) (11) (12) (13) (14) Similarly, a polynomial of fifth degree may be \
computed with four multiplications and five additions, and a polynomial of \
sixth degree may be computed with four multiplications and seven additions. 
Polynomials of orders one to four are solvable using only rational operations \
and finite root extractions. A first-order equation is trivially solvable. A \
second-order equation is soluble using the quadratic equation. A third-order \
equation is solvable using the cubic equation. A fourth-order equation is \
solvable using the quartic equation. It was proved by Abel and Galois using \
group theory 
that general equations of fifth and higher order cannot be solved rationally \
with finite root extractions (Abel's impossibility theorem). 
However, solutions of the general quintic equation may be given in terms of \
Jacobi theta functions or hypergeometric functions in one variable. Hermite \
and Kronecker proved that higher order polynomials are not soluble in the \
same manner. Klein showed that the work of Hermite was implicit in the group \
properties of the icosahedron. Klein's method of solving the quintic in terms \
of hypergeometric functions in one variable can be extended to the sextic, \
but for higher order polynomials, either hypergeometric functions in several \
variables or \"Siegel functions\" must be used (Belardinelli 1960, King 1996, \
Chow 1999). In the 1880s, Poincar\[EAcute] created functions which give the \
solution to the th order polynomial equation in finite form. These functions \
turned out to be \"natural\" generalizations of the elliptic functions. 
\
\>", "Text",
 CellChangeTimes->{{3.42895331575*^9, 3.42895331978125*^9}}],

Cell[TextData[{
 "\n",
 ButtonBox["link ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Polynomial.html"], None}],
 "Weisstein, Eric W. \"Set.\" From MathWorld--A Wolfram Web Resource."
}], "Text",
 CellChangeTimes->{{3.430511498078125*^9, 3.4305115338125*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 109}, {Automatic, 50}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[732, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1361, 46, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1627, 57, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1711, 62, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[1984, 75, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[17018, 367, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 17407, 382},
 {"operation", 17485, 385},
 {"briefexp", 17567, 388},
 {"concepts", 17648, 391},
 {"theory", 17727, 394},
 {"aplications", 17809, 397}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 117, 1, 137, "Title"],
Cell[CellGroupData[{
Cell[732, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[797, 31, 527, 10, 155, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1361, 46, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1426, 49, 186, 5, 47, "Text"]
}, Open  ]],
Cell[1627, 57, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[1711, 62, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[1774, 65, 173, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1984, 75, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[CellGroupData[{
Cell[2055, 80, 319, 6, 82, "Input"],
Cell[2377, 88, 1618, 28, 27, "Graphics"]
}, Open  ]],
Cell[4010, 119, 743, 13, 133, "Input"],
Cell[4756, 134, 2870, 51, 74, "Text"],
Cell[7629, 187, 362, 7, 82, "Input"],
Cell[7994, 196, 251, 5, 65, "Input"],
Cell[CellGroupData[{
Cell[8270, 205, 357, 6, 48, "Input"],
Cell[8630, 213, 1539, 21, 20, "Graphics"]
}, Open  ]],
Cell[10184, 237, 232, 6, 65, "Input"],
Cell[10419, 245, 636, 12, 167, "Input"],
Cell[11058, 259, 738, 14, 201, "Input"],
Cell[CellGroupData[{
Cell[11821, 277, 33, 0, 31, "Input"],
Cell[CellGroupData[{
Cell[11879, 281, 1539, 21, 20, "Graphics"],
Cell[13421, 304, 1539, 21, 20, "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[14987, 329, 1717, 25, 353, "Text"],
Cell[16707, 356, 296, 8, 47, "Text"]
}, Open  ]],
Cell[17018, 367, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
