(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7552,        236]
NotebookOptionsPosition[      5959,        170]
NotebookOutlinePosition[      6968,        212]
CellTagsIndexPosition[      6769,        202]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ContinuousExponentialGrowth", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
Continuous exponential growth, where r is the growth rate, N(t) is the \
population size, and N(0) is the initial population size.
\
\>", "Text"]
}, Open  ]],

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[TextData[{
 "This is an application of the exponential function \nf(x)= ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[ExponentialE]", "\[ScriptX]"],
    FontSize->16], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " a function whose growth is faster then polynomial functions. In this \
demonstration there is a factor ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["N", "0"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " = N(0)  to the exponential function and also another factor r to variable \
x.\nSince N(t)=N(0) ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[ScriptE]", 
     RowBox[{"r", " ", "t"}]],
    FontSize->18], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 ", the factor N(0) determines the crossing with the vertical axis of the \
graph of the function. It is a dominant factor in the growth of the function  \
when t is relatively small, but it is less dominant then r."
}], "Text",
 CellChangeTimes->{{3.430580771046875*^9, 3.43058082525*^9}, {
   3.4305808590625*^9, 3.430580958375*^9}, {3.430581016796875*^9, 
   3.430581167890625*^9}, 3.430581920453125*^9, {3.430581972328125*^9, 
   3.430582180765625*^9}, {3.430582245421875*^9, 3.430582315375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Exponential function, exponential growth\
\>", "Text",
 CellChangeTimes->{{3.430581174*^9, 3.430581222359375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "Exponential growth is the increase in a quantity according to the law \n\n\
N(t)=N(0) ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[ScriptE]", 
     RowBox[{"r", " ", "t"}]],
    FontSize->18], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "\nfor a parameter t and constant r",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000>`0@0006`00000000000000?oooooooooo
00000000002Y0000:0400215CDH00040/0<001H0000400000000000000000000T0H001X4001:0@00
cP00000000000000000001091@2`90<0AP000;`0002`0000AdA9@`4008000`00[a@o?P00002H0000
0@090003C00000<070000000100000<11P050000308X0JT01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?oooonlkF09100002d10P030000000A0000300000P0000;0000400000T0000?0000
2@000100000900003`000140000<00001P0000T0000@0000Z@0002P1000W00006000004000000000
00000000000U000030000040000V0000700000800000000000000000000000009@0000`000020000
DP00070100030000300000T000000000000009010000000000820Td0D`0P05<0H@1^07<0801C06D0
LP1Y06H00000000000000000000000000000000000000000000000000000095lM?0B003YT7`80Y5l
ooooo`82TGak0I5l^`6AO000002Lehh01a<Q[`00002PkQ80=8M1O^`30`3Y000000000:3_4P2=^U/0
cJ^jg000003LkQ80SKYK00S_4P3IRd5ng>hB000000020Y5l0`0004065@0003l0B0521@004P0D0000
n?0B003YT7ah0AD0ooooo`82TGak0I5l^`6AO0`000000000Y02AO9Pg@@E<ka80f3lQ0328@Gh00?oo
:XQ1OZ2>@Wh00000SKYK03C_4P2M9o9gP>4P02D0001PU1`0000`062D7018ka807RObM``000074b6_
I7H02000000U0000300000<0000U0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000010000:00000`000020000:00000`000030000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{8.375, 4.75},
  ImageMargins->0],
 "(the analog of the decay constant), where ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[ScriptE]", "\[ScriptX]"],
    FontSize->16], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " is the exponential function  and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["N", "0"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " = N(0) is the initial value. Exponential growth is common in physical \
processes such as population growth in the absence of predators or resource \
restrictions (where a slightly more general form is known as the law of \
growth). Exponential growth also occurs as the limit of discrete processes \
such a compound interest.\n\nWeisstein, Eric W. \"",
 ButtonBox["Exponential Growth",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ExponentialGrowth.html"], None}],
 ".\" From ",
 StyleBox["MathWorld",
  FontSlant->"Italic"],
 "--A Wolfram Web Resource.  \n\n"
}], "Text",
 CellChangeTimes->{{3.430579410796875*^9, 3.43057947415625*^9}, 
   3.4305795281875*^9, {3.430579704328125*^9, 3.430579718609375*^9}, {
   3.4305797730625*^9, 3.430579864703125*^9}, 3.43057989675*^9, {
   3.4305799290625*^9, 3.430580217578125*^9}, {3.430580250859375*^9, 
   3.43058031284375*^9}, 3.4305803476875*^9, {3.430580382609375*^9, 
   3.43058040653125*^9}, 3.430581949078125*^9, {3.43058200328125*^9, 
   3.4305820101875*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 359}, {Automatic, 74}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[659, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[5887, 166, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[981, 42, 59, 1, 41, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2386, 82, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[894, 37, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2611, 94, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6276, 181},
 {"aplications", 6356, 184},
 {"briefexp", 6441, 187},
 {"concepts", 6521, 190},
 {"operation", 6603, 193},
 {"theory", 6682, 196}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 44, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[659, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[724, 30, 155, 4, 65, "Text"]
}, Open  ]],
Cell[894, 37, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[CellGroupData[{
Cell[981, 42, 59, 1, 41, "Section",
 CellTags->"briefexp"],
Cell[1043, 45, 1306, 32, 130, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2386, 82, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2449, 85, 125, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2611, 94, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2660, 97, 3212, 66, 238, "Text"]
}, Open  ]],
Cell[5887, 166, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
