(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      9853,        322]
NotebookOptionsPosition[      8179,        253]
NotebookOutlinePosition[      9191,        295]
CellTagsIndexPosition[      8992,        285]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["A Case Of The Epsilon Delta Definition Of A Limit", "Title",
 CellChangeTimes->{{3.43128535465625*^9, 3.431285368359375*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "\nFrom the intuitive notion of a limit, if  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    UnderscriptBox["lim", 
     RowBox[{"\[ScriptX]", "\[RightArrow]", "\[ScriptA]"}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " f(\[ScriptX]) = L, then can be made as close to L as desired simply by \
finding an that is sufficiently close to \[ScriptA]. The formalized version \
of this is the \[Epsilon]-\[Delta] definition of a limit. In this case ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    UnderscriptBox["lim", 
     RowBox[{"\[ScriptX]", "\[RightArrow]", "4"}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "(1/2 \[ScriptX] + 3) = 5. Select a value for \[Epsilon] > 0and you can find \
a corresponding \[Delta] > 0 so that, if  0 < \[VerticalBar]\[ScriptX]-\
\[ScriptA]\[VerticalBar] < \[Delta], then \[VerticalBar]f(\[ScriptX]) - L\
\[VerticalBar] < ",
 "\[Epsilon]",
 ".\n"
}], "Text",
 CellChangeTimes->{{3.430933599140625*^9, 3.430933601921875*^9}, {
  3.4309337028125*^9, 3.43093377103125*^9}, {3.43093380159375*^9, 
  3.4309340879375*^9}, {3.430934133609375*^9, 3.4309341730625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Fix any value for \[Epsilon]. The correct value for \[Delta] in this example \
is the largest value such that vertical lines are shown in green.\
\>", "Text",
 CellChangeTimes->{{3.43128169653125*^9, 3.431281819625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

This is a very simple example of a function  with limit in all the domain \
shown, in particular for \[ScriptX]=4, the existence of the limit in this \
example is guarrantied by the fact that we can always find a rectangle \
centered at (4,5) of height 2 \[Epsilon] width 2 \[Delta] which encloses \
entirely the graph of the function.\
\>", "Text",
 CellChangeTimes->{{3.431281827734375*^9, 3.43128189478125*^9}, {
  3.4312819335625*^9, 3.431282011734375*^9}, {3.43128204490625*^9, 
  3.43128205428125*^9}, {3.431285075375*^9, 3.43128516021875*^9}, {
  3.43128525334375*^9, 3.4312852601875*^9}, {3.431285290453125*^9, 
  3.43128529403125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\
Real function, limit of a function, absolute value, interval, center of an \
interval, size of an interval, closeness of real values, finite limit..\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nAn epsilon-delta definition is a mathematical definition in which a \
statement on a ",
 StyleBox["real function",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 " of one variable f  having, for example, the form \"for all ",
 StyleBox["neighborhoods",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 "  U of  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " there is a ",
 StyleBox["neighborhood",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 "  V  of ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " such that, whenever \[ScriptX] \[Epsilon] V , then  f(\[ScriptX]) \
\[Epsilon] U \" is rephrased as \"for all \[Delta] >  0\" such that, whenever \
  \[VerticalBar]\[ScriptX]-",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " \[VerticalBar], then \[VerticalBar]f(\[ScriptX])-",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 "\[VerticalBar] < \[Epsilon]. These two statements are equivalent \
formulations of the definition of the limit: ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[ScriptX]", "\[RightArrow]", 
       SubscriptBox["\[ScriptX]", "0"]}]],
     FontSize->10]}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "  f(\[ScriptX]) = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 "  In the second one, the ",
 StyleBox["neighborhood",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 "  is replaced by the ",
 StyleBox["open interval",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 " (",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 "-\[Epsilon],",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 "+\[Epsilon]), and the ",
 StyleBox["neighborhood V ",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 "by the ",
 StyleBox["open interval",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0., 0., 1.]],
 "  (",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptX]", "0"], " "}],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "-\[Delta],. ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 " +\[Delta]).\nThis statment express  the fact that for all \[ScriptX] which \
lie close enough to ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->14], TraditionalForm]], "Subtitle"],
 " , f(\[ScriptX]) lies as close to ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptY]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 " as desired. In the second formulation this condition is entirely expressed \
in terms of numbers: \[Epsilon] and \[Delta] are distances that measures the \
\"closeness.\" This facilitates the task of proving limits since the \
fundamental formulas are actually shown by constructing, for every \
\[Epsilon], a  \[Delta] with the required property. \n\n\n\
http://mathworld.wolfram.com/Epsilon-DeltaDefinition.html\n",
 ButtonBox["link",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Epsilon-DeltaDefinition.html"], None}]
}], "Text",
 CellChangeTimes->{{3.431278923640625*^9, 3.431278926375*^9}, {
   3.43127898715625*^9, 3.43127898715625*^9}, {3.43127904159375*^9, 
   3.431279041859375*^9}, 3.431279201046875*^9, {3.43127925553125*^9, 
   3.431279258046875*^9}, {3.431279291390625*^9, 3.431279518890625*^9}, {
   3.43127962221875*^9, 3.431279693734375*^9}, {3.431279726796875*^9, 
   3.43127974303125*^9}, {3.43127977528125*^9, 3.431279787765625*^9}, {
   3.4312798183125*^9, 3.431279985078125*^9}, {3.431280018171875*^9, 
   3.43128039759375*^9}, {3.431280433328125*^9, 3.4312805784375*^9}, {
   3.43128145053125*^9, 3.431281511390625*^9}, {3.43128154725*^9, 
   3.431281549484375*^9}, 3.4312835455625*^9}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 329}, {Automatic, 69}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[746, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[2037, 64, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[2370, 77, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[3124, 97, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3396, 108, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[8107, 249, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 8496, 264},
 {"operation", 8574, 267},
 {"briefexp", 8656, 270},
 {"concepts", 8737, 273},
 {"theory", 8816, 276},
 {"aplications", 8899, 279}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 131, 1, 137, "Title"],
Cell[CellGroupData[{
Cell[746, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[811, 31, 1189, 28, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2037, 64, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[2102, 67, 231, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2370, 77, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[2432, 80, 655, 12, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3124, 97, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[3187, 100, 172, 3, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3396, 108, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3445, 111, 4647, 135, 306, "Text"]
}, Open  ]],
Cell[8107, 249, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
