(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7131,        273]
NotebookOptionsPosition[      5349,        202]
NotebookOutlinePosition[      6360,        244]
CellTagsIndexPosition[      6161,        234]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Limit Laws", "Title",
 CellChangeTimes->{3.431694540921875*^9}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
Pairs of functions can be combined in six standard ways. The pairs are \
plotted as dashed curves and their combination as a solid brown line. The \
limit of the combination as x  approaches 1 is the height of the red dot. 
\
\>", "Text",
 CellChangeTimes->{{3.43169461521875*^9, 3.43169461665625*^9}, {
  3.431694669796875*^9, 3.4316946733125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The push-buttoms sellect the pair f-g to which the desired operations can be \
applied.\
\>", "Text",
 CellChangeTimes->{{3.43169880253125*^9, 3.431698854671875*^9}, {
  3.431698900625*^9, 3.4316989061875*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\
Real function, limit of a function, absolute value, interval, center of an \
interval, size of an interval, closeness of real values, finite limit, \
infinity limit at infinity, lower bound.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "If  L,M,c  and k are real numbers and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " f(x) = L and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " g(x) = M, then \n1. Sum Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " (f(x) + g(x)) = L+M"
}], "Text",
 CellChangeTimes->{{3.431698983921875*^9, 3.431698983984375*^9}, {
  3.431699077796875*^9, 3.43169933634375*^9}}],

Cell[TextData[{
 "2. Difference Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " (f(x) - g(x)) = L-M"
}], "Text",
 CellChangeTimes->{
  3.431698983984375*^9, {3.43169909028125*^9, 3.431699090609375*^9}, {
   3.431699325171875*^9, 3.43169935128125*^9}}],

Cell[TextData[{
 "3. Product Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " (f(x) \[Times]g(x)) = L",
 "\[Times]",
 "M"
}], "Text",
 CellChangeTimes->{
  3.431698984*^9, {3.431699093625*^9, 3.431699093953125*^9}, {
   3.43169934640625*^9, 3.4316993841875*^9}}],

Cell[TextData[{
 "4. Constant Multiple Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 "  k f(x)  =k  L"
}], "Text",
 CellChangeTimes->{
  3.431698984*^9, {3.43169909640625*^9, 3.431699096640625*^9}, {
   3.431699394546875*^9, 3.43169943590625*^9}}],

Cell[TextData[{
 "5. Quotient Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " (f(x) / g(x)) = L/M\n6. Power Rule: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", "c"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->14],
 " ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox[
     RowBox[{"f", "(", "x", ")"}], "k"],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["L", "k"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " , if  L\[GreaterSlantEqual] 0 and k ",
 "\[GreaterSlantEqual] 0"
}], "Text",
 CellChangeTimes->{{3.43169909784375*^9, 3.43169910225*^9}, {
  3.43169945196875*^9, 3.43169963990625*^9}}],

Cell[TextData[{
 "\n",
 ButtonBox["Link\n",
  BaseStyle->"Hyperlink",
  ButtonData->{
   "ACaseOfTheEpsilonDeltaDefinitionOfALimit-text.nb", "theory"}],
 "http://mathworld.wolfram.com/Limit.html, ",
 ButtonBox["link",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Limit.html"], None}]
}], "Text",
 CellChangeTimes->{{3.4316996585*^9, 3.43169968309375*^9}, {
  3.43169981959375*^9, 3.43169985615625*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 337}, {Automatic, 29}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[684, 28, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1145, 43, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1446, 55, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1530, 60, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[1844, 72, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[5277, 198, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 5666, 213},
 {"operation", 5744, 216},
 {"briefexp", 5826, 219},
 {"concepts", 5907, 222},
 {"theory", 5986, 225},
 {"aplications", 6068, 228}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 69, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[684, 28, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[749, 31, 359, 7, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1145, 43, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1210, 46, 221, 6, 47, "Text"]
}, Open  ]],
Cell[1446, 55, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[1530, 60, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[1593, 63, 214, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1844, 72, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[1893, 75, 782, 25, 49, "Text"],
Cell[2678, 102, 388, 12, 30, "Text"],
Cell[3069, 116, 398, 14, 30, "Text"],
Cell[3470, 132, 384, 12, 30, "Text"],
Cell[3857, 146, 965, 34, 51, "Text"],
Cell[4825, 182, 437, 13, 65, "Text"]
}, Open  ]],
Cell[5277, 198, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
