(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8640,        321]
NotebookOptionsPosition[      6951,        253]
NotebookOutlinePosition[      7970,        295]
CellTagsIndexPosition[      7771,        285]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Discontinuity", "Title"],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "For a value f(x), let  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["L", "-"],
    FontSize->10], TraditionalForm]], "Subtitle"],
 " = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["lim", 
     RowBox[{"x", "\[RightArrow]", 
      SuperscriptBox["s", "-"]}]],
    FontSize->12], TraditionalForm]], "Subtitle",
  FontSize->16],
 "  f(x) (the limit from the left) and   ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["L", "+"],
    FontSize->10], TraditionalForm]], "Subtitle"],
 " = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["lim", 
     RowBox[{"x", "\[RightArrow]", 
      SuperscriptBox["s", "+"]}]],
    FontSize->10], TraditionalForm]], "Subtitle",
  FontSize->16],
 "  f(x) (the limit from the right). \nIf L",
 StyleBox["-",
  FontVariations->{"CompatibilityType"->Superscript}],
 " = L",
 StyleBox["+",
  FontVariations->{"CompatibilityType"->Superscript}],
 " = f(s), the function is continuous at x=s . \nIf L",
 StyleBox["-",
  FontVariations->{"CompatibilityType"->Superscript}],
 " = L",
 StyleBox["+",
  FontVariations->{"CompatibilityType"->Superscript}],
 " \[NotEqual] f(s), the function has a removable discontinuity at x=s. \nIf \
L",
 StyleBox["-",
  FontVariations->{"CompatibilityType"->Superscript}],
 " \[NotEqual] L",
 StyleBox["+",
  FontVariations->{"CompatibilityType"->Superscript}],
 ", and both values are finite, the function has a jump discontinuity at x=s \
. \nIf L",
 StyleBox["-",
  FontVariations->{"CompatibilityType"->Superscript}],
 " \[NotEqual] L",
 StyleBox["+",
  FontVariations->{"CompatibilityType"->Superscript}],
 ", and one or both values is infinite, the function has an infinite \
discontinuity at x=s. This is also called an essential discontinuity.\n"
}], "Text",
 CellChangeTimes->{{3.431712633734375*^9, 3.431712656765625*^9}, {
  3.4317127353125*^9, 3.431712836109375*^9}, {3.431712870578125*^9, 
  3.43171287596875*^9}, {3.431712920421875*^9, 3.431712932078125*^9}, {
  3.431713034515625*^9, 3.43171307190625*^9}, {3.431713115875*^9, 
  3.431713290828125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

You can build simple rational functions manipulating the buttons and sliders. \
The plotted function expression is shown as a title of the plot.\
\>", "Text",
 CellChangeTimes->{{3.431716996953125*^9, 3.431717085953125*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, continuity of a function,  limit of a function, discontinuity of a \
function,  removable discontinuity, essential discontinuity.\
\>", "Text",
 CellChangeTimes->{{3.431717107328125*^9, 3.431717235625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "A function f(x) in a single variable x is said to be continuous at point ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 " if \n1. f(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ") is defined, so that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 " is in the domain of f . \n2. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", 
     SubscriptBox["x", "0"]}]], TraditionalForm]], "Subtitle",
  FontSize->10],
 "f(x) ",
 StyleBox[" ",
  FontSize->10],
 "exists for x in the domain  of f . \n3.",
 Cell[BoxData[
  FormBox[
   SubscriptBox["lim", 
    RowBox[{"x", "\[RightArrow]", 
     SubscriptBox["x", "0"]}]], TraditionalForm]], "Subtitle",
  FontSize->10],
 "f(x) =f(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->10], TraditionalForm]], "Subtitle"],
 ")\nwhere lim denotes a limit.\n"
}], "Text",
 CellChangeTimes->{{3.43171369215625*^9, 3.431713779875*^9}, {
  3.4317155494375*^9, 3.431715588921875*^9}, {3.431715619609375*^9, 
  3.431715932015625*^9}, {3.43171606546875*^9, 3.4317161433125*^9}, {
  3.4317166311875*^9, 3.431716654171875*^9}}],

Cell[TextData[{
 "If two functions f and g are continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ", then \n1. f + g is continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ". \n2. f -g is continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ". \n3. f g is continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ". \n4. f / g is continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["x", "0"], " "}],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "if  g(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ") \[NotEqual] 0 \n5. Providing that f is continuous at  g(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ", f \[SmallCircle] g is continuous at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ", where  f \[SmallCircle] g denotes f(g(x)), the composition  of the \
functions f and g. \n"
}], "Text",
 CellChangeTimes->{{3.43171603103125*^9, 3.4317160448125*^9}, {
  3.431716160875*^9, 3.431716370984375*^9}, {3.43171646803125*^9, 
  3.431716587359375*^9}}],

Cell[TextData[{
 "Weisstein, Eric W. \"Continuous Function.\" From ",
 StyleBox["MathWorld",
  FontSlant->"Italic"],
 "--A Wolfram Web \n",
 ButtonBox["link",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ContinuousFunction.html "], None}]
}], "Text",
 CellChangeTimes->{{3.4317167444375*^9, 3.43171677225*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 515}, {Automatic, -4}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[622, 26, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[2819, 98, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[3134, 109, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[3218, 114, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[3545, 127, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[6879, 249, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 7273, 264},
 {"operation", 7351, 267},
 {"briefexp", 7433, 270},
 {"concepts", 7515, 273},
 {"theory", 7595, 276},
 {"aplications", 7678, 279}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 30, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[622, 26, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[687, 29, 2095, 64, 190, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2819, 98, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[2884, 101, 235, 5, 65, "Text"]
}, Open  ]],
Cell[3134, 109, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[3218, 114, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[3281, 117, 227, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3545, 127, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3594, 130, 1367, 47, 127, "Text"],
Cell[4964, 179, 1552, 55, 155, "Text"],
Cell[6519, 236, 345, 10, 47, "Text"]
}, Open  ]],
Cell[6879, 249, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
