(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7482,        245]
NotebookOptionsPosition[      5738,        173]
NotebookOutlinePosition[      6753,        215]
CellTagsIndexPosition[      6554,        205]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Average Rate Of Change Exploring More Functions", "Title",
 CellChangeTimes->{{3.45174966259375*^9, 3.4517496738125*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

The demo shows the average rate of change for the listed functions.\
\>", "Text",
 CellChangeTimes->{
  3.4517499014375*^9, {3.451749954546875*^9, 3.451750030515625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell[TextData[{
 "\nSelect the function you want to study with the functions menu, then \
select a point ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " and an interval size  \[CapitalDelta]x sliding the corresponding sliders."
}], "Text",
 CellChangeTimes->{{3.45175004984375*^9, 3.451750102078125*^9}, {
  3.451750148984375*^9, 3.451750155796875*^9}, {3.451750224046875*^9, 
  3.45175024425*^9}, {3.451750477125*^9, 3.451750593453125*^9}, {
  3.451753078125*^9, 3.451753083890625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

Lot of common situations where changes which depend upon some variable takes \
place are named dynamical with respect to such variable. Average rate of \
change is an important concept to begin the understanding of such changes, in \
fact it is often the only behavior which can be studied since most of the \
measuring devices designed by mankind are limited by the maximum amount that \
a cuantity can be diminuished.  \
\>", "Text",
 CellChangeTimes->{{3.451750600109375*^9, 3.45175074965625*^9}, {
  3.451750830515625*^9, 3.451751058796875*^9}, {3.451752198515625*^9, 
  3.451752206578125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Functions, independent variable, dependent variable, rate of change, quotient \
of changes.\
\>", "Text",
 CellChangeTimes->{{3.451752226171875*^9, 3.4517522965625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nA rate of change of a quantity, normally termed the dependent one which \
is associated with the dependent variable, with respect to another one, \
normally considered the independent one, usually is understood as the number \
of units the dependent variable changes with a unit change in the independent \
one. \nFor real valued funtions of one real variable: f:\
\[DoubleStruckCapitalR]\[RightArrow]\[DoubleStruckCapitalR], the average rate \
of change \[CapitalDelta]f/\[CapitalDelta]\[ScriptX] measures the fractional \
increment of f with \[ScriptX]. This fractional increment depends upon  the \
actual value of the dependent variable \[ScriptX], ie. for a particular value \
of x, say ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 ", the average rate of change is the quantity:\n\n                           \
          ",
 StyleBox["\[CapitalDelta]f/\[CapitalDelta]\[ScriptX]",
  FontSize->18],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[VerticalSeparator]", 
     SubscriptBox["\[ScriptX]", "0"]],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->18],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["\[ScriptX]", "0"], " ", "+", 
       "\[CapitalDelta]\[ScriptX]"}], ")"}], "-", 
     RowBox[{"f", "(", 
      SubscriptBox["\[ScriptX]", "0"], ")"}]}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "   "
}], "Text",
 CellChangeTimes->{{3.451752313859375*^9, 3.451752630125*^9}, {
   3.4517526748125*^9, 3.451752746484375*^9}, {3.451752865609375*^9, 
   3.451752894984375*^9}, {3.451752925296875*^9, 3.451752976359375*^9}, {
   3.4517530659375*^9, 3.451753104421875*^9}, {3.4517531645625*^9, 
   3.451753227328125*^9}, {3.451753279953125*^9, 3.451753510453125*^9}, {
   3.45175358*^9, 3.451753666328125*^9}, {3.451753718296875*^9, 
   3.45175387909375*^9}, {3.451753914625*^9, 3.451753917859375*^9}, 
   3.451753956796875*^9, {3.4517539999375*^9, 3.451754000734375*^9}, {
   3.4517542905625*^9, 3.451754302046875*^9}},
 TextAlignment->Left]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aplications", "Section",
 CellTags->"aplications"],

Cell["\<\

In the real physical world, the measuring devices designed by mankind used in \
science or engineering facilities impose a limit to how small can be the \
value of \[CapitalDelta]\[ScriptX], therefore in measuring things such as \
velocity whose phiscial meaning can be change in position with time, what is \
actually measured is the average velocity. \
\>", "Text",
 CellChangeTimes->{{3.45175434471875*^9, 3.451754377109375*^9}, {
   3.451754430640625*^9, 3.451754525578125*^9}, {3.4517545969375*^9, 
   3.4517546014375*^9}, {3.45175464415625*^9, 3.451754819484375*^9}, 
   3.4517548709375*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 468}, {Automatic, 0}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[719, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[5043, 155, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1700, 62, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2408, 81, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1002, 40, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2688, 94, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6059, 184},
 {"aplications", 6139, 187},
 {"briefexp", 6224, 190},
 {"concepts", 6305, 193},
 {"operation", 6387, 196},
 {"theory", 6467, 199}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 127, 1, 137, "Title"],
Cell[CellGroupData[{
Cell[719, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[784, 30, 181, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1002, 40, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1067, 43, 596, 14, 66, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1700, 62, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1762, 65, 609, 11, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2408, 81, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2471, 84, 180, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2688, 94, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2737, 97, 2269, 53, 212, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5043, 155, 56, 1, 71, "Section",
 CellTags->"aplications"],
Cell[5102, 158, 608, 11, 101, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
