(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5859,        212]
NotebookOptionsPosition[      4150,        143]
NotebookOutlinePosition[      5165,        185]
CellTagsIndexPosition[      4966,        175]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Related Rates A Boat Approaching A Dock", "Title",
 CellChangeTimes->{{3.452430927171875*^9, 3.45243093525*^9}}],

Cell["\<\

All related rate demos are going to be in the same call.\
\>", "Text",
 CellChangeTimes->{{3.452950636546875*^9, 3.45295066965625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
A boat is being pulled into a dock by a rope attached 1 meter above the plane \
of the bow. At what speed is the boat approaching the dock at given distances? 
Drag the slider to adjust the distance.
\
\>", "Text"]
}, Open  ]],

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

Very often related rates is used  in the calculation of rates that we can't \
measure, from thouse that we can. This is possible, if a relation among the \
changing variables can be stablished. If this is the case then by appling the \
chain rule to this relation, the unknown rate can be derived from the known \
one.\
\>", "Text",
 CellChangeTimes->{{3.45243122690625*^9, 3.452431297796875*^9}, {
  3.452518001203125*^9, 3.45251820203125*^9}, {3.45295047765625*^9, 
  3.452950503921875*^9}, {3.45295054025*^9, 3.4529505536875*^9}, {
  3.45295059040625*^9, 3.452950615578125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, derivative of a function, rate of change, related rates, chain \
rule, composite function.\
\>", "Text",
 CellChangeTimes->{{3.452518226859375*^9, 3.4525182856875*^9}, 
   3.452518321828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nThe chain rule states that for the composition of the deribvable \
functionsf and g,  f \[SmallCircle]g to form function y(x)=f(g(x)). The \
derivative of function y is given by ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "'"], "(", "x", ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "'"], "(", 
       RowBox[{"g", "(", "x", ")"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["g", "'"], "(", "x", ")"}]}]}],
    FontSize->12], TraditionalForm]], "Subtitle",
  FontSize->14],
 " or in Leibnitz notation by:"
}], "Text",
 CellChangeTimes->{{3.452518339578125*^9, 3.452518369015625*^9}, {
  3.4525184113125*^9, 3.452518499109375*^9}, {3.4525185396875*^9, 
  3.4525186545*^9}, {3.452518744765625*^9, 3.452518746*^9}}],

Cell[TextData[{
 "\n                                                   ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[DifferentialD]", "\[ScriptY]"}], 
      RowBox[{"\[DifferentialD]", "\[ScriptX]"}]], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[DifferentialD]", "\[ScriptF]"}], 
       RowBox[{"\[DifferentialD]", "\[ScriptG]"}]], " ", 
      FractionBox[
       RowBox[{"\[DifferentialD]", "g"}], 
       RowBox[{"\[DifferentialD]", "\[ScriptX]"}]]}]}],
    FontSize->18], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.452518691703125*^9, 3.452518722984375*^9}}],

Cell["\<\

This expression stablihes the relation between the rates of y and g.\
\>", "Text",
 CellChangeTimes->{{3.452518882484375*^9, 3.45251888875*^9}, {
  3.452518953265625*^9, 3.452519019328125*^9}, {3.45251905596875*^9, 
  3.452519084734375*^9}}]
}, Open  ]],

Cell["Applications", "Section",
 CellChangeTimes->{3.452430920640625*^9},
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{331, Automatic}, {Automatic, 2}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[859, 33, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1163, 44, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1250, 49, 59, 1, 41, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1941, 68, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[2256, 82, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[4035, 138, 99, 2, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 4471, 154},
 {"operation", 4549, 157},
 {"briefexp", 4631, 160},
 {"concepts", 4712, 163},
 {"theory", 4791, 166},
 {"aplications", 4873, 169}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 118, 1, 137, "Title"],
Cell[688, 25, 146, 4, 47, "Text"],
Cell[CellGroupData[{
Cell[859, 33, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[924, 36, 224, 5, 83, "Text"]
}, Open  ]],
Cell[1163, 44, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[CellGroupData[{
Cell[1250, 49, 59, 1, 41, "Section",
 CellTags->"briefexp"],
Cell[1312, 52, 592, 11, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1941, 68, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2004, 71, 215, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2256, 82, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2305, 85, 824, 22, 85, "Text"],
Cell[3132, 109, 633, 18, 64, "Text"],
Cell[3768, 129, 252, 6, 47, "Text"]
}, Open  ]],
Cell[4035, 138, 99, 2, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
