(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7487,        265]
NotebookOptionsPosition[      5621,        191]
NotebookOutlinePosition[      6641,        233]
CellTagsIndexPosition[      6442,        223]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Approximating The Derivative  By The Symmetric  Difference Quotient\
\>", "Title",
 CellChangeTimes->{{3.451822664109375*^9, 3.4518226835625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

For the particular function f(xa) = Sin(x), this demo shows the numerical \
aproximation to the value of its derivative by using three diferent \
expressions:\
\>", "Text",
 CellChangeTimes->{{3.451822691296875*^9, 3.451822808578125*^9}, 
   3.451824371796875*^9}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"d", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"a", "+", "d"}], ")"}], "-", 
     RowBox[{"f", "(", "a", ")"}]}], "d"], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.451824155609375*^9, 3.451824181578125*^9}, {
  3.451824219984375*^9, 3.451824244796875*^9}}],

Cell["\<\

with d negative or positive and \
\>", "Text",
 CellChangeTimes->{{3.451822821609375*^9, 3.451822830640625*^9}, {
  3.451823270078125*^9, 3.45182328496875*^9}, {3.45182428559375*^9, 
  3.451824287296875*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"d", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"a", "+", "d"}], ")"}], "-", 
     RowBox[{"f", "(", 
      RowBox[{"a", "-", "d"}], ")"}]}], 
    RowBox[{"2", " ", "d"}]], TraditionalForm]], "Subtitle"],
 " "
}], "Text",
 CellChangeTimes->{{3.45182339984375*^9, 3.45182341834375*^9}, {
  3.451824254890625*^9, 3.45182428025*^9}}],

Cell["\<\

for either positive or negative d.\
\>", "Text",
 CellChangeTimes->{{3.45182348140625*^9, 3.45182350125*^9}, {
  3.45182429396875*^9, 3.45182429534375*^9}}],

Cell["\<\

The demo shows the resulting errors with respect to the actual value of the \
derivative for the three diferent schemes, for different values of a and d.\
\>", "Text",
 CellChangeTimes->{{3.4518235426875*^9, 3.451823637140625*^9}, {
  3.45182367165625*^9, 3.4518236850625*^9}, {3.4518237273125*^9, 
  3.451823756125*^9}, {3.451824299203125*^9, 3.45182431421875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Pay atention to the errors that result for different values of a and d.\
\>", "Text",
 CellChangeTimes->{
  3.45182351834375*^9, {3.451823779328125*^9, 3.45182385753125*^9}, {
   3.451824319265625*^9, 3.45182433134375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

The first two schemes used in the aproximation to the value of the derivative \
corresponds to the value of the slopes of secants drawn through the points \
(a-d,f(a-d)) , (a,f(a)) and (a,f(a)), (a+d,f(a+d)) respectively. The third \
scheme correspond to the value of the secant drawn through the points \
(a-d,f(a-d)) and (a+d,f(a+d)).
In the numerical analysis literature these three schemes are called:   \
backward difference, forward diference and symetric difference. The first two \
are two points approximation to the derivative. The last one is a three point \
aproximation to the derivative.
The last scheme gives a numerical result for the derivative which is an \
average of the first two schemes. This last aproximation has always the least \
error with respect to the exact value of the derivative.\
\>", "Text",
 CellChangeTimes->{{3.4518239111875*^9, 3.451823928890625*^9}, {
   3.45182398365625*^9, 3.451824103734375*^9}, {3.4518243853125*^9, 
   3.45182458121875*^9}, {3.451824701640625*^9, 3.45182482409375*^9}, {
   3.45182487803125*^9, 3.451824934484375*^9}, 3.45182498740625*^9, {
   3.4518256103125*^9, 3.451825630765625*^9}, {3.45182576525*^9, 
   3.451826005578125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, derivative, forward diference, backward difference, symetric \
difference \
\>", "Text",
 CellChangeTimes->{{3.451824613140625*^9, 3.45182466965625*^9}, {
  3.451825641828125*^9, 3.4518256581875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nIn the numerical analysis literature for  numerical diferentiation, it is \
shown that two point aproximation have an associated error which is of order \
d, whereas three point aproximations have error of order",
 StyleBox[" ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->10],
 "."
}], "Text",
 CellChangeTimes->{{3.45182501196875*^9, 3.451825201640625*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{530, Automatic}, {Automatic, 81}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[748, 29, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[3040, 112, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[3376, 126, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[4681, 154, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[5002, 168, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[5549, 187, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 5943, 202},
 {"operation", 6021, 205},
 {"briefexp", 6104, 208},
 {"concepts", 6186, 211},
 {"theory", 6266, 214},
 {"aplications", 6349, 217}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 156, 3, 191, "Title"],
Cell[CellGroupData[{
Cell[748, 29, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[813, 32, 275, 7, 65, "Text"],
Cell[1091, 41, 565, 20, 49, "Text"],
Cell[1659, 63, 219, 6, 47, "Text"],
Cell[1881, 71, 572, 20, 50, "Text"],
Cell[2456, 93, 167, 5, 47, "Text"],
Cell[2626, 100, 377, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3040, 112, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[3105, 115, 234, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3376, 126, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[3438, 129, 1206, 20, 209, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4681, 154, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[4744, 157, 221, 6, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5002, 168, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[5051, 171, 483, 13, 83, "Text"]
}, Open  ]],
Cell[5549, 187, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
