(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8056,        276]
NotebookOptionsPosition[      6122,        200]
NotebookOutlinePosition[      7139,        242]
CellTagsIndexPosition[      6940,        232]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Chain Rule", "Title",
 CellChangeTimes->{3.452000944234375*^9}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

The demo shows 64 examples which can be obtained through the combinations of \
f and g shown in the menu., the window of the display can be adjusted through \
the plot domain and plot range sliders. The point where the derivative is \
calculated is selectod in the x value slider.
The picture shows the graph of the function f \[Degree] g, the cmposition of \
the function f with g, the tangent with it at the selected point and the \
graph of the derivative composite function.\
\>", "Text",
 CellChangeTimes->{{3.452000949515625*^9, 3.452001234203125*^9}, {
  3.452001275609375*^9, 3.452001379234375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

Use the demo to get familiar with how the composition function loos like and \
also to get the graph of the derivative derivative function from the function \
visually.\
\>", "Text",
 CellChangeTimes->{{3.45200139003125*^9, 3.45200152953125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
If functions f and g have derivatives, for the function composition: \
y(x)=f(g(x)), the derivative is given by:\
\>", "Text",
 CellChangeTimes->{{3.452346869140625*^9, 3.452346882140625*^9}, {
  3.4523469213125*^9, 3.452346998421875*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "'"], "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "'"], "(", 
      RowBox[{"g", "(", "x", ")"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["g", "'"], "(", "x", ")"}]}]}], TraditionalForm]], 
  "Subtitle",
  FontSize->14],
 "\n"
}], "Text",
 CellChangeTimes->{{3.4523468214375*^9, 3.45234686603125*^9}, {
  3.452347103109375*^9, 3.45234719178125*^9}, {3.4525187548125*^9, 
  3.452518773328125*^9}}],

Cell["or in Leibitz notation:", "Text",
 CellChangeTimes->{{3.452347227296875*^9, 3.452347246796875*^9}}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[DifferentialD]", "\[ScriptY]"}], 
      RowBox[{"\[DifferentialD]", "\[ScriptX]"}]], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[DifferentialD]", "\[ScriptF]"}], 
       RowBox[{"\[DifferentialD]", "\[ScriptG]"}]], " ", 
      FractionBox[
       RowBox[{"\[DifferentialD]", "g"}], 
       RowBox[{"\[DifferentialD]", "\[ScriptX]"}]]}]}],
    FontSize->18], TraditionalForm]], "Subtitle"]
}], "Text",
 CellChangeTimes->{{3.4523472515625*^9, 3.45234726478125*^9}, {
  3.4523473279375*^9, 3.45234733659375*^9}, {3.45234738459375*^9, 
  3.4523474009375*^9}, {3.452347440390625*^9, 3.45234748546875*^9}}],

Cell["\<\

Intuitible, the chain rule can be thinked in the following way: The quantity \
\>", "Text",
 CellChangeTimes->{
  3.452347509546875*^9, {3.452347591640625*^9, 3.452347681125*^9}}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["g", "'"], "(", "x", ")"}], "=", 
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]], 
     FractionBox["\[CapitalDelta]g", "\[CapitalDelta]x"]}]}], 
   TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->16]
}], "Text",
 CellChangeTimes->{{3.452347695484375*^9, 3.452347734796875*^9}, {
  3.45234777184375*^9, 3.452347840109375*^9}}],

Cell["\<\

is the local quotient in which small intervals are amplified by the \
\"maping\" g. In a similar fashion f '(x) is the amplification given by the \
\"maping\" f. appling first g and then f it is equivalent to amplify an \
interval x first g ' times, and then enlarge the resulting interval g,  f ' \
times given a total quotient of amplification of f ' g ' times, which is the \
total quotinient of amplification for the composed \"maping\" y= f \[Degree]g. 
(The chain rule: Courant and John. in Introduction to calculus and \
mathematical analysis)    \
\>", "Text",
 CellChangeTimes->{{3.452347873296875*^9, 3.452348589265625*^9}, {
  3.4523487305*^9, 3.452348751984375*^9}}],

Cell[TextData[{
 "See also  ",
 ButtonBox["composition of functions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ddmdfbasics"}, "CompositionOfFunctions-text.nb", 
     CharacterEncoding -> "WindowsANSI"], "theory"}]
}], "Text",
 CellChangeTimes->{{3.452002039328125*^9, 3.45200205196875*^9}, {
   3.452002087375*^9, 3.452002087375*^9}, 3.45234661253125*^9, {
   3.452346791515625*^9, 3.452346811390625*^9}, {3.45234861415625*^9, 
   3.45234862403125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\
Functions, derivative of a function, continuous functions, derivable \
functions,tangent, composition of functions and its derivative, chain rule.\
\>", "Text",
 CellChangeTimes->{{3.452001777421875*^9, 3.452001836859375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\
For a proof of this theorem see: The chain rule: Courant and John. in \
Introduction to calculus and mathematical analysis
\
\>", "Text",
 CellChangeTimes->{
  3.45200184653125*^9, {3.452348643328125*^9, 3.452348686203125*^9}}]
}, Open  ]],

Cell["Applications", "Section",
 CellChangeTimes->{3.452348801015625*^9},
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 126}, {Automatic, 9}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[661, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1381, 46, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1740, 60, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[5370, 171, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[5706, 183, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[6007, 195, 99, 2, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6443, 211},
 {"operation", 6521, 214},
 {"briefexp", 6603, 217},
 {"concepts", 6684, 220},
 {"theory", 6764, 223},
 {"aplications", 6847, 226}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 69, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[661, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[726, 30, 618, 11, 119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1381, 46, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1446, 49, 257, 6, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1740, 60, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1802, 63, 249, 5, 47, "Text"],
Cell[2054, 70, 538, 18, 50, "Text"],
Cell[2595, 90, 105, 1, 29, "Text"],
Cell[2703, 93, 728, 20, 61, "Text"],
Cell[3434, 115, 190, 5, 47, "Text"],
Cell[3627, 122, 507, 16, 56, "Text"],
Cell[4137, 140, 689, 12, 137, "Text"],
Cell[4829, 154, 504, 12, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5370, 171, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[5433, 174, 236, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5706, 183, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[5755, 186, 237, 6, 65, "Text"]
}, Open  ]],
Cell[6007, 195, 99, 2, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
