(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7912,        296]
NotebookOptionsPosition[      5944,        219]
NotebookOutlinePosition[      6961,        261]
CellTagsIndexPosition[      6762,        251]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Mean Value Theorem", "Title",
 CellChangeTimes->{{3.451945620015625*^9, 3.4519456221875*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

 The mean value theorem is applied in this demo to the cubic polynomial:\
\>", "Text",
 CellChangeTimes->{{3.451945723203125*^9, 3.451945805046875*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "3"], 
       SuperscriptBox["x", "3"]}], " ", "+", 
      RowBox[{
       SubscriptBox["c", "2"], 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SubscriptBox["c", "1"], "x"}], " ", "+", 
      SubscriptBox["c", "0"]}]}],
    FontSize->16], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.451945812171875*^9, 3.4519458734375*^9}, {
  3.451945908546875*^9, 3.4519460575625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell[TextData[{
 "\nThe shape of the curve is defined by the  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "3"], ",", 
    SubscriptBox["c", "2"], ",", 
    SubscriptBox["c", "1"], ",", 
    SubscriptBox["c", "0"]}], TraditionalForm]], "Subtitle",
  FontSize->16],
 " coeficients of the cubic polynomial f. The interval of interest is (c,a). \
By adjusting all these values, it is seen that the mvt always hold."
}], "Text",
 CellChangeTimes->{{3.45194616490625*^9, 3.4519464555*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Functions, derivative of a function, continuous functions, derivable \
functions,tangent,average rate of change, instantaneous rate of change, \
Roolle's theorem.\
\>", "Text",
 CellChangeTimes->{{3.451989657703125*^9, 3.451989829125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\

Let f be a differentiable function on (a,b) and continuous in [a,b], then \
there is at least a point c in (a,b) such that:\
\>", "Text",
 CellChangeTimes->{{3.45194380728125*^9, 3.451943895171875*^9}}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SuperscriptBox["f", "'"], "(", "c", ")"}],
    FontSize->18], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", "b", ")"}], "-", 
     RowBox[{"f", "(", "a", ")"}]}], 
    RowBox[{"b", "-", "a"}]], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->24]
}], "Text",
 CellChangeTimes->{
  3.451944016703125*^9, {3.451944075265625*^9, 3.451944169875*^9}}],

Cell["\<\

The proof of the mean value theorem follows from the following theorem:\
\>", "Text",
 CellChangeTimes->{{3.451944593734375*^9, 3.45194468028125*^9}, {
  3.451945761046875*^9, 3.451945762734375*^9}}],

Cell["\<\

Rolle's Theorem: \
\>", "Text",
 CellChangeTimes->{{3.451944685484375*^9, 3.451944705484375*^9}}],

Cell[TextData[{
 "Let g be a differentiable function on (a,b) and continuous in [a,b], if \
g(a) g(b) =0, then there exists at least a point \[Xi] \[Epsilon] (a,b) such \
that  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["g", "'"], "(", "\[Xi]", ")"}], " ", "=", " ", "0"}],
    FontSize->14], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->16]
}], "Text",
 CellChangeTimes->{{3.45194473803125*^9, 3.451944955859375*^9}}],

Cell["\<\

In order to prove the mean value theorem, consider  the function:\
\>", "Text",
 CellChangeTimes->{{3.451945045375*^9, 3.4519451268125*^9}}],

Cell[TextData[{
 "\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], "-", 
     RowBox[{"f", "(", "a", ")"}], "-", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "(", "b", ")"}], "-", 
        RowBox[{"f", "(", "a", ")"}]}], 
       RowBox[{"b", "-", "a"}]], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "a"}], ")"}]}]}]}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->16]
}], "Text",
 CellChangeTimes->{
  3.45194513196875*^9, {3.451945168484375*^9, 3.451945261875*^9}, {
   3.4519453485625*^9, 3.451945376734375*^9}}],

Cell["\<\

g(x) is the vertical distance from the point (x,f(x)) to its secant. The \
function g satisfies the Rolle's theoremin \[Xi]=c. The mvt follows from \
Rolle's theoremby appling it to g.  \
\>", "Text",
 CellChangeTimes->{{3.451945393046875*^9, 3.451945454140625*^9}, {
  3.451945524203125*^9, 3.451945546515625*^9}, {3.451945585546875*^9, 
  3.451945602390625*^9}, {3.451990954*^9, 3.45199105034375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aplications", "Section",
 CellTags->"aplications"],

Cell["\<\

One of the applications is learning about the function through the knowledge \
of the derivative behaviour, One example of it is to know if a function in \
certain interval is increasing or decreasing.\
\>", "Text",
 CellChangeTimes->{{3.451990533140625*^9, 3.451990552890625*^9}, {
  3.451990814390625*^9, 3.45199092340625*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 370}, {Automatic, 52}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[691, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1573, 62, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[2155, 81, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2239, 86, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[2589, 100, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[5517, 205, 56, 1, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6266, 230},
 {"operation", 6344, 233},
 {"briefexp", 6426, 236},
 {"concepts", 6507, 239},
 {"theory", 6586, 242},
 {"aplications", 6669, 245}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[691, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[756, 30, 163, 4, 47, "Text"],
Cell[922, 36, 614, 21, 52, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1573, 62, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1638, 65, 502, 13, 68, "Text"]
}, Open  ]],
Cell[2155, 81, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[2239, 86, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[2302, 89, 250, 6, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2589, 100, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2638, 103, 213, 5, 65, "Text"],
Cell[2854, 110, 558, 21, 67, "Text"],
Cell[3415, 133, 210, 5, 47, "Text"],
Cell[3628, 140, 108, 4, 47, "Text"],
Cell[3739, 146, 496, 14, 50, "Text"],
Cell[4238, 162, 151, 4, 47, "Text"],
Cell[4392, 168, 671, 22, 59, "Text"],
Cell[5066, 192, 414, 8, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5517, 205, 56, 1, 71, "Section",
 CellTags->"aplications"],
Cell[5576, 208, 340, 7, 65, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
