(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6594,        239]
NotebookOptionsPosition[      4845,        167]
NotebookOutlinePosition[      5863,        209]
CellTagsIndexPosition[      5664,        199]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Tangent To A Curve", "Title",
 CellChangeTimes->{{3.451754983890625*^9, 3.451754987296875*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "\nThe demo shows the plot of a cubic polynomial p = a x^3 + b x^2 + c x and \
a tangent to the graph of p at point ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.45175519115625*^9, 3.451755309125*^9}, {
   3.451755354234375*^9, 3.451755355*^9}, 3.4517553898125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell[TextData[{
 "\nPlay with the values of the coeficients a, b and c, it is worth to get \
familiar with the effect they produce in the shape of the graph of p. The \
value of ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 " selects the point (",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ",p(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ") where the tangent is drawn. For a given shape of the graph of p, the \
slope of the tangent depends upon ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 ". It is also worth to look at how fast this slope changes wit changes in ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->12], TraditionalForm]], "Subtitle"],
 "."
}], "Text",
 CellChangeTimes->{{3.45175539525*^9, 3.451755776828125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

A tangent to a curve in a given point, is a stright line through it which \
only touches the curve at this point and it does not touch any other point of \
the curve in a given neighborhood of this point\
\>", "Text",
 CellChangeTimes->{{3.451755799609375*^9, 3.45175594703125*^9}, {
  3.451756005171875*^9, 3.451756059203125*^9}, {3.451756956609375*^9, 
  3.451756960609375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Stright line, curve, tangent, tangency point, graph of a function\
\>", "Text",
 CellChangeTimes->{{3.4517569760625*^9, 3.451757034921875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nFinding a tangent to a graph of a function which defines a curve requires \
the definition of the ",
 ButtonBox["derivative of a function",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[
       ParentDirectory[]], "demons", "kmderivatives"}, 
     "TheDefinitionOfTheDerivative-source.nb", CharacterEncoding -> 
     "WindowsANSI"], None}],
 ", ",
 ButtonBox["see also the demos.\n",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[
       ParentDirectory[]], "demons", "kmderivatives"}, 
     "TangentLineUsingManyDifferentLimitConfigurations-source.nb", 
     CharacterEncoding -> "WindowsANSI"], None}],
 "The task of calculating a tangent to a graphof a function is one of the \
main goals of diferential calculus of one variable and is central to the \
understanding of the derivative and diferential of a function."
}], "Text",
 CellChangeTimes->{
  3.451757114875*^9, {3.4517571675*^9, 3.45175724771875*^9}, {
   3.4517574799375*^9, 3.451757560078125*^9}, {3.451757617421875*^9, 
   3.451757617421875*^9}, {3.451757822109375*^9, 3.451757824828125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aplications", "Section",
 CellTags->"aplications"],

Cell["\<\
It is often needed in geometry, but applications are found in a lot of the \
fields where differential calculus concepts  are used.\
\>", "Text",
 CellChangeTimes->{{3.451757640546875*^9, 3.451757729859375*^9}, {
  3.451757775328125*^9, 3.45175786184375*^9}, {3.4517578950625*^9, 
  3.45175798003125*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{530, Automatic}, {Automatic, 81}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[693, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[4443, 154, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[2452, 91, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2942, 107, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1233, 47, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[3196, 119, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 5167, 178},
 {"aplications", 5247, 181},
 {"briefexp", 5332, 184},
 {"concepts", 5413, 187},
 {"operation", 5496, 190},
 {"theory", 5576, 193}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[693, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[758, 30, 438, 12, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1233, 47, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1298, 50, 1117, 36, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2452, 91, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[2514, 94, 391, 8, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2942, 107, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[3005, 110, 154, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3196, 119, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[3245, 122, 1161, 27, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4443, 154, 56, 1, 71, "Section",
 CellTags->"aplications"],
Cell[4502, 157, 315, 6, 47, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
