(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8494,        285]
NotebookOptionsPosition[      6748,        214]
NotebookOutlinePosition[      7763,        256]
CellTagsIndexPosition[      7564,        246]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Definition Of The Derivative", "Title",
 CellChangeTimes->{{3.451764579875*^9, 3.451764585765625*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell[TextData[{
 "\nThis demo shows the particular example of the value of the derivative of \
the function f[x] = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox["x"],
    FontSize->10], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 " at the point (1,f(1)) =(1,1), which turns out to be the slope of the \
tangent line to the graph of this function at (1,1). This tangent is also the \
limit of the secants lines drawn through the point (1,1) and (x,f(x)), where \
the value of x approaches 1."
}], "Text",
 CellChangeTimes->{{3.45176459665625*^9, 3.451764621109375*^9}, {
  3.45176465771875*^9, 3.451765007078125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

The blue point is a locator which can be moved following the graph of the \
graph of the function. It defines a point through which the secant line \
passes.\
\>", "Text",
 CellChangeTimes->{{3.451765011625*^9, 3.4517653570625*^9}, {
  3.451765397421875*^9, 3.4517654064375*^9}, {3.451765441046875*^9, 
  3.451765572171875*^9}, {3.451765633734375*^9, 3.451765699375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
The blue point  defines the point  (x,f(x))  through which the secant lines \
passes through. As the blue point approaches the red point, the slope of the  \
secant line get closer to the value of the derivative of the function at x=1.\
\>", "Text",
 CellChangeTimes->{{3.451765565*^9, 3.4517656125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Secant line, tangent line, graph of a function, plane curve,limit of a \
function, limit of a secuence of real values.\
\>", "Text",
 CellChangeTimes->{
  3.451765728859375*^9, 3.451765768125*^9, {3.452519743921875*^9, 
   3.45251975134375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\nGiven a real valued function with real values: f: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->16],
 "\[Subset]\[DoubleStruckCapitalR]\[RightArrow]\[DoubleStruckCapitalR], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]], "Subtitle",
  FontSize->16],
 " the domain of f.  Then if "
}], "Text",
 CellChangeTimes->{{3.451765784015625*^9, 3.451765895765625*^9}, {
   3.45176598690625*^9, 3.451765986921875*^9}, {3.45176601815625*^9, 
   3.451766130390625*^9}, {3.451767211609375*^9, 3.451767211609375*^9}, 
   3.451820113109375*^9}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
      ")"}], "-", 
     RowBox[{"f", "(", 
      SubscriptBox["\[ScriptX]", "0"], ")"}]}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle"],
 " \n"
}], "Text",
 CellChangeTimes->{{3.45176620496875*^9, 3.451766215875*^9}, {
  3.45176624746875*^9, 3.4517663666875*^9}, {3.451766409609375*^9, 
  3.451766419296875*^9}, {3.451819684140625*^9, 3.45181973371875*^9}}],

Cell[TextData[{
 "\ndo exists for  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptX]", "0"], TraditionalForm]], "Subtitle",
  FontSize->16],
 StyleBox[" ",
  FontSize->16],
 "\[Epsilon] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]],
  FontSize->16],
 ", then the value of this limit is called the derivative of the function f \
at ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 " and it is writen as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", "'"], TraditionalForm]], "Subtitle",
  FontSize->16],
 "(",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[ScriptX]", "0"],
    FontSize->16], TraditionalForm]], "Subtitle"],
 ") or alternatively as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{
      FractionBox["\[DifferentialD]", 
       RowBox[{"\[DifferentialD]", "\[ScriptX]"}]], "f"}],
     FontSize->16], 
    SubscriptBox["\[VerticalSeparator]", 
     StyleBox[
      SubscriptBox["\[ScriptX]", "0"],
      FontSize->10]]}], TraditionalForm]], "Subtitle"],
 ".\nIf the previus limit exists for every \[ScriptX] \[Epsilon] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalD]", "f"], TraditionalForm]],
  FontSize->16],
 ", then this limit is simply called the derivative of the function f.\nThe \
derivative of a function is in itself a new function, so it is posible to \
talk about the derivative of the derivative if the above limit exists for the \
so called first derivative  and so on  ie. these are called the higher order \
derivatives of the function."
}], "Text",
 CellChangeTimes->{{3.45176642715625*^9, 3.451766434390625*^9}, {
   3.451766495140625*^9, 3.451766753296875*^9}, {3.451766815578125*^9, 
   3.451766847390625*^9}, 3.451766887625*^9, {3.451766919109375*^9, 
   3.45176692196875*^9}, {3.451767271515625*^9, 3.451767313875*^9}, {
   3.451819752015625*^9, 3.451819819921875*^9}, {3.451819853015625*^9, 
   3.451819879078125*^9}, 3.45182016590625*^9, {3.45182020475*^9, 
   3.451820315140625*^9}, {3.452515924703125*^9, 3.45251593028125*^9}, {
   3.4525159651875*^9, 3.452516018515625*^9}, {3.452516060171875*^9, 
   3.452516067796875*^9}, {3.45251610865625*^9, 3.452516131875*^9}, {
   3.452517644625*^9, 3.452517667390625*^9}, {3.452517699765625*^9, 
   3.452517840078125*^9}, {3.452517873625*^9, 3.4525179089375*^9}}]
}, Open  ]],

Cell["Applications", "Section",
 CellChangeTimes->{3.452517937265625*^9},
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{521, Automatic}, {Automatic, 6}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[704, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "operation"->{
  Cell[1452, 50, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "briefexp"->{
  Cell[1936, 66, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2349, 79, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "theory"->{
  Cell[2705, 94, 46, 1, 71, "Section",
   CellTags->"theory"]},
 "aplications"->{
  Cell[6633, 209, 99, 2, 71, "Section",
   CellTags->"aplications"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 7069, 225},
 {"operation", 7147, 228},
 {"briefexp", 7229, 231},
 {"concepts", 7310, 234},
 {"theory", 7389, 237},
 {"aplications", 7471, 240}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 112, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[704, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[769, 30, 646, 15, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1452, 50, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1517, 53, 382, 8, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1936, 66, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1998, 69, 314, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2349, 79, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2412, 82, 256, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2705, 94, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2754, 97, 660, 16, 50, "Text"],
Cell[3417, 115, 767, 24, 86, "Text"],
Cell[4187, 141, 2431, 65, 183, "Text"]
}, Open  ]],
Cell[6633, 209, 99, 2, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
