(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15689,        574]
NotebookOptionsPosition[     13549,        494]
NotebookOutlinePosition[     14572,        536]
CellTagsIndexPosition[     14367,        526]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Product Rule", "Title",
 CellChangeTimes->{{3.451851398953125*^9, 3.45185140121875*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

This demo calculates the derivative of the product of two functions f and g. \
It also shows the graph of each, their product and its derivative\
\>", "Text",
 CellChangeTimes->{{3.45185140653125*^9, 3.451851471625*^9}, {
  3.451851578875*^9, 3.451851661796875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\

There are 144 products f g obtained through the combinations of f and g. It \
is worth tring to get familiar with the individual graphs of the functions f \
and g, their product and its derivative. \
\>", "Text",
 CellChangeTimes->{
  3.451851681671875*^9, {3.4518517274375*^9, 3.451851872484375*^9}, {
   3.4518572866875*^9, 3.451857308546875*^9}}]
}, Open  ]],

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Functions, derivatives, trigonometric functions, exponential and logaritmic \
functions, derivative of the product of two functions.\
\>", "Text",
 CellChangeTimes->{{3.451851888421875*^9, 3.451852001078125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\

Given two derivable funcitons f and g. The rule that gives us the derivative \
of their product is derived in the following way.
The derivative of a function f is defined through the existence of \
\>", "Text",
 CellChangeTimes->{{3.451852009578125*^9, 3.451852125375*^9}, {
  3.45185402953125*^9, 3.451854077265625*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
      ")"}], "-", 
     RowBox[{"f", "(", 
      SubscriptBox["\[ScriptX]", "0"], ")"}]}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle"],
 " "
}], "Text"],

Cell["\<\
For the case of the product of two functions f and g, this expressions is \
cast into the form:\
\>", "Text",
 CellChangeTimes->{{3.451854132734375*^9, 3.451854196859375*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f", " ", "g"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
       ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f", " ", "g"}], ")"}], 
      RowBox[{"(", 
       SubscriptBox["\[ScriptX]", "0"], ")"}]}]}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle"],
 " \n\n =",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->18], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"f", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
       ")"}], " ", 
      RowBox[{"g", "(", 
       RowBox[{
        SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
       ")"}]}], "-", 
     RowBox[{
      RowBox[{"f", "(", 
       SubscriptBox["\[ScriptX]", "0"], ")"}], 
      RowBox[{"g", "(", 
       SubscriptBox["\[ScriptX]", "0"], ")"}]}]}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle"]
}], "Text",
 CellChangeTimes->{{3.451854235046875*^9, 3.45185439190625*^9}, {
   3.451854450875*^9, 3.45185449834375*^9}, 3.45185468909375*^9}],

Cell[TextData[{
 "\nAdding and substraning f",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"(", 
     SubscriptBox["\[ScriptX]", "0"], ")"}], " ", "g", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
     ")"}]}]}]]],
 " to the denominator"
}], "Text",
 CellChangeTimes->{{3.45185451371875*^9, 3.45185452771875*^9}, {
  3.4518545751875*^9, 3.451854599671875*^9}}],

Cell[TextData[{
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->12], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FractionBox["1", "\[CapitalDelta]x"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}],
          ")"}], " ", 
        RowBox[{"g", "(", 
         RowBox[{
          SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}],
          ")"}]}], "+", 
       RowBox[{"f", " ", 
        RowBox[{"(", 
         SubscriptBox["\[ScriptX]", "0"], ")"}], " ", 
        RowBox[{"g", "(", 
         RowBox[{
          SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}],
          ")"}]}], "-", 
       RowBox[{"f", " ", 
        RowBox[{"(", 
         SubscriptBox["\[ScriptX]", "0"], ")"}], " ", 
        RowBox[{"g", "(", 
         RowBox[{
          SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}],
          ")"}]}], "-", 
       RowBox[{
        RowBox[{"f", "(", 
         SubscriptBox["\[ScriptX]", "0"], ")"}], 
        RowBox[{"g", "(", 
         SubscriptBox["\[ScriptX]", "0"], ")"}]}]}], ")"}]}],
    FontSize->12], TraditionalForm]], "Subtitle",
  FontSize->36]
}], "Text",
 CellChangeTimes->{{3.45185471040625*^9, 3.4518547530625*^9}, {
   3.451854783515625*^9, 3.451854790890625*^9}, {3.4518551694375*^9, 
   3.451855177046875*^9}, 3.451856209515625*^9}],

Cell[TextData[{
 "\nCollecting the terms ",
 Cell[BoxData[
  RowBox[{"f", " ", 
   RowBox[{"(", 
    SubscriptBox["\[ScriptX]", "0"], ")"}]}]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", 
    RowBox[{
     SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
    ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.451854881203125*^9, 3.45185493084375*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->14], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[ScriptX]", "0"], "+", 
            "\[CapitalDelta]\[ScriptX]"}], ")"}]}], "-", 
         RowBox[{"f", "(", 
          SubscriptBox["\[ScriptX]", "0"], ")"}]}], ")"}], " ", 
       RowBox[{"g", "(", 
        RowBox[{
         SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"f", "(", 
        SubscriptBox["\[ScriptX]", "0"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"g", "(", 
          RowBox[{
           SubscriptBox["\[ScriptX]", "0"], "+", 
           "\[CapitalDelta]\[ScriptX]"}], ")"}], "-", 
         RowBox[{"g", "(", 
          SubscriptBox["\[ScriptX]", "0"], ")"}]}], ")"}]}]}], 
     "\[CapitalDelta]x"],
    FontSize->18], TraditionalForm]], "Subtitle"]
}], "Text",
 CellChangeTimes->{{3.451855027375*^9, 3.451855047359375*^9}, {
  3.451855081625*^9, 3.4518551038125*^9}}],

Cell["\<\

Apling the usual rules for limits and since \
\>", "Text",
 CellChangeTimes->{{3.45185520525*^9, 3.45185520978125*^9}, {
  3.451855340359375*^9, 3.4518553478125*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["lim", 
     RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
    FontSize->16], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", 
    RowBox[{
     SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
    ")"}], TraditionalForm]],
  FontSize->14],
 " =",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", 
    SubscriptBox["\[ScriptX]", "0"], ")"}], TraditionalForm]],
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.451855225765625*^9, 3.4518552548125*^9}, {
   3.4518553915625*^9, 3.451855408390625*^9}, 3.451855474171875*^9, 
   3.45185743421875*^9}],

Cell["\<\

We arrive at the result\
\>", "Text",
 CellChangeTimes->{{3.45185526571875*^9, 3.45185533678125*^9}, {
  3.45185548471875*^9, 3.451855497078125*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"g", "(", 
     SubscriptBox["\[ScriptX]", "0"], ")"}],
    FontSize->16], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->14], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[ScriptX]", "0"], "+", 
           "\[CapitalDelta]\[ScriptX]"}], ")"}]}], "-", 
        RowBox[{"f", "(", 
         SubscriptBox["\[ScriptX]", "0"], ")"}]}], ")"}], " "}], 
     "\[CapitalDelta]x"],
    FontSize->18], TraditionalForm]], "Subtitle"],
 "+",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"f", "(", 
     SubscriptBox["\[ScriptX]", "0"], ")"}],
    FontSize->16], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox["lim", 
      RowBox[{"\[CapitalDelta]\[ScriptX]", "\[RightArrow]", "0"}]],
     FontSize->14], " "}], TraditionalForm]], "Subtitle"],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"g", "(", 
       RowBox[{
        SubscriptBox["\[ScriptX]", "0"], "+", "\[CapitalDelta]\[ScriptX]"}], 
       ")"}], "-", 
      RowBox[{"g", "(", 
       SubscriptBox["\[ScriptX]", "0"], ")"}]}], ")"}], "\[CapitalDelta]x"], 
   TraditionalForm]], "Subtitle",
  FontSize->18]
}], "Text",
 CellChangeTimes->{{3.4518555350625*^9, 3.45185555040625*^9}, {
  3.4518555814375*^9, 3.451855605234375*^9}, {3.451855637203125*^9, 
  3.451855681203125*^9}, {3.451857210625*^9, 3.4518572288125*^9}}],

Cell[TextData[{
 "\n=",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"g", "(", 
     SubscriptBox["\[ScriptX]", "0"], ")"}],
    FontSize->14], TraditionalForm]]],
 StyleBox[" ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SuperscriptBox["f", "'"], "(", 
     SubscriptBox["\[ScriptX]", "0"], ")"}],
    FontSize->12], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->36],
 " + f(",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], ")"}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->12],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", "'"], "(", 
    SubscriptBox["x", "0"], ")"}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->12]
}], "Text",
 CellChangeTimes->{{3.451855702078125*^9, 3.4518557040625*^9}, {
  3.45185573534375*^9, 3.451855737484375*^9}, {3.45185587353125*^9, 
  3.45185597453125*^9}, {3.451856008453125*^9, 3.4518560185625*^9}, {
  3.4518560638125*^9, 3.4518561315625*^9}}],

Cell["\<\

Then we have the usual rule for the derivative of the product of the \
functions f and g:\
\>", "Text",
 CellChangeTimes->{{3.4518563060625*^9, 3.451856354109375*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"f", " ", "g"}], ")"}], "'"],
    FontSize->18], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 StyleBox["(\[ScriptX]) ",
  FontSize->18],
 "= ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SuperscriptBox["f", "'"], "(", "x", ")"}],
    FontSize->18], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm"],
 StyleBox[" ",
  FontSize->24],
 StyleBox["g(x)",
  FontSize->18],
 "+ ",
 StyleBox["f(",
  FontSize->18],
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ")"}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->18],
 StyleBox[" ",
  FontSize->18],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", "'"], "(", "x", ")"}], TraditionalForm]], "Subtitle",
  FormatType->"TraditionalForm",
  FontSize->18]
}], "Text",
 CellChangeTimes->{{3.451857546421875*^9, 3.45185758946875*^9}}]
}, Open  ]],

Cell["Aplications", "Section",
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{530, Automatic}, {Automatic, 81}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[690, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[13477, 490, 56, 1, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1509, 55, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1593, 60, 60, 1, 41, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1069, 41, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[1916, 73, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 13871, 505},
 {"aplications", 13951, 508},
 {"briefexp", 14037, 511},
 {"concepts", 14118, 514},
 {"operation", 14200, 517},
 {"theory", 14280, 520}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 98, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[690, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[755, 30, 277, 6, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1069, 41, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1134, 44, 360, 8, 65, "Text"]
}, Open  ]],
Cell[1509, 55, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[CellGroupData[{
Cell[1593, 60, 60, 1, 41, "Section",
 CellTags->"concepts"],
Cell[1656, 63, 223, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1916, 73, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[1965, 76, 332, 7, 83, "Text"],
Cell[2300, 85, 556, 20, 50, "Text"],
Cell[2859, 107, 185, 4, 29, "Text"],
Cell[3047, 113, 1621, 54, 107, "Text"],
Cell[4671, 169, 435, 14, 47, "Text"],
Cell[5109, 185, 1620, 49, 45, "Text"],
Cell[6732, 236, 397, 14, 47, "Text"],
Cell[7132, 252, 1329, 42, 45, "Text"],
Cell[8464, 296, 177, 5, 47, "Text"],
Cell[8644, 303, 679, 24, 33, "Text"],
Cell[9326, 329, 160, 5, 47, "Text"],
Cell[9489, 336, 1765, 62, 45, "Text"],
Cell[11257, 400, 1054, 38, 49, "Text"],
Cell[12314, 440, 178, 5, 47, "Text"],
Cell[12495, 447, 967, 40, 41, "Text"]
}, Open  ]],
Cell[13477, 490, 56, 1, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
