(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8806,        326]
NotebookOptionsPosition[      6694,        245]
NotebookOutlinePosition[      7709,        287]
CellTagsIndexPosition[      7510,        277]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Osculating Circles", "Title",
 CellChangeTimes->{3.452520487453125*^9}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\

The demo shows the circle of best fit or osculationg circle, to the graph of \
three common functions.\
\>", "Text",
 CellChangeTimes->{{3.452520573984375*^9, 3.452520688953125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\
 Slide the marker along the x-axis to move the tangency point on the curve. \
Choose among polynomial, trigonometric, and logarithmic functions.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\
For a given point on the graph of a function, a circle with tangency and \
matching curvature is known as either the circle of best fit or the \
osculating circle.
The calculation of the osculating circle to the graph of a function is a \
relatively advanced subjet. It is shown in this text just with the purpose of \
ilustrating the concept of inflection point on the graph of a function whis \
is highly smooth. It rquires that the function have a continuos second order \
derivative\
\>", "Text",
 CellChangeTimes->{{3.452520993359375*^9, 3.452521001515625*^9}, {
  3.45252108059375*^9, 3.452521240171875*^9}, {3.452521276*^9, 
  3.452521344640625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell["\<\

Function, graph of a function, curvature at a given point on the graph of a \
function, radius of curvature, first and second order derivatives of a \
function, osculating circle\
\>", "Text",
 CellChangeTimes->{{3.452520715203125*^9, 3.4525207770625*^9}, {
  3.45252083603125*^9, 3.45252091759375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell["\<\

If the curve defined by function f is parametrized as:\
\>", "Text",
 CellChangeTimes->{{3.45254586096875*^9, 3.452545914234375*^9}}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", "t"}], ";"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"y", "(", "t", ")"}], "=", 
    RowBox[{"f", "(", "t", ")"}]}], ";"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"r", "(", "t", ")"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "(", "t", ")"}], ",", 
      RowBox[{"y", "(", "t", ")"}]}], "}"}]}], ";"}], 
  TraditionalForm]}], "Text",
 CellChangeTimes->{{3.45254597796875*^9, 3.45254600596875*^9}}],

Cell["\<\

The curvature at a point (x(t),y(t)) of the graph of f is given by the \
expresion\
\>", "Text",
 CellChangeTimes->{{3.452545361921875*^9, 3.452545435546875*^9}, {
  3.4525460571875*^9, 3.4525460656875*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"curvature", "(", "t", ")"}], "=", 
   FractionBox[
    TemplateBox[{TagBox[
       RowBox[{
         FractionBox["\[PartialD]", 
          RowBox[{"\[PartialD]", "t"}]], 
         FractionBox[
          RowBox[{"\[PartialD]", 
            RowBox[{"y", "(", "t", ")"}]}], 
          RowBox[{"\[PartialD]", "t"}], MultilineFunction -> None]}], D]},
     "Abs"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[PartialD]", 
           RowBox[{"y", "(", "t", ")"}]}], 
          RowBox[{"\[PartialD]", "t"}],
          MultilineFunction->None], ")"}], "2"], "+", "1"}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], TraditionalForm]], "Text",
 CellChangeTimes->{3.452546077765625*^9}],

Cell["\<\
the radius of the osculating circle is given by the inverse of the curvature.\
\>", "Text",
 CellChangeTimes->{{3.45254550334375*^9, 3.452545586703125*^9}}],

Cell["\<\

A normalized tangent vector is given by\
\>", "Text",
 CellChangeTimes->{{3.452546109890625*^9, 3.4525461285*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"T", "(", "t", ")"}], "=", 
   FractionBox[
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"r", "(", "t", ")"}]}], 
     RowBox[{"\[PartialD]", "t"}],
     MultilineFunction->None], 
    SqrtBox[
     RowBox[{
      FractionBox[
       RowBox[{"\[PartialD]", 
        RowBox[{"r", "(", "t", ")"}]}], 
       RowBox[{"\[PartialD]", "t"}],
       MultilineFunction->None], ".", 
      FractionBox[
       RowBox[{"\[PartialD]", 
        RowBox[{"r", "(", "t", ")"}]}], 
       RowBox[{"\[PartialD]", "t"}],
       MultilineFunction->None]}]]]}], TraditionalForm]], "Text",
 CellChangeTimes->{3.452520977609375*^9, 3.452545787078125*^9, 
  3.452546085765625*^9}],

Cell["\<\

An a normal vector to the curve at point  (x(t),y(t)) is\
\>", "Text",
 CellChangeTimes->{{3.452546141125*^9, 3.452546169453125*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Tprime", "(", "t", ")"}], "=", 
   FractionBox[
    RowBox[{"\[PartialD]", 
     RowBox[{"T", "(", "t", ")"}]}], 
    RowBox[{"\[PartialD]", "t"}],
    MultilineFunction->None]}], TraditionalForm]], "Text",
 CellChangeTimes->{3.452546097609375*^9}],

Cell["\<\

At t= m  this is normalized as\
\>", "Text",
 CellChangeTimes->{{3.452546201265625*^9, 3.45254621559375*^9}, {
  3.452546460015625*^9, 3.452546471359375*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"NNN", "=", 
    FractionBox[
     RowBox[{"Tprime", "(", "m", ")"}], 
     SqrtBox[
      RowBox[{
       RowBox[{"Tprime", "(", "m", ")"}], ".", 
       RowBox[{"Tprime", "(", "m", ")"}]}]]]}], "]"}], 
  TraditionalForm]], "Text",
 CellChangeTimes->{3.452546190171875*^9}],

Cell["\<\

Then the osculating circle can be draw with center in \
\>", "Text",
 CellChangeTimes->{{3.452546274578125*^9, 3.452546303359375*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"center", "=", 
   RowBox[{
    RowBox[{"NNN", "  ", 
     RowBox[{"radius", "(", "m", ")"}]}], "+", 
    RowBox[{"r", "(", "m", ")"}]}]}], TraditionalForm]], "Text",
 CellChangeTimes->{3.45254634109375*^9}]
}, Open  ]],

Cell["Applications", "Section",
 CellChangeTimes->{3.452520595984375*^9},
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{530, Automatic}, {Automatic, 81}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[669, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[6579, 240, 99, 2, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1234, 51, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[2000, 71, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[964, 40, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[2414, 86, 46, 1, 71, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 7016, 256},
 {"aplications", 7096, 259},
 {"briefexp", 7181, 262},
 {"concepts", 7262, 265},
 {"operation", 7344, 268},
 {"theory", 7423, 271}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 77, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[669, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[734, 30, 193, 5, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[964, 40, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1029, 43, 168, 3, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1234, 51, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1296, 54, 667, 12, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2000, 71, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[2063, 74, 314, 7, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2414, 86, 46, 1, 71, "Section",
 CellTags->"theory"],
Cell[2463, 89, 144, 4, 47, "Text"],
Cell[2610, 95, 562, 19, 68, "Text"],
Cell[3175, 116, 218, 6, 47, "Text"],
Cell[3396, 124, 818, 25, 72, "Text"],
Cell[4217, 151, 166, 3, 29, "Text"],
Cell[4386, 156, 125, 4, 47, "Text"],
Cell[4514, 162, 718, 23, 82, "Text"],
Cell[5235, 187, 144, 4, 47, "Text"],
Cell[5382, 193, 295, 9, 47, "Text"],
Cell[5680, 204, 169, 5, 47, "Text"],
Cell[5852, 211, 320, 11, 58, "Text"],
Cell[6175, 224, 145, 4, 47, "Text"],
Cell[6323, 230, 241, 7, 29, "Text"]
}, Open  ]],
Cell[6579, 240, 99, 2, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
