(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7497,        205]
NotebookOptionsPosition[      5896,        139]
NotebookOutlinePosition[      6913,        181]
CellTagsIndexPosition[      6714,        171]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Global Extrema On An Interval", "Title",
 CellChangeTimes->{{3.452964373796875*^9, 3.452964378734375*^9}}],

Cell[CellGroupData[{

Cell["What this demo is about", "Section",
 CellTags->"about"],

Cell["\<\
This Demonstration shows that the global extrema on an interval are located \
at either the local extrema or at the endpoints. .
\
\>", "Text",
 CellChangeTimes->{3.452964412578125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggested operation", "Section",
 CellTags->"operation"],

Cell["\<\
Move the boundaries to either include or exclude the local extrema for the \
desired interval. Values of the global extrema on the interval can be shown \
or hidden and updated with sliders\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brief explanation", "Section",
 CellTags->"briefexp"],

Cell["\<\

Function, domain of a function, continuous function, derivable function, \
extreme values, local or global maximum or minimum, \
\>", "Text",
 CellChangeTimes->{{3.452964445140625*^9, 3.452964533578125*^9}}]
}, Open  ]],

Cell["Important concepts", "Section",
 CellTags->"concepts"],

Cell[CellGroupData[{

Cell["Theory", "Section",
 CellTags->"theory"],

Cell[TextData[{
 "\n1. Definition: A function f : \[CapitalDifferentialD] \[Subset] \
\[DoubleStruckCapitalR] \[RightArrow]\[DoubleStruckCapitalR] has an absolute \
maximun (or global maximum) at c fi f(c) \[GreaterSlantEqual] f(x) for all x \
\[Epsilon] \[CapitalDifferentialD] , \[CapitalDifferentialD] the domain of f. \
The number f(c) is called the maximum value of f on \[CapitalDifferentialD]. \
Similarly, f has an absolute minimum at c if f(c) \[LessSlantEqual] f(x) for \
all  x\[Epsilon]  \[CapitalDifferentialD] and the number f(c) is called the \
mimimum value of f on \[CapitalDifferentialD]. The maximum and minimum values \
of f on \[CapitalDifferentialD] are called the extreme values of f on \
\[CapitalDifferentialD].\n\n2. Definition: A function f has a local maximum( \
or relative maximum) at c if f(c) \[GreaterSlantEqual] f(x) when x is near c  \
ie. for all x in some open interval containing c.. Similarloy, f has a local \
minimum at c if f(c)\[LessSlantEqual] f(x) when x is near c.\n\n3. The \
extreme value theorem. If f is continuous on a closed interval [a,b], then f \
attains a maximum value f(c) and an absolute minimum f(d) at some numbers c \
and d in [a,b].\n\n4. Fermat theorem. If f has a local maximum or minimum at \
c, and if f ' (c) exists, then f ' (c) =0.\n\n5. Definition A critical number \
of a function is a number c in the domain of f such that either f ' (c) = 0 \
or f '(c) does not exists.\n\n6. If f has a local extremum at c, the c is a \
critical  number of f.\n\n7.  Theorem: If f '(x) >0 on an interval, the f is \
increasing on the interval, whereas if f '(x) < 0 on an interval, the f is \
decreasing on that interval.\n\n8. The first derivative test: suppose that c \
is a critical number of a continuous function f.\n\ti. if f ' changes from \
positive to negative at c, the f has a locall maximum at c.\n\tii. if f ' \
changes from negative to positive at c, then f has a local mimimum at c.\n\t\
iii. if f ' does not change sign at c, (that is f ' is is either positive or \
negative on both sides of c)\n\t     then f has noi local maximum or minimum \
at c.\n9. Definition: A function (or its graph) is called concave upward on \
an interval I if f ' is an increasing function on I, or f '' (x) > 0 for all \
x \[Epsilon] I. It is called concave downward on I if f ' is decreasing on I, \
or f ''(x) < 0 for all x \[Epsilon] I.\n\n10. Lema: Suppose f '' is \
continuous near c.\n\ti. if f ' (c) \[LongEqual] 0 and f ''(c) > 0, then f \
has a local minimum at c.\n\tii.  if f ' (c) \[LongEqual] 0 and f ''(c) < 0, \
then f has a local maximum at c.\n\tiii.  if f ' (c) \[LongEqual] 0 and f \
''(c) =0, then f has an ",
 ButtonBox["inflection",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[
       ParentDirectory[]], "demons", "koexamderiv"}, 
     "OsculatingCircles-source.nb", CharacterEncoding -> "WindowsANSI"], 
    None}],
 " point at c \n\t\nCalculus: concepts and context. James Stewart.\n"
}], "Text",
 CellChangeTimes->{
  3.45295314578125*^9, {3.4529534380625*^9, 3.452953458140625*^9}, {
   3.452953901296875*^9, 3.452953904171875*^9}, {3.452953988078125*^9, 
   3.452954041484375*^9}, {3.4529541038125*^9, 3.45295422965625*^9}, {
   3.452954262765625*^9, 3.4529542848125*^9}, {3.4529543179375*^9, 
   3.4529544550625*^9}, {3.45295449990625*^9, 3.452954643921875*^9}, {
   3.45295468078125*^9, 3.452954697109375*^9}, {3.45295961578125*^9, 
   3.452959674421875*^9}, {3.45295971259375*^9, 3.45295972115625*^9}, {
   3.452959752421875*^9, 3.452959913984375*^9}, {3.452959998109375*^9, 
   3.452960406125*^9}, {3.452960949203125*^9, 3.452960986578125*^9}, {
   3.452961063140625*^9, 3.452961216296875*^9}, {3.45296126703125*^9, 
   3.452961805625*^9}, {3.45296185228125*^9, 3.4529618575625*^9}, {
   3.452961893921875*^9, 3.4529622143125*^9}, {3.4529622790625*^9, 
   3.452962324296875*^9}, {3.452964606375*^9, 3.452964651984375*^9}, {
   3.4529650770625*^9, 3.4529650770625*^9}, 3.452965131640625*^9}]
}, Open  ]],

Cell["Applications", "Section",
 CellChangeTimes->{3.452964367203125*^9},
 CellTags->"aplications"]
}, Open  ]]
},
WindowSize->{611, 750},
WindowMargins->{{Automatic, 479}, {Automatic, -38}},
DefaultNewCellStyle->"Text",
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "about"->{
  Cell[704, 27, 62, 1, 71, "Section",
   CellTags->"about"]},
 "aplications"->{
  Cell[5781, 134, 99, 2, 71, "Section",
   CellTags->"aplications"]},
 "briefexp"->{
  Cell[1316, 52, 59, 1, 71, "Section",
   CellTags->"briefexp"]},
 "concepts"->{
  Cell[1611, 63, 60, 1, 71, "Section",
   CellTags->"concepts"]},
 "operation"->{
  Cell[1001, 40, 62, 1, 71, "Section",
   CellTags->"operation"]},
 "theory"->{
  Cell[1696, 68, 46, 1, 41, "Section",
   CellTags->"theory"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"about", 6219, 150},
 {"aplications", 6299, 153},
 {"briefexp", 6384, 156},
 {"concepts", 6465, 159},
 {"operation", 6547, 162},
 {"theory", 6627, 165}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 112, 1, 83, "Title"],
Cell[CellGroupData[{
Cell[704, 27, 62, 1, 71, "Section",
 CellTags->"about"],
Cell[769, 30, 195, 5, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1001, 40, 62, 1, 71, "Section",
 CellTags->"operation"],
Cell[1066, 43, 213, 4, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1316, 52, 59, 1, 71, "Section",
 CellTags->"briefexp"],
Cell[1378, 55, 218, 5, 65, "Text"]
}, Open  ]],
Cell[1611, 63, 60, 1, 71, "Section",
 CellTags->"concepts"],
Cell[CellGroupData[{
Cell[1696, 68, 46, 1, 41, "Section",
 CellTags->"theory"],
Cell[1745, 71, 4021, 60, 713, "Text"]
}, Open  ]],
Cell[5781, 134, 99, 2, 71, "Section",
 CellTags->"aplications"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
